@@ -19,6 +19,7 @@ package jakarta.servlet;
 import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.nio.charset.Charset;
 import java.util.Enumeration;
 import java.util.EventListener;
 import java.util.Map;
@@ -71,7 +72,7 @@ public interface ServletContext {
      * Returns a <code>ServletContext</code> object that corresponds to a specified URL on the server.
      * <p>
      * This method allows servlets to gain access to the context for various parts of the server, and as needed obtain
-     * {@link RequestDispatcher} objects from the context. The given path must be begin with "/", is interpreted
+     * {@link RequestDispatcher} objects from the context. The given path must begin with "/", is interpreted
      * relative to the server's document root and is matched against the context roots of other web applications hosted
      * on this container.
      * <p>
@@ -269,7 +270,7 @@ public interface ServletContext {
     /**
      * Returns a <code>String</code> containing the real path for a given virtual path. For example, the path
      * "/index.html" returns the absolute file path on the server's filesystem would be served by a request for
-     * "http://host/contextPath/index.html", where contextPath is the context path of this ServletContext..
+     * "http://host/contextPath/index.html", where contextPath is the context path of this ServletContext.
      * <p>
      * The real path returned will be in a form appropriate to the computer and operating system on which the servlet
      * container is running, including the proper path separators. This method returns <code>null</code> if the servlet
@@ -300,7 +301,7 @@ public interface ServletContext {
      * <code>null</code> if the parameter does not exist.
      * <p>
      * This method can make available configuration information useful to an entire "web application". For example, it
-     * can provide a web site administrator's email address or the name of a system that holds critical data.
+     * can provide a website administrator's email address or the name of a system that holds critical data.
      *
      * @param name a <code>String</code> containing the name of the parameter whose value is requested
      *
@@ -495,10 +496,10 @@ public interface ServletContext {
     ServletRegistration.Dynamic addJspFile(String jspName, String jspFile);
 
     /**
-     * Create an Servlet instance using the given class. The instance is just created. No initialisation occurs.
+     * Create a Servlet instance using the given class. The instance is just created. No initialisation occurs.
      *
      * @param <T> The type for the given class
-     * @param c   The the class for which an instance should be created
+     * @param c   The class for which an instance should be created
      *
      * @return The created Servlet instance.
      *
@@ -625,7 +626,7 @@ public interface ServletContext {
      * Create a Filter instance using the given class. The instance is just created. No initialisation occurs.
      *
      * @param <T> The type for the given class
-     * @param c   The the class for which an instance should be created
+     * @param c   The class for which an instance should be created
      *
      * @return The created Filter instance.
      *
@@ -818,8 +819,6 @@ public interface ServletContext {
      *
      * @return The associated web application class loader
      *
-     * @throws SecurityException if access to the class loader is prevented by a SecurityManager
-     *
      * @since Servlet 3.0
      */
     ClassLoader getClassLoader();
@@ -908,6 +907,27 @@ public interface ServletContext {
      */
     void setRequestCharacterEncoding(String encoding);
 
+    /**
+     * Sets the request character encoding for this ServletContext.
+     * <p>
+     * Implementations are strongly encouraged to override this default method and provide a more efficient
+     * implementation.
+     *
+     * @param encoding request character encoding
+     *
+     * @throws IllegalStateException         if this ServletContext has already been initialized
+     * @throws UnsupportedOperationException if this ServletContext was passed to the
+     *                                           {@link ServletContextListener#contextInitialized} method of a
+     *                                           {@link ServletContextListener} that was neither declared in
+     *                                           {@code web.xml} or {@code web-fragment.xml}, nor annotated with
+     *                                           {@link jakarta.servlet.annotation.WebListener}
+     *
+     * @since Servlet 6.1
+     */
+    default void setRequestCharacterEncoding(Charset encoding) {
+        setRequestCharacterEncoding(encoding.name());
+    }
+
     /**
      * Get the default character encoding for writing response bodies.
      *
@@ -917,6 +937,27 @@ public interface ServletContext {
      */
     String getResponseCharacterEncoding();
 
+    /**
+     * Sets the response character encoding for this ServletContext.
+     * <p>
+     * Implementations are strongly encouraged to override this default method and provide a more efficient
+     * implementation.
+     *
+     * @param encoding response character encoding
+     *
+     * @throws IllegalStateException         if this ServletContext has already been initialized
+     * @throws UnsupportedOperationException if this ServletContext was passed to the
+     *                                           {@link ServletContextListener#contextInitialized} method of a
+     *                                           {@link ServletContextListener} that was neither declared in
+     *                                           {@code web.xml} or {@code web-fragment.xml}, nor annotated with
+     *                                           {@link jakarta.servlet.annotation.WebListener}
+     *
+     * @since Servlet 6.1
+     */
+    default void setResponseCharacterEncoding(Charset encoding) {
+        setResponseCharacterEncoding(encoding.name());
+    }
+
     /**
      * Set the default character encoding to use for writing response bodies. Calling this method will over-ride any
      * value set in the deployment descriptor.
