@@ -19,6 +19,7 @@ package jakarta.servlet.http;
 import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
+import java.io.Serial;
 import java.io.UnsupportedEncodingException;
 import java.io.Writer;
 import java.lang.reflect.InvocationTargetException;
@@ -43,7 +44,7 @@ import jakarta.servlet.WriteListener;
 
 
 /**
- * Provides an abstract class to be subclassed to create an HTTP servlet suitable for a Web site. A subclass of
+ * Provides an abstract class to be subclassed to create an HTTP servlet suitable for a website. A subclass of
  * <code>HttpServlet</code> must override at least one method, usually one of these:
  * <ul>
  * <li><code>doGet</code>, if the servlet supports HTTP GET requests
@@ -68,12 +69,14 @@ import jakarta.servlet.WriteListener;
  */
 public abstract class HttpServlet extends GenericServlet {
 
+    @Serial
     private static final long serialVersionUID = 1L;
 
     private static final String METHOD_DELETE = "DELETE";
     private static final String METHOD_HEAD = "HEAD";
     private static final String METHOD_GET = "GET";
     private static final String METHOD_OPTIONS = "OPTIONS";
+    private static final String METHOD_PATCH = "PATCH";
     private static final String METHOD_POST = "POST";
     private static final String METHOD_PUT = "PUT";
     private static final String METHOD_TRACE = "TRACE";
@@ -221,6 +224,48 @@ public abstract class HttpServlet extends GenericServlet {
     }
 
 
+    /**
+     * Called by the server (via the <code>service</code> method) to allow a servlet to handle a PATCH request. The HTTP
+     * PATCH method allows the client to partially modify an existing resource.
+     * <p>
+     * When overriding this method, read the request data and write the response headers, get the response's Writer or
+     * output stream object, and finally, write the response data. It's best to include content type and encoding. When
+     * using a <code>PrintWriter</code> object to return the response, set the content type before accessing the
+     * <code>PrintWriter</code> object.
+     * <p>
+     * The servlet container must write the headers before committing the response, because in HTTP the headers must be
+     * sent before the response body.
+     * <p>
+     * Where possible, set the Content-Length header (with the {@link jakarta.servlet.ServletResponse#setContentLength}
+     * method), to allow the servlet container to use a persistent connection to return its response to the client,
+     * improving performance. The content length is automatically set if the entire response fits inside the response
+     * buffer.
+     * <p>
+     * When using HTTP 1.1 chunked encoding (which means that the response has a Transfer-Encoding header), do not set
+     * the Content-Length header.
+     * <p>
+     * This method is neither safe nor idempotent. Operations requested through PATCH have side effects for which the
+     * user can be held accountable.
+     * <p>
+     * If the HTTP PATCH request is incorrectly formatted, <code>doPost</code> returns an HTTP "Bad Request" message.
+     *
+     * @param req  an {@link HttpServletRequest} object that contains the request the client has made of the servlet
+     * @param resp an {@link HttpServletResponse} object that contains the response the servlet sends to the client
+     *
+     * @exception IOException      if an input or output error is detected when the servlet handles the request
+     * @exception ServletException if the request for the POST could not be handled
+     *
+     * @see jakarta.servlet.ServletOutputStream
+     * @see jakarta.servlet.ServletResponse#setContentType
+     *
+     * @since Servlet 6.1
+     */
+    protected void doPatch(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
+        String msg = lStrings.getString("http.method_patch_not_supported");
+        sendMethodNotAllowed(req, resp, msg);
+    }
+
+
     /**
      * Called by the server (via the <code>service</code> method) to allow a servlet to handle a POST request. The HTTP
      * POST method allows the client to send data of unlimited length to the Web server a single time and is useful when
@@ -319,7 +364,7 @@ public abstract class HttpServlet extends GenericServlet {
         String protocol = req.getProtocol();
         // Note: Tomcat reports "" for HTTP/0.9 although some implementations
         // may report HTTP/0.9
-        if (protocol.length() == 0 || protocol.endsWith("0.9") || protocol.endsWith("1.0")) {
+        if (protocol.isEmpty() || protocol.endsWith("0.9") || protocol.endsWith("1.0")) {
             resp.sendError(HttpServletResponse.SC_BAD_REQUEST, msg);
         } else {
             resp.sendError(HttpServletResponse.SC_METHOD_NOT_ALLOWED, msg);
@@ -342,6 +387,7 @@ public abstract class HttpServlet extends GenericServlet {
 
                     boolean allowGet = false;
                     boolean allowHead = false;
+                    boolean allowPatch = false;
                     boolean allowPost = false;
                     boolean allowPut = false;
                     boolean allowDelete = false;
@@ -353,6 +399,10 @@ public abstract class HttpServlet extends GenericServlet {
                                 allowHead = true;
                                 break;
                             }
+                            case "doPatch": {
+                                allowPatch = true;
+                                break;
+                            }
                             case "doPost": {
                                 allowPost = true;
                                 break;
@@ -383,6 +433,11 @@ public abstract class HttpServlet extends GenericServlet {
                         allow.append(", ");
                     }
 
+                    if (allowPatch) {
+                        allow.append(METHOD_PATCH);
+                        allow.append(", ");
+                    }
+
                     if (allowPost) {
                         allow.append(METHOD_POST);
                         allow.append(", ");
@@ -452,7 +507,7 @@ public abstract class HttpServlet extends GenericServlet {
 
         // Tomcat specific hack to see if TRACE is allowed
         if (TomcatHack.getAllowTrace(req)) {
-            if (allow.length() == 0) {
+            if (allow.isEmpty()) {
                 allow = METHOD_TRACE;
             } else {
                 allow = allow + ", " + METHOD_TRACE;
@@ -521,14 +576,16 @@ public abstract class HttpServlet extends GenericServlet {
      * <li>proxy-authorization</li>
      * </ul>
      * <p>
-     * Note that HTTP header names are case insensitive.
+     * Note that HTTP header names are case-insensitive.
      *
      * @param headerName the name of the HTTP request header to test
      *
-     * @return (@code true} if the HTTP request header is considered sensitive and should be excluded from the response
+     * @return {@code true} if the HTTP request header is considered sensitive and should be excluded from the response
      *             to a {@code TRACE} request, otherwise {@code false}
+     *
+     * @since Servlet 6.1
      */
-    private boolean isSensitiveHeader(String headerName) {
+    protected boolean isSensitiveHeader(String headerName) {
         String lcHeaderName = headerName.toLowerCase(Locale.ENGLISH);
         for (String sensitiveHeaderName : SENSITIVE_HTTP_HEADERS) {
             if (lcHeaderName.startsWith(sensitiveHeaderName)) {
@@ -556,63 +613,58 @@ public abstract class HttpServlet extends GenericServlet {
 
         String method = req.getMethod();
 
-        if (method.equals(METHOD_GET)) {
-            long lastModified = getLastModified(req);
-            if (lastModified == -1) {
-                // servlet doesn't support if-modified-since, no reason
-                // to go through further expensive logic
-                doGet(req, resp);
-            } else {
-                long ifModifiedSince;
-                try {
-                    ifModifiedSince = req.getDateHeader(HEADER_IFMODSINCE);
-                } catch (IllegalArgumentException iae) {
-                    // Invalid date header - proceed as if none was set
-                    ifModifiedSince = -1;
-                }
-                if (ifModifiedSince < (lastModified / 1000 * 1000)) {
-                    // If the servlet mod time is later, call doGet()
-                    // Round down to the nearest second for a proper compare
-                    // A ifModifiedSince of -1 will always be less
-                    maybeSetLastModified(resp, lastModified);
+        switch (method) {
+            case METHOD_GET -> {
+                long lastModified = getLastModified(req);
+                if (lastModified == -1) {
+                    // servlet doesn't support if-modified-since, no reason
+                    // to go through further expensive logic
                     doGet(req, resp);
                 } else {
-                    resp.setStatus(HttpServletResponse.SC_NOT_MODIFIED);
+                    long ifModifiedSince;
+                    try {
+                        ifModifiedSince = req.getDateHeader(HEADER_IFMODSINCE);
+                    } catch (IllegalArgumentException iae) {
+                        // Invalid date header - proceed as if none was set
+                        ifModifiedSince = -1;
+                    }
+                    if (ifModifiedSince < (lastModified / 1000 * 1000)) {
+                        // If the servlet mod time is later, call doGet()
+                        // Round down to the nearest second for a proper compare
+                        // A ifModifiedSince of -1 will always be less
+                        maybeSetLastModified(resp, lastModified);
+                        doGet(req, resp);
+                    } else {
+                        resp.setStatus(HttpServletResponse.SC_NOT_MODIFIED);
+                    }
                 }
+
             }
+            case METHOD_HEAD -> {
+                long lastModified = getLastModified(req);
+                maybeSetLastModified(resp, lastModified);
+                doHead(req, resp);
 
-        } else if (method.equals(METHOD_HEAD)) {
-            long lastModified = getLastModified(req);
-            maybeSetLastModified(resp, lastModified);
-            doHead(req, resp);
+            }
+            case METHOD_POST -> doPost(req, resp);
+            case METHOD_PUT -> doPut(req, resp);
+            case METHOD_DELETE -> doDelete(req, resp);
+            case METHOD_OPTIONS -> doOptions(req, resp);
+            case METHOD_TRACE -> doTrace(req, resp);
+            case METHOD_PATCH -> doPatch(req, resp);
+            default -> {
+                //
+                // Note that this means NO servlet supports whatever
+                // method was requested, anywhere on this server.
+                //
 
-        } else if (method.equals(METHOD_POST)) {
-            doPost(req, resp);
+                String errMsg = lStrings.getString("http.method_not_implemented");
+                Object[] errArgs = new Object[1];
+                errArgs[0] = method;
+                errMsg = MessageFormat.format(errMsg, errArgs);
 
-        } else if (method.equals(METHOD_PUT)) {
-            doPut(req, resp);
-
-        } else if (method.equals(METHOD_DELETE)) {
-            doDelete(req, resp);
-
-        } else if (method.equals(METHOD_OPTIONS)) {
-            doOptions(req, resp);
-
-        } else if (method.equals(METHOD_TRACE)) {
-            doTrace(req, resp);
-
-        } else {
-            //
-            // Note that this means NO servlet supports whatever
-            // method was requested, anywhere on this server.
-            //
-
-            String errMsg = lStrings.getString("http.method_not_implemented");
-            Object[] errArgs = new Object[1];
-            errArgs[0] = method;
-            errMsg = MessageFormat.format(errMsg, errArgs);
-
-            resp.sendError(HttpServletResponse.SC_NOT_IMPLEMENTED, errMsg);
+                resp.sendError(HttpServletResponse.SC_NOT_IMPLEMENTED, errMsg);
+            }
         }
     }
 
@@ -683,8 +735,9 @@ public abstract class HttpServlet extends GenericServlet {
                 if (REQUEST_FACADE_CLAZZ.isAssignableFrom(req.getClass())) {
                     try {
                         return ((Boolean) GET_ALLOW_TRACE.invoke(req, (Object[]) null)).booleanValue();
-                    } catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException ignore) {
+                    } catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
                         // Should never happen given the checks in place.
+                        // Ignore
                     }
                 }
             }
@@ -819,7 +872,7 @@ public abstract class HttpServlet extends GenericServlet {
         }
 
         @Override
-        public void write(byte buf[], int offset, int len) throws IOException {
+        public void write(byte[] buf, int offset, int len) throws IOException {
             if (buf == null) {
                 throw new NullPointerException(lStrings.getString("err.io.nullArray"));
             }
@@ -891,11 +944,11 @@ public abstract class HttpServlet extends GenericServlet {
             Writer osw = null;
             try {
                 osw = new OutputStreamWriter(out, encoding);
-            } catch (UnsupportedEncodingException ignore) {
-                /*
-                 * Impossible. The same values were used in the constructor. If this method gets called then the
-                 * constructor must have succeeded so the above call must also succeed.
-                 */
+            } catch (UnsupportedEncodingException e) {
+                // Impossible.
+                // The same values were used in the constructor. If this method
+                // gets called then the constructor must have succeeded so the
+                // above call must also succeed.
             }
             pw = new PrintWriter(osw);
         }
@@ -1040,14 +1093,7 @@ public abstract class HttpServlet extends GenericServlet {
     /*
      * Calls NoBodyResponse.setContentLength() once the async request is complete.
      */
-    private static class NoBodyAsyncContextListener implements AsyncListener {
-
-        private final NoBodyResponse noBodyResponse;
-
-        NoBodyAsyncContextListener(NoBodyResponse noBodyResponse) {
-            this.noBodyResponse = noBodyResponse;
-        }
-
+    private record NoBodyAsyncContextListener(NoBodyResponse noBodyResponse) implements AsyncListener {
         @Override
         public void onComplete(AsyncEvent event) throws IOException {
             noBodyResponse.setContentLength();
