@@ -27,13 +27,11 @@ import jakarta.servlet.RequestDispatcher;
 import jakarta.servlet.http.Cookie;
 import jakarta.servlet.http.HttpServletRequest;
 import jakarta.servlet.http.HttpServletResponse;
-import jakarta.servlet.http.HttpSession;
 
 import org.apache.catalina.Globals;
 import org.apache.catalina.Realm;
 import org.apache.catalina.Session;
 import org.apache.catalina.connector.Request;
-import org.apache.catalina.connector.Response;
 import org.apache.coyote.ActionCode;
 import org.apache.coyote.ContinueResponseTiming;
 import org.apache.juli.logging.Log;
@@ -335,14 +333,11 @@ public class FormAuthenticator extends AuthenticatorBase {
                 response.sendRedirect(response.encodeRedirectURL(uri));
             }
         } else {
-            // Until the Servlet API allows specifying the type of redirect to
-            // use.
-            Response internalResponse = request.getResponse();
             String location = response.encodeRedirectURL(requestURI);
             if ("HTTP/1.1".equals(request.getProtocol())) {
-                internalResponse.sendRedirect(location, HttpServletResponse.SC_SEE_OTHER);
+                response.sendRedirect(location, HttpServletResponse.SC_SEE_OTHER);
             } else {
-                internalResponse.sendRedirect(location, HttpServletResponse.SC_FOUND);
+                response.sendRedirect(location, HttpServletResponse.SC_FOUND);
             }
         }
         return false;
@@ -716,23 +711,21 @@ public class FormAuthenticator extends AuthenticatorBase {
         saved.setDecodedRequestURI(request.getDecodedRequestURI());
 
         SavedRequest previousSavedRequest = (SavedRequest) session.getNote(Constants.FORM_REQUEST_NOTE);
-        if (session instanceof HttpSession) {
-            if (((HttpSession) session).isNew()) {
-                int originalMaxInactiveInterval = session.getMaxInactiveInterval();
-                if (originalMaxInactiveInterval > getAuthenticationSessionTimeout() || originalMaxInactiveInterval <= 0) {
-                    saved.setOriginalMaxInactiveInterval(originalMaxInactiveInterval);
-                    session.setMaxInactiveInterval(getAuthenticationSessionTimeout());
-                }
-            } else if (previousSavedRequest != null &&
-                    previousSavedRequest.getOriginalMaxInactiveIntervalOptional() != null) {
-                /*
-                 * The user may have refreshed the browser page during authentication. Transfer the original max inactive
-                 * interval from previous saved request to current one else, once authentication is completed, the session
-                 * will retain the shorter authentication session timeout
-                 */
-                saved.setOriginalMaxInactiveInterval(
-                        previousSavedRequest.getOriginalMaxInactiveIntervalOptional().intValue());
+        if (session.isNew()) {
+            int originalMaxInactiveInterval = session.getMaxInactiveInterval();
+            if (originalMaxInactiveInterval > getAuthenticationSessionTimeout() || originalMaxInactiveInterval <= 0) {
+                saved.setOriginalMaxInactiveInterval(originalMaxInactiveInterval);
+                session.setMaxInactiveInterval(getAuthenticationSessionTimeout());
             }
+        } else if (previousSavedRequest != null &&
+                previousSavedRequest.getOriginalMaxInactiveIntervalOptional() != null) {
+            /*
+             * The user may have refreshed the browser page during authentication. Transfer the original max inactive
+             * interval from previous saved request to current one else, once authentication is completed, the session
+             * will retain the shorter authentication session timeout
+             */
+            saved.setOriginalMaxInactiveInterval(
+                    previousSavedRequest.getOriginalMaxInactiveIntervalOptional().intValue());
         }
 
         // Stash the SavedRequest in our session for later use
