@@ -25,26 +25,24 @@ import java.util.HashSet;
 
 import javax.management.ObjectName;
 
-import org.apache.catalina.Globals;
 import org.apache.catalina.LifecycleException;
 import org.apache.catalina.LifecycleState;
 import org.apache.catalina.Service;
+import org.apache.catalina.core.AprStatus;
 import org.apache.catalina.util.LifecycleMBeanBase;
 import org.apache.coyote.AbstractProtocol;
 import org.apache.coyote.Adapter;
 import org.apache.coyote.ProtocolHandler;
 import org.apache.coyote.UpgradeProtocol;
-import org.apache.coyote.http11.AbstractHttp11JsseProtocol;
+import org.apache.coyote.http11.AbstractHttp11Protocol;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
-import org.apache.tomcat.jni.AprStatus;
 import org.apache.tomcat.util.IntrospectionUtils;
 import org.apache.tomcat.util.buf.B2CConverter;
 import org.apache.tomcat.util.buf.CharsetUtil;
 import org.apache.tomcat.util.buf.EncodedSolidusHandling;
 import org.apache.tomcat.util.buf.StringUtils;
 import org.apache.tomcat.util.compat.JreCompat;
-import org.apache.tomcat.util.http.Method;
 import org.apache.tomcat.util.net.SSLHostConfig;
 import org.apache.tomcat.util.net.openssl.OpenSSLImplementation;
 import org.apache.tomcat.util.net.openssl.OpenSSLStatus;
@@ -53,6 +51,9 @@ import org.apache.tomcat.util.res.StringManager;
 
 /**
  * Implementation of a Coyote connector.
+ *
+ * @author Craig R. McClanahan
+ * @author Remy Maucherat
  */
 public class Connector extends LifecycleMBeanBase {
 
@@ -61,22 +62,6 @@ public class Connector extends LifecycleMBeanBase {
 
     public static final String INTERNAL_EXECUTOR_NAME = "Internal";
 
-    private static final boolean aprStatusPresent;
-
-    static {
-        /*
-         * The AprStatus class has to be in the org.apache.tomcat.jni package so it can be referenced by the OpenSSL
-         * clean-up code to avoid a race condition on shutdown between the AprLifecycleListener shutting down the Tomcat
-         * Native library along with any remaining open connections and the OpenSSL clean-up code shutting down an
-         * individual connection that can trigger a JVM crash.
-         *
-         * In some deployment scenarios AprStatus is not present - e.g. because tomcat-jni.jar is not present. To avoid
-         * a CNFE in this class on Connector initialisation when AprStatus is not present - and ugly work-arounds that
-         * try loading the class and catching the exception - use getResource() to see if AprStatus is present.
-         */
-        aprStatusPresent =
-                (Connector.class.getClassLoader().getResource("org/apache/tomcat/jni/AprStatus.class") != null);
-    }
 
     // ------------------------------------------------------------ Constructor
 
@@ -220,10 +205,10 @@ public class Connector extends LifecycleMBeanBase {
     private int maxCookieCount = 200;
 
     /**
-     * The maximum number of parameters (GET plus POST) which will be automatically parsed by the container. 10000 by
-     * default. The default Tomcat server.xml configures a lower default of 1000. A value of less than 0 means no limit.
+     * The maximum number of parameters (GET plus POST) which will be automatically parsed by the container. 1000 by
+     * default. A value of less than 0 means no limit.
      */
-    protected int maxParameterCount = 10000;
+    protected int maxParameterCount = 1000;
 
     private int maxPartCount = 50;
 
@@ -244,7 +229,7 @@ public class Connector extends LifecycleMBeanBase {
      * Comma-separated list of HTTP methods that will be parsed according to POST-style rules for
      * application/x-www-form-urlencoded request bodies.
      */
-    protected String parseBodyMethods = Method.POST;
+    protected String parseBodyMethods = "POST";
 
     /**
      * A Set of methods determined by {@link #parseBodyMethods}.
@@ -415,11 +400,10 @@ public class Connector extends LifecycleMBeanBase {
 
 
     /**
-     * @return <code>true</code> if the object facades are discarded, either when the discardFacades value is
-     *             <code>true</code> or when the security manager is enabled.
+     * @return <code>true</code> if the object facades are discarded.
      */
     public boolean getDiscardFacades() {
-        return discardFacades || Globals.IS_SECURITY_ENABLED;
+        return discardFacades;
     }
 
 
@@ -578,7 +562,7 @@ public class Connector extends LifecycleMBeanBase {
             methodSet.addAll(Arrays.asList(StringUtils.splitCommaSeparated(methods)));
         }
 
-        if (methodSet.contains(Method.TRACE)) {
+        if (methodSet.contains("TRACE")) {
             throw new IllegalArgumentException(sm.getString("coyoteConnector.parseBodyMethodNoTrace"));
         }
 
@@ -958,25 +942,33 @@ public class Connector extends LifecycleMBeanBase {
      * Create (or allocate) and return a Request object suitable for specifying the contents of a Request to the
      * responsible Container.
      *
+     * @param coyoteRequest The Coyote request with which the Request object will always be associated. In normal usage
+     *                          this must be non-null. In some test scenarios, it may be possible to use a null request
+     *                          without triggering an NPE.
+     *
      * @return a new Servlet request object
      */
-    public Request createRequest() {
-        return new Request(this);
+    public Request createRequest(org.apache.coyote.Request coyoteRequest) {
+        return new Request(this, coyoteRequest);
     }
 
 
     /**
-     * Create (or allocate) and return a Response object suitable for receiving the contents of a Response from the
-     * responsible Container.
+     * Create and return a Response object suitable for receiving the contents of a Response from the responsible
+     * Container.
+     *
+     * @param coyoteResponse The Coyote request with which the Response object will always be associated. In normal
+     *                           usage this must be non-null. In some test scenarios, it may be possible to use a null
+     *                           response without triggering an NPE.
      *
      * @return a new Servlet response object
      */
-    public Response createResponse() {
+    public Response createResponse(org.apache.coyote.Response coyoteResponse) {
         int size = protocolHandler.getDesiredBufferSize();
         if (size > 0) {
-            return new Response(size);
+            return new Response(coyoteResponse, size);
         } else {
-            return new Response();
+            return new Response(coyoteResponse);
         }
     }
 
@@ -1062,21 +1054,23 @@ public class Connector extends LifecycleMBeanBase {
             setParseBodyMethods(getParseBodyMethods());
         }
 
-        if (protocolHandler instanceof AbstractHttp11JsseProtocol) {
-            AbstractHttp11JsseProtocol<?> jsseProtocolHandler = (AbstractHttp11JsseProtocol<?>) protocolHandler;
+        if (JreCompat.isJre22Available() && OpenSSLStatus.getUseOpenSSL() && OpenSSLStatus.isAvailable() &&
+            protocolHandler instanceof AbstractHttp11Protocol<?> jsseProtocolHandler) {
+            // Use FFM and OpenSSL if available
             if (jsseProtocolHandler.isSSLEnabled() && jsseProtocolHandler.getSslImplementationName() == null) {
-                // If SSL is enabled and a specific implementation isn't specified, select the correct default.
-                if (JreCompat.isJre22Available() && OpenSSLStatus.getUseOpenSSL() && OpenSSLStatus.isAvailable()) {
-                    // Use FFM and OpenSSL if available
-                    jsseProtocolHandler.setSslImplementationName(
-                            "org.apache.tomcat.util.net.openssl.panama.OpenSSLImplementation");
-                } else if (aprStatusPresent && AprStatus.isAprAvailable() && AprStatus.getUseOpenSSL()) {
-                    // Use tomcat-native and OpenSSL otherwise, if available
-                    jsseProtocolHandler.setSslImplementationName(OpenSSLImplementation.class.getName());
-                }
-                // Otherwise the default JSSE will be used
+                // OpenSSL is compatible with the JSSE configuration, so use it if it is available
+                jsseProtocolHandler
+                        .setSslImplementationName("org.apache.tomcat.util.net.openssl.panama.OpenSSLImplementation");
+            }
+        } else if (AprStatus.isAprAvailable() && AprStatus.getUseOpenSSL() &&
+            protocolHandler instanceof AbstractHttp11Protocol<?> jsseProtocolHandler) {
+            // Use tomcat-native and OpenSSL otherwise, if available
+            if (jsseProtocolHandler.isSSLEnabled() && jsseProtocolHandler.getSslImplementationName() == null) {
+                // OpenSSL is compatible with the JSSE configuration, so use it if APR is available
+                jsseProtocolHandler.setSslImplementationName(OpenSSLImplementation.class.getName());
             }
         }
+        // Otherwise the default JSSE will be used
 
         try {
             protocolHandler.init();
