@@ -32,7 +32,6 @@ import javax.management.ObjectName;
 import org.apache.catalina.Container;
 import org.apache.catalina.Context;
 import org.apache.catalina.Engine;
-import org.apache.catalina.Globals;
 import org.apache.catalina.Host;
 import org.apache.catalina.JmxEnabled;
 import org.apache.catalina.LifecycleEvent;
@@ -49,6 +48,9 @@ import org.apache.tomcat.util.ExceptionUtils;
 /**
  * Standard implementation of the <b>Host</b> interface. Each child container must be a Context implementation to
  * process the requests directed to a particular web application.
+ *
+ * @author Craig R. McClanahan
+ * @author Remy Maucherat
  */
 public class StandardHost extends ContainerBase implements Host {
 
@@ -130,7 +132,7 @@ public class StandardHost extends ContainerBase implements Host {
     /**
      * deploy Context XML config files property.
      */
-    private boolean deployXML = !Globals.IS_SECURITY_ENABLED;
+    private boolean deployXML = true;
 
 
     /**
@@ -328,8 +330,7 @@ public class StandardHost extends ContainerBase implements Host {
         }
         try {
             file = file.getCanonicalFile();
-        } catch (IOException ignore) {
-            // Ignore
+        } catch (IOException e) {// ignore
         }
         this.hostConfigBase = file;
         return file;
@@ -635,7 +636,7 @@ public class StandardHost extends ContainerBase implements Host {
     @Override
     public void addChild(Container child) {
 
-        if (!(child instanceof Context)) {
+        if (!(child instanceof Context context)) {
             throw new IllegalArgumentException(sm.getString("standardHost.notContext"));
         }
 
@@ -643,7 +644,6 @@ public class StandardHost extends ContainerBase implements Host {
 
         // Avoid NPE for case where Context is defined in server.xml with only a
         // docBase
-        Context context = (Context) child;
         if (context.getPath() == null) {
             ContextName cn = new ContextName(context.getDocBase(), true);
             context.setPath(cn.getPath());
@@ -662,8 +662,7 @@ public class StandardHost extends ContainerBase implements Host {
         @Override
         public void lifecycleEvent(LifecycleEvent event) {
             if (event.getType().equals(AFTER_START_EVENT)) {
-                if (event.getSource() instanceof Context) {
-                    Context context = ((Context) event.getSource());
+                if (event.getSource() instanceof Context context) {
                     childClassLoaders.put(context.getLoader().getClassLoader(),
                             context.getServletContext().getContextPath());
                 }
