@@ -50,6 +50,9 @@ import org.apache.tomcat.util.res.StringManager;
  * <p>
  * <b>IMPLEMENTATION NOTE </b>: Correct behavior of session storing and reloading depends upon external calls to the
  * <code>start()</code> and <code>stop()</code> methods of this class at the correct times.
+ *
+ * @author Craig R. McClanahan
+ * @author Peter Rossbach
  */
 public class DeltaManager extends ClusterManagerBase {
 
@@ -514,8 +517,8 @@ public class DeltaManager extends ClusterManagerBase {
                     counterSend_EVT_CHANGE_SESSION_ID.incrementAndGet();
                 }
                 send(msg);
-            } catch (IOException ioe) {
-                log.error(sm.getString("deltaManager.unableSerializeSessionID", newSessionID), ioe);
+            } catch (IOException e) {
+                log.error(sm.getString("deltaManager.unableSerializeSessionID", newSessionID), e);
             }
         }
     }
@@ -606,9 +609,9 @@ public class DeltaManager extends ClusterManagerBase {
         } catch (ClassNotFoundException e) {
             log.error(sm.getString("deltaManager.loading.cnfe", e), e);
             throw e;
-        } catch (IOException ioe) {
-            log.error(sm.getString("deltaManager.loading.ioe", ioe), ioe);
-            throw ioe;
+        } catch (IOException e) {
+            log.error(sm.getString("deltaManager.loading.ioe", e), e);
+            throw e;
         }
     }
 
@@ -634,9 +637,9 @@ public class DeltaManager extends ClusterManagerBase {
             }
             // Flush and close the output stream
             oos.flush();
-        } catch (IOException ioe) {
-            log.error(sm.getString("deltaManager.unloading.ioe", ioe), ioe);
-            throw ioe;
+        } catch (IOException e) {
+            log.error(sm.getString("deltaManager.unloading.ioe", e), e);
+            throw e;
         }
 
         // send object data as byte[]
@@ -785,8 +788,8 @@ public class DeltaManager extends ClusterManagerBase {
             do {
                 try {
                     Thread.sleep(100);
-                } catch (Exception ignore) {
-                    // Ignore
+                } catch (Exception sleep) {
+                    //
                 }
                 reqNow = System.currentTimeMillis();
                 isTimeout = ((reqNow - reqStart) > (1000L * getStateTransferTimeout()));
@@ -797,7 +800,7 @@ public class DeltaManager extends ClusterManagerBase {
                 do {
                     try {
                         Thread.sleep(100);
-                    } catch (Exception ignore) {
+                    } catch (Exception sleep) {
                         // Ignore
                     }
                 } while ((!getStateTransferred()) && (!isNoContextManagerReceived()));
@@ -865,8 +868,7 @@ public class DeltaManager extends ClusterManagerBase {
 
     @Override
     public void messageDataReceived(ClusterMessage cmsg) {
-        if (cmsg instanceof SessionMessage) {
-            SessionMessage msg = (SessionMessage) cmsg;
+        if (cmsg instanceof SessionMessage msg) {
             switch (msg.getEventType()) {
                 case SessionMessage.EVT_GET_ALL_SESSIONS:
                 case SessionMessage.EVT_SESSION_CREATED:
@@ -923,8 +925,8 @@ public class DeltaManager extends ClusterManagerBase {
                 msg = new SessionMessageImpl(getName(), SessionMessage.EVT_SESSION_DELTA, session.getDiff(), sessionId,
                         sessionId + "-" + System.currentTimeMillis());
             }
-        } catch (IOException ioe) {
-            log.error(sm.getString("deltaManager.createMessage.unableCreateDeltaRequest", sessionId), ioe);
+        } catch (IOException x) {
+            log.error(sm.getString("deltaManager.createMessage.unableCreateDeltaRequest", sessionId), x);
             return null;
         }
         if (msg == null) {
@@ -1046,8 +1048,7 @@ public class DeltaManager extends ClusterManagerBase {
             log.trace("Start expire all sessions " + getName() + " at " + timeNow + " sessioncount " + sessions.length);
         }
         for (Session value : sessions) {
-            if (value instanceof DeltaSession) {
-                DeltaSession session = (DeltaSession) value;
+            if (value instanceof DeltaSession session) {
                 if (session.isPrimarySession()) {
                     if (session.isValid()) {
                         session.expire();
@@ -1124,8 +1125,8 @@ public class DeltaManager extends ClusterManagerBase {
                     // we didn't recognize the message type, do nothing
                     break;
             } // switch
-        } catch (Exception e) {
-            log.error(sm.getString("deltaManager.receiveMessage.error", getName()), e);
+        } catch (Exception x) {
+            log.error(sm.getString("deltaManager.receiveMessage.error", getName()), x);
         } finally {
             currentThread.setContextClassLoader(contextLoader);
         }
@@ -1311,7 +1312,7 @@ public class DeltaManager extends ClusterManagerBase {
                 if (getSendAllSessionsWaitTime() > 0 && remain > 0) {
                     try {
                         Thread.sleep(getSendAllSessionsWaitTime());
-                    } catch (Exception ignore) {
+                    } catch (Exception sleep) {
                         // Ignore
                     }
                 }
