@@ -304,8 +304,7 @@ public class ReplicationValve extends ValveBase implements ClusterValve {
                 crossContextSessions.set(new ArrayList<>());
             }
             getNext().invoke(request, response);
-            if (context != null && cluster != null && context.getManager() instanceof ClusterManager) {
-                ClusterManager clusterManager = (ClusterManager) context.getManager();
+            if (context != null && cluster != null && context.getManager() instanceof ClusterManager clusterManager) {
 
                 // valve cluster can access manager - other cluster handle replication
                 // at host level - hopefully!
@@ -377,9 +376,9 @@ public class ReplicationValve extends ValveBase implements ClusterValve {
             if (isCrossContext) {
                 sendCrossContextSession();
             }
-        } catch (Exception e) {
+        } catch (Exception x) {
             // FIXME we have a lot of sends, but the trouble with one node stops the correct replication to other nodes!
-            log.error(sm.getString("ReplicationValve.send.failure"), e);
+            log.error(sm.getString("ReplicationValve.send.failure"), x);
         } finally {
             if (doStatistics()) {
                 updateStats(totalstart, start, isAsync);
@@ -506,8 +505,8 @@ public class ReplicationValve extends ValveBase implements ClusterValve {
         for (String invalidId : invalidIds) {
             try {
                 send(manager, invalidId);
-            } catch (Exception e) {
-                log.error(sm.getString("ReplicationValve.send.invalid.failure", invalidId), e);
+            } catch (Exception x) {
+                log.error(sm.getString("ReplicationValve.send.invalid.failure", invalidId), x);
             }
         }
     }
@@ -545,7 +544,8 @@ public class ReplicationValve extends ValveBase implements ClusterValve {
                             Long.valueOf(totalSendTime.longValue() / nrOfRequests.longValue()),
                             Long.valueOf(nrOfRequests.longValue()), Long.valueOf(nrOfSendRequests.longValue()),
                             Long.valueOf(nrOfCrossContextSendRequests.longValue()),
-                            Long.valueOf(nrOfFilterRequests.longValue()), Long.valueOf(totalRequestTime.longValue()),
+                            Long.valueOf(nrOfFilterRequests.longValue()),
+                            Long.valueOf(totalRequestTime.longValue()),
                             Long.valueOf(totalSendTime.longValue())));
                 }
             }
@@ -565,8 +565,7 @@ public class ReplicationValve extends ValveBase implements ClusterValve {
         if ((id != null) && (!id.isEmpty())) {
             Manager manager = request.getContext().getManager();
             Session session = manager.findSession(id);
-            if (session instanceof ClusterSession) {
-                ClusterSession cses = (ClusterSession) session;
+            if (session instanceof ClusterSession cses) {
                 if (log.isDebugEnabled()) {
                     log.debug(sm.getString("ReplicationValve.session.indicator", request.getContext().getName(), id,
                             primaryIndicatorName, Boolean.valueOf(cses.isPrimarySession())));
