@@ -16,6 +16,7 @@
  */
 package org.apache.catalina.realm;
 
+import java.io.IOException;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
 import java.net.URI;
@@ -41,85 +42,78 @@ import org.apache.catalina.LifecycleException;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.ExceptionUtils;
+import org.apache.tomcat.util.file.ConfigFileLoader;
+import org.apache.tomcat.util.file.ConfigurationSource;
 
 /**
- * <p>Implementation of <b>Realm</b> that authenticates users via the <em>Java
- * Authentication and Authorization Service</em> (JAAS).  JAAS support requires
- * either JDK 1.4 (which includes it as part of the standard platform) or
- * JDK 1.3 (with the plug-in <code>jaas.jar</code> file).</p>
- *
- * <p>The value configured for the <code>appName</code> property is passed to
- * the <code>javax.security.auth.login.LoginContext</code> constructor, to
- * specify the <em>application name</em> used to select the set of relevant
- * <code>LoginModules</code> required.</p>
- *
- * <p>The JAAS Specification describes the result of a successful login as a
- * <code>javax.security.auth.Subject</code> instance, which can contain zero
- * or more <code>java.security.Principal</code> objects in the return value
- * of the <code>Subject.getPrincipals()</code> method.  However, it provides
- * no guidance on how to distinguish Principals that describe the individual
- * user (and are thus appropriate to return as the value of
- * request.getUserPrincipal() in a web application) from the Principal(s)
- * that describe the authorized roles for this user.  To maintain as much
- * independence as possible from the underlying <code>LoginMethod</code>
- * implementation executed by JAAS, the following policy is implemented by
- * this Realm:</p>
+ * <p>
+ * Implementation of <b>Realm</b> that authenticates users via the <em>Java Authentication and Authorization
+ * Service</em> (JAAS).
+ * </p>
+ * <p>
+ * The value configured for the <code>appName</code> property is passed to the
+ * <code>javax.security.auth.login.LoginContext</code> constructor, to specify the <em>application name</em> used to
+ * select the set of relevant <code>LoginModules</code> required.
+ * </p>
+ * <p>
+ * The JAAS Specification describes the result of a successful login as a <code>javax.security.auth.Subject</code>
+ * instance, which can contain zero or more <code>java.security.Principal</code> objects in the return value of the
+ * <code>Subject.getPrincipals()</code> method. However, it provides no guidance on how to distinguish Principals that
+ * describe the individual user (and are thus appropriate to return as the value of request.getUserPrincipal() in a web
+ * application) from the Principal(s) that describe the authorized roles for this user. To maintain as much independence
+ * as possible from the underlying <code>LoginMethod</code> implementation executed by JAAS, the following policy is
+ * implemented by this Realm:
+ * </p>
  * <ul>
- * <li>The JAAS <code>LoginModule</code> is assumed to return a
- *     <code>Subject</code> with at least one <code>Principal</code> instance
- *     representing the user himself or herself, and zero or more separate
- *     <code>Principals</code> representing the security roles authorized
- *     for this user.</li>
- * <li>On the <code>Principal</code> representing the user, the Principal
- *     name is an appropriate value to return via the Servlet API method
- *     <code>HttpServletRequest.getRemoteUser()</code>.</li>
- * <li>On the <code>Principals</code> representing the security roles, the
- *     name is the name of the authorized security role.</li>
- * <li>This Realm will be configured with two lists of fully qualified Java
- *     class names of classes that implement
- *     <code>java.security.Principal</code> - one that identifies class(es)
- *     representing a user, and one that identifies class(es) representing
- *     a security role.</li>
- * <li>As this Realm iterates over the <code>Principals</code> returned by
- *     <code>Subject.getPrincipals()</code>, it will identify the first
- *     <code>Principal</code> that matches the "user classes" list as the
- *     <code>Principal</code> for this user.</li>
- * <li>As this Realm iterates over the <code>Principals</code> returned by
- *     <code>Subject.getPrincipals()</code>, it will accumulate the set of
- *     all <code>Principals</code> matching the "role classes" list as
- *     identifying the security roles for this user.</li>
- * <li>It is a configuration error for the JAAS login method to return a
- *     validated <code>Subject</code> without a <code>Principal</code> that
- *     matches the "user classes" list.</li>
- * <li>By default, the enclosing Container's name serves as the
- *     application name used to obtain the JAAS LoginContext ("Catalina" in
- *     a default installation). Tomcat must be able to find an application
- *     with this name in the JAAS configuration file. Here is a hypothetical
- *     JAAS configuration file entry for a database-oriented login module that uses
- *     a Tomcat-managed JNDI database resource:
- *     <blockquote><pre>Catalina {
-org.foobar.auth.DatabaseLoginModule REQUIRED
-    JNDI_RESOURCE=jdbc/AuthDB
-  USER_TABLE=users
-  USER_ID_COLUMN=id
-  USER_NAME_COLUMN=name
-  USER_CREDENTIAL_COLUMN=password
-  ROLE_TABLE=roles
-  ROLE_NAME_COLUMN=name
-  PRINCIPAL_FACTORY=org.foobar.auth.impl.SimplePrincipalFactory;
-};</pre></blockquote></li>
- * <li>To set the JAAS configuration file
- *     location, set the <code>CATALINA_OPTS</code> environment variable
- *     similar to the following:
-<blockquote><code>CATALINA_OPTS="-Djava.security.auth.login.config=$CATALINA_HOME/conf/jaas.config"</code></blockquote>
+ * <li>The JAAS <code>LoginModule</code> is assumed to return a <code>Subject</code> with at least one
+ * <code>Principal</code> instance representing the user himself or herself, and zero or more separate
+ * <code>Principals</code> representing the security roles authorized for this user.</li>
+ * <li>On the <code>Principal</code> representing the user, the Principal name is an appropriate value to return via the
+ * Servlet API method <code>HttpServletRequest.getRemoteUser()</code>.</li>
+ * <li>On the <code>Principals</code> representing the security roles, the name is the name of the authorized security
+ * role.</li>
+ * <li>This Realm will be configured with two lists of fully qualified Java class names of classes that implement
+ * <code>java.security.Principal</code> - one that identifies class(es) representing a user, and one that identifies
+ * class(es) representing a security role.</li>
+ * <li>As this Realm iterates over the <code>Principals</code> returned by <code>Subject.getPrincipals()</code>, it will
+ * identify the first <code>Principal</code> that matches the "user classes" list as the <code>Principal</code> for this
+ * user.</li>
+ * <li>As this Realm iterates over the <code>Principals</code> returned by <code>Subject.getPrincipals()</code>, it will
+ * accumulate the set of all <code>Principals</code> matching the "role classes" list as identifying the security roles
+ * for this user.</li>
+ * <li>It is a configuration error for the JAAS login method to return a validated <code>Subject</code> without a
+ * <code>Principal</code> that matches the "user classes" list.</li>
+ * <li>By default, the enclosing Container's name serves as the application name used to obtain the JAAS LoginContext
+ * ("Catalina" in a default installation). Tomcat must be able to find an application with this name in the JAAS
+ * configuration file. Here is a hypothetical JAAS configuration file entry for a database-oriented login module that
+ * uses a Tomcat-managed JNDI database resource: <blockquote>
+ *
+ * <pre>
+ * Catalina {
+ * org.foobar.auth.DatabaseLoginModule REQUIRED
+ *   JNDI_RESOURCE=jdbc/AuthDB
+ *   USER_TABLE=users
+ *   USER_ID_COLUMN=id
+ *   USER_NAME_COLUMN=name
+ *   USER_CREDENTIAL_COLUMN=password
+ *   ROLE_TABLE=roles
+ *   ROLE_NAME_COLUMN=name
+ *   PRINCIPAL_FACTORY=org.foobar.auth.impl.SimplePrincipalFactory;
+ * };
+ * </pre>
+ *
+ * </blockquote></li>
+ * <li>To set the JAAS configuration file location, set the <code>CATALINA_OPTS</code> environment variable similar to
+ * the following:
+ * <blockquote><code>CATALINA_OPTS="-Djava.security.auth.login.config=$CATALINA_HOME/conf/jaas.config"</code></blockquote>
  * </li>
- * <li>As part of the login process, JAASRealm registers its own <code>CallbackHandler</code>,
- *     called (unsurprisingly) <code>JAASCallbackHandler</code>. This handler supplies the
- *     HTTP requests's username and credentials to the user-supplied <code>LoginModule</code></li>
- * <li>As with other <code>Realm</code> implementations, digested passwords are supported if
- *     the <code>&lt;Realm&gt;</code> element in <code>server.xml</code> contains a
- *     <code>digest</code> attribute; <code>JAASCallbackHandler</code> will digest the password
- *     prior to passing it back to the <code>LoginModule</code></li>
+ * <li>As part of the login process, JAASRealm registers its own <code>CallbackHandler</code>, called (unsurprisingly)
+ * <code>JAASCallbackHandler</code>. This handler supplies the HTTP requests' username and credentials to the
+ * user-supplied <code>LoginModule</code></li>
+ * <li>As with other <code>Realm</code> implementations, digested passwords are supported if the
+ * <code>&lt;Realm&gt;</code> element in <code>server.xml</code> contains a <code>digest</code> attribute;
+ * <code>JAASCallbackHandler</code> will digest the password prior to passing it back to the
+ * <code>LoginModule</code></li>
  * </ul>
  *
  * @author Craig R. McClanahan
@@ -133,8 +127,8 @@ public class JAASRealm extends RealmBase {
 
 
     /**
-     * The application name passed to the JAAS <code>LoginContext</code>,
-     * which uses it to select the set of relevant <code>LoginModule</code>s.
+     * The application name passed to the JAAS <code>LoginContext</code>, which uses it to select the set of relevant
+     * <code>LoginModule</code>s.
      */
     protected String appName = null;
 
@@ -152,16 +146,14 @@ public class JAASRealm extends RealmBase {
 
 
     /**
-     * Whether to use context ClassLoader or default ClassLoader.
-     * True means use context ClassLoader, and True is the default
-     * value.
+     * Whether to use context ClassLoader or default ClassLoader. True means use context ClassLoader, and True is the
+     * default value.
      */
     protected boolean useContextClassLoader = true;
 
 
     /**
-     * Path to find a JAAS configuration file, if not set global JVM JAAS
-     * configuration will be used.
+     * Path to find a JAAS configuration file, if not set global JVM JAAS configuration will be used.
      */
     protected String configFile;
 
@@ -169,11 +161,10 @@ public class JAASRealm extends RealmBase {
     protected volatile boolean jaasConfigurationLoaded = false;
 
     /**
-     * Keeps track if JAAS invocation of login modules was successful or not. By
-     * default it is true unless we detect JAAS login module can't perform the
-     * login. This will be used for realm's {@link #isAvailable()} status so
-     * that {@link LockOutRealm} will not lock the user out if JAAS login
-     * modules are unavailable to perform the actual login.
+     * Keeps track if JAAS invocation of login modules was successful or not. By default, it is true unless we detect
+     * JAAS login module can't perform the login. This will be used for realm's {@link #isAvailable()} status so that
+     * {@link LockOutRealm} will not lock the user out if JAAS login modules are unavailable to perform the actual
+     * login.
      */
     private volatile boolean invocationSuccess = true;
 
@@ -188,6 +179,7 @@ public class JAASRealm extends RealmBase {
 
     /**
      * Set the JAAS configuration file.
+     *
      * @param configFile The JAAS configuration file
      */
     public void setConfigFile(String configFile) {
@@ -196,8 +188,8 @@ public class JAASRealm extends RealmBase {
 
     /**
      * Set the JAAS <code>LoginContext</code> app name.
-     * @param name The application name that will be used to retrieve
-     *  the set of relevant <code>LoginModule</code>s
+     *
+     * @param name The application name that will be used to retrieve the set of relevant <code>LoginModule</code>s
      */
     public void setAppName(String name) {
         appName = name;
@@ -211,8 +203,7 @@ public class JAASRealm extends RealmBase {
     }
 
     /**
-     * Sets whether to use the context or default ClassLoader.
-     * True means use context ClassLoader.
+     * Sets whether to use the context or default ClassLoader. True means use context ClassLoader.
      *
      * @param useContext True means use context ClassLoader
      */
@@ -221,8 +212,7 @@ public class JAASRealm extends RealmBase {
     }
 
     /**
-     * Returns whether to use the context or default ClassLoader.
-     * True means to use the context ClassLoader.
+     * Returns whether to use the context or default ClassLoader. True means to use the context ClassLoader.
      *
      * @return The value of useContextClassLoader
      */
@@ -241,8 +231,7 @@ public class JAASRealm extends RealmBase {
     }
 
     /**
-     * Comma-delimited list of <code>java.security.Principal</code> classes
-     * that represent security roles.
+     * Comma-delimited list of <code>java.security.Principal</code> classes that represent security roles.
      */
     protected String roleClassNames = null;
 
@@ -251,10 +240,10 @@ public class JAASRealm extends RealmBase {
     }
 
     /**
-     * Sets the list of comma-delimited classes that represent roles. The
-     * classes in the list must implement <code>java.security.Principal</code>.
-     * The supplied list of classes will be parsed when {@link #start()} is
+     * Sets the list of comma-delimited classes that represent roles. The classes in the list must implement
+     * <code>java.security.Principal</code>. The supplied list of classes will be parsed when {@link #start()} is
      * called.
+     *
      * @param roleClassNames The class names list
      */
     public void setRoleClassNames(String roleClassNames) {
@@ -262,13 +251,12 @@ public class JAASRealm extends RealmBase {
     }
 
     /**
-     * Parses a comma-delimited list of class names, and store the class names
-     * in the provided List. Each class must implement
-     * <code>java.security.Principal</code>.
+     * Parses a comma-delimited list of class names, and store the class names in the provided List. Each class must
+     * implement <code>java.security.Principal</code>.
      *
      * @param classNamesString a comma-delimited list of fully qualified class names.
-     * @param classNamesList the list in which the class names will be stored.
-     *        The list is cleared before being populated.
+     * @param classNamesList   the list in which the class names will be stored. The list is cleared before being
+     *                             populated.
      */
     protected void parseClassNames(String classNamesString, List<String> classNamesList) {
         classNamesList.clear();
@@ -283,12 +271,11 @@ public class JAASRealm extends RealmBase {
 
         String[] classNames = classNamesString.split("[ ]*,[ ]*");
         for (String className : classNames) {
-            if (className.length() == 0) {
+            if (className.isEmpty()) {
                 continue;
             }
             try {
-                Class<?> principalClass = Class.forName(className, false,
-                        loader);
+                Class<?> principalClass = Class.forName(className, false, loader);
                 if (Principal.class.isAssignableFrom(principalClass)) {
                     classNamesList.add(className);
                 } else {
@@ -301,8 +288,7 @@ public class JAASRealm extends RealmBase {
     }
 
     /**
-     * Comma-delimited list of <code>java.security.Principal</code> classes
-     * that represent individual users.
+     * Comma-delimited list of <code>java.security.Principal</code> classes that represent individual users.
      */
     protected String userClassNames = null;
 
@@ -311,10 +297,10 @@ public class JAASRealm extends RealmBase {
     }
 
     /**
-     * Sets the list of comma-delimited classes that represent individual
-     * users. The classes in the list must implement
-     * <code>java.security.Principal</code>. The supplied list of classes will
-     * be parsed when {@link #start()} is called.
+     * Sets the list of comma-delimited classes that represent individual users. The classes in the list must implement
+     * <code>java.security.Principal</code>. The supplied list of classes will be parsed when {@link #start()} is
+     * called.
+     *
      * @param userClassNames The class names list
      */
     public void setUserClassNames(String userClassNames) {
@@ -324,87 +310,56 @@ public class JAASRealm extends RealmBase {
 
     // --------------------------------------------------------- Public Methods
 
-    /**
-     * Return the <code>Principal</code> associated with the specified username
-     * and credentials, if there is one; otherwise return <code>null</code>.
-     *
-     * @param username Username of the <code>Principal</code> to look up
-     * @param credentials Password or other credentials to use in
-     *  authenticating this username
-     * @return the associated principal, or <code>null</code> if there is none.
-     */
     @Override
     public Principal authenticate(String username, String credentials) {
-        return authenticate(username,
-                new JAASCallbackHandler(this, username, credentials));
+        return authenticate(username, new JAASCallbackHandler(this, username, credentials));
     }
 
 
-    /**
-     * Return the <code>Principal</code> associated with the specified username
-     * and digest, if there is one; otherwise return <code>null</code>.
-     *
-     * @param username      Username of the <code>Principal</code> to look up
-     * @param clientDigest  Digest to use in authenticating this username
-     * @param nonce         Server generated nonce
-     * @param nc            Nonce count
-     * @param cnonce        Client generated nonce
-     * @param qop           Quality of protection applied to the message
-     * @param realmName     Realm name
-     * @param md5a2         Second MD5 digest used to calculate the digest
-     *                          MD5(Method + ":" + uri)
-     * @return the associated principal, or <code>null</code> if there is none.
-     */
     @Override
-    public Principal authenticate(String username, String clientDigest,
-            String nonce, String nc, String cnonce, String qop,
-            String realmName, String md5a2) {
-        return authenticate(username,
-                new JAASCallbackHandler(this, username, clientDigest, nonce,
-                        nc, cnonce, qop, realmName, md5a2,
-                        HttpServletRequest.DIGEST_AUTH));
+    public Principal authenticate(String username, String clientDigest, String nonce, String nc, String cnonce,
+            String qop, String realmName, String digestA2, String algorithm) {
+        return authenticate(username, new JAASCallbackHandler(this, username, clientDigest, nonce, nc, cnonce, qop,
+                realmName, digestA2, algorithm, HttpServletRequest.DIGEST_AUTH));
     }
 
 
-    // -------------------------------------------------------- Package Methods
-
-
     // ------------------------------------------------------ Protected Methods
 
-
     /**
      * Perform the actual JAAS authentication.
-     * @param username The user name
+     *
+     * @param username        The username
      * @param callbackHandler The callback handler
+     *
      * @return the associated principal, or <code>null</code> if there is none.
      */
-    protected Principal authenticate(String username,
-            CallbackHandler callbackHandler) {
+    protected Principal authenticate(String username, CallbackHandler callbackHandler) {
 
         // Establish a LoginContext to use for authentication
         try {
-            LoginContext loginContext = null;
-            if( appName==null ) {
-                appName="Tomcat";
+            if (appName == null) {
+                appName = "Tomcat";
             }
 
-            if( log.isDebugEnabled()) {
-                log.debug(sm.getString("jaasRealm.beginLogin", username, appName));
+            if (log.isTraceEnabled()) {
+                log.trace(sm.getString("jaasRealm.beginLogin", username, appName));
             }
 
             // What if the LoginModule is in the container class loader ?
             ClassLoader ocl = null;
+            Thread currentThread = null;
 
             if (!isUseContextClassLoader()) {
-                ocl = Thread.currentThread().getContextClassLoader();
-                Thread.currentThread().setContextClassLoader(
-                        this.getClass().getClassLoader());
+                currentThread = Thread.currentThread();
+                ocl = currentThread.getContextClassLoader();
+                currentThread.setContextClassLoader(this.getClass().getClassLoader());
             }
 
+            LoginContext loginContext;
             try {
                 Configuration config = getConfig();
-                loginContext = new LoginContext(
-                        appName, null, callbackHandler, config);
+                loginContext = new LoginContext(appName, null, callbackHandler, config);
             } catch (Throwable e) {
                 ExceptionUtils.handleThrowable(e);
                 log.error(sm.getString("jaasRealm.unexpectedError"), e);
@@ -413,17 +368,17 @@ public class JAASRealm extends RealmBase {
                 invocationSuccess = false;
                 return null;
             } finally {
-                if(!isUseContextClassLoader()) {
-                    Thread.currentThread().setContextClassLoader(ocl);
+                if (currentThread != null) {
+                    currentThread.setContextClassLoader(ocl);
                 }
             }
 
-            if( log.isDebugEnabled()) {
-                log.debug("Login context created " + username);
+            if (log.isTraceEnabled()) {
+                log.trace("Login context created " + username);
             }
 
             // Negotiate a login via this LoginContext
-            Subject subject = null;
+            Subject subject;
             try {
                 loginContext.login();
                 subject = loginContext.getSubject();
@@ -433,7 +388,7 @@ public class JAASRealm extends RealmBase {
                 // of the JAAS operation to keep variable consistent.
                 invocationSuccess = true;
                 if (subject == null) {
-                    if( log.isDebugEnabled()) {
+                    if (log.isDebugEnabled()) {
                         log.debug(sm.getString("jaasRealm.failedLogin", username));
                     }
                     return null;
@@ -471,30 +426,32 @@ public class JAASRealm extends RealmBase {
             } catch (Throwable e) {
                 ExceptionUtils.handleThrowable(e);
                 log.error(sm.getString("jaasRealm.unexpectedError"), e);
-                // JAAS throws exception different than LoginException so mark the
+                // JAAS throws exception different from LoginException so mark the
                 // realm as unavailable
                 invocationSuccess = false;
                 return null;
             }
 
-            if( log.isDebugEnabled()) {
-                log.debug(sm.getString("jaasRealm.loginContextCreated", username));
+            if (log.isTraceEnabled()) {
+                log.trace(sm.getString("jaasRealm.loginContextCreated", username));
             }
 
             // Return the appropriate Principal for this authenticated Subject
             Principal principal = createPrincipal(username, subject, loginContext);
             if (principal == null) {
-                log.debug(sm.getString("jaasRealm.authenticateFailure", username));
+                if (log.isDebugEnabled()) {
+                    log.debug(sm.getString("jaasRealm.authenticateFailure", username));
+                }
                 return null;
             }
-            if (log.isDebugEnabled()) {
-                log.debug(sm.getString("jaasRealm.authenticateSuccess", username, principal));
+            if (log.isTraceEnabled()) {
+                log.trace(sm.getString("jaasRealm.authenticateSuccess", username, principal));
             }
 
             return principal;
-        } catch( Throwable t) {
-            log.error( "error ", t);
-            //JAAS throws exception different than LoginException so mark the realm as unavailable
+        } catch (Throwable t) {
+            log.error(sm.getString("jaasRealm.unexpectedError"), t);
+            // JAAS throws exception different from LoginException so mark the realm as unavailable
             invocationSuccess = false;
             return null;
         }
@@ -502,9 +459,8 @@ public class JAASRealm extends RealmBase {
 
 
     /**
-     * @return the password associated with the given principal's user name. This
-     * always returns null as the JAASRealm has no way of obtaining this
-     * information.
+     * @return the password associated with the given principal's username. This always returns null as the JAASRealm
+     *             has no way of obtaining this information.
      */
     @Override
     protected String getPassword(String username) {
@@ -512,37 +468,30 @@ public class JAASRealm extends RealmBase {
     }
 
 
-    /**
-     * @return the <code>Principal</code> associated with the given user name.
-     */
     @Override
     protected Principal getPrincipal(String username) {
 
-        return authenticate(username,
-                new JAASCallbackHandler(this, username, null, null, null, null,
-                        null, null, null, HttpServletRequest.CLIENT_CERT_AUTH));
+        return authenticate(username, new JAASCallbackHandler(this, username, null, null, null, null, null, null, null,
+                null, HttpServletRequest.CLIENT_CERT_AUTH));
 
     }
 
 
     /**
-     * Identify and return a <code>java.security.Principal</code> instance
-     * representing the authenticated user for the specified <code>Subject</code>.
-     * The Principal is constructed by scanning the list of Principals returned
-     * by the JAASLoginModule. The first <code>Principal</code> object that matches
-     * one of the class names supplied as a "user class" is the user Principal.
-     * This object is returned to the caller.
-     * Any remaining principal objects returned by the LoginModules are mapped to
-     * roles, but only if their respective classes match one of the "role class" classes.
+     * Identify and return a <code>java.security.Principal</code> instance representing the authenticated user for the
+     * specified <code>Subject</code>. The Principal is constructed by scanning the list of Principals returned by the
+     * JAASLoginModule. The first <code>Principal</code> object that matches one of the class names supplied as a "user
+     * class" is the user Principal. This object is returned to the caller. Any remaining principal objects returned by
+     * the LoginModules are mapped to roles, but only if their respective classes match one of the "role class" classes.
      * If a user Principal cannot be constructed, return <code>null</code>.
-     * @param username The associated user name
-     * @param subject The <code>Subject</code> representing the logged-in user
-     * @param loginContext Associated with the Principal so
-     *                     {@link LoginContext#logout()} can be called later
+     *
+     * @param username     The associated username
+     * @param subject      The <code>Subject</code> representing the logged-in user
+     * @param loginContext Associated with the Principal so {@link LoginContext#logout()} can be called later
+     *
      * @return the principal object
      */
-    protected Principal createPrincipal(String username, Subject subject,
-            LoginContext loginContext) {
+    protected Principal createPrincipal(String username, Subject subject, LoginContext loginContext) {
         // Prepare to scan the Principals for this Subject
 
         List<String> roles = new ArrayList<>();
@@ -552,21 +501,21 @@ public class JAASRealm extends RealmBase {
         for (Principal principal : subject.getPrincipals()) {
             String principalClass = principal.getClass().getName();
 
-            if( log.isDebugEnabled() ) {
-                log.debug(sm.getString("jaasRealm.checkPrincipal", principal, principalClass));
+            if (log.isTraceEnabled()) {
+                log.trace(sm.getString("jaasRealm.checkPrincipal", principal, principalClass));
             }
 
             if (userPrincipal == null && userClasses.contains(principalClass)) {
                 userPrincipal = principal;
-                if( log.isDebugEnabled() ) {
-                    log.debug(sm.getString("jaasRealm.userPrincipalSuccess", principal.getName()));
+                if (log.isTraceEnabled()) {
+                    log.trace(sm.getString("jaasRealm.userPrincipalSuccess", principal.getName()));
                 }
             }
 
             if (roleClasses.contains(principalClass)) {
                 roles.add(principal.getName());
-                if( log.isDebugEnabled() ) {
-                    log.debug(sm.getString("jaasRealm.rolePrincipalAdd", principal.getName()));
+                if (log.isTraceEnabled()) {
+                    log.trace(sm.getString("jaasRealm.rolePrincipalAdd", principal.getName()));
                 }
             }
         }
@@ -579,7 +528,7 @@ public class JAASRealm extends RealmBase {
             }
             return null;
         } else {
-            if (roles.size() == 0) {
+            if (roles.isEmpty()) {
                 if (log.isDebugEnabled()) {
                     log.debug(sm.getString("jaasRealm.rolePrincipalFailure"));
                 }
@@ -587,30 +536,28 @@ public class JAASRealm extends RealmBase {
         }
 
         // Return the resulting Principal for our authenticated user
-        return new GenericPrincipal(username, roles, userPrincipal,
-                loginContext);
+        return new GenericPrincipal(username, roles, userPrincipal, loginContext);
     }
 
     /**
-     * Ensure the given name is legal for JAAS configuration.
-     * Added for Bugzilla 30869, made protected for easy customization
-     * in case my implementation is insufficient, which I think is
-     * very likely.
+     * Ensure the given name is legal for JAAS configuration. Added for Bugzilla 30869, made protected for easy
+     * customization in case my implementation is insufficient, which I think is very likely.
      *
      * @param src The name to validate
+     *
      * @return A string that's a valid JAAS realm name
      */
     protected String makeLegalForJAAS(final String src) {
         String result = src;
 
         // Default name is "other" per JAAS spec
-        if(result == null) {
+        if (result == null) {
             result = "other";
         }
 
         // Strip leading slash if present, as Sun JAAS impl
         // barfs on it (see Bugzilla 30869 bug report).
-        if(result.startsWith("/")) {
+        if (result.startsWith("/")) {
             result = result.substring(1);
         }
 
@@ -620,15 +567,6 @@ public class JAASRealm extends RealmBase {
 
     // ------------------------------------------------------ Lifecycle Methods
 
-
-    /**
-     * Prepare for the beginning of active use of the public methods of this
-     * component and implement the requirements of
-     * {@link org.apache.catalina.util.LifecycleBase#startInternal()}.
-     *
-     * @exception LifecycleException if this component detects a fatal error
-     *  that prevents this component from being used
-     */
     @Override
     protected void startInternal() throws LifecycleException {
 
@@ -643,6 +581,7 @@ public class JAASRealm extends RealmBase {
 
     /**
      * Load custom JAAS Configuration.
+     *
      * @return the loaded configuration
      */
     protected Configuration getConfig() {
@@ -657,22 +596,31 @@ public class JAASRealm extends RealmBase {
                     jaasConfigurationLoaded = true;
                     return null;
                 }
-                URL resource = Thread.currentThread().getContextClassLoader().getResource(configFile);
-                URI uri = resource.toURI();
                 @SuppressWarnings("unchecked")
-                Class<Configuration> sunConfigFile = (Class<Configuration>)
-                Class.forName("com.sun.security.auth.login.ConfigFile");
-                Constructor<Configuration> constructor =
-                        sunConfigFile.getConstructor(URI.class);
-                Configuration config = constructor.newInstance(uri);
+                Class<Configuration> sunConfigFile =
+                        (Class<Configuration>) Class.forName("com.sun.security.auth.login.ConfigFile");
+                Constructor<Configuration> constructor = sunConfigFile.getConstructor(URI.class);
+                URL resource = Thread.currentThread().getContextClassLoader().getResource(configFile);
+                Configuration config;
+                if (resource == null) {
+                    try (ConfigurationSource.Resource configFileResource =
+                            ConfigFileLoader.getSource().getResource(configFile)) {
+                        config = constructor.newInstance(configFileResource.getURI());
+                        this.jaasConfigurationLoaded = true;
+                    } catch (IOException ioe) {
+                        throw new RuntimeException(sm.getString("jaasRealm.configFileNotFound", configFile));
+                    }
+                } else {
+                    URI uri = resource.toURI();
+                    config = constructor.newInstance(uri);
+                    this.jaasConfigurationLoaded = true;
+                }
                 this.jaasConfiguration = config;
-                this.jaasConfigurationLoaded = true;
                 return this.jaasConfiguration;
             }
         } catch (InvocationTargetException ex) {
             throw new RuntimeException(ex.getCause());
-        } catch (SecurityException | URISyntaxException | ReflectiveOperationException |
-                IllegalArgumentException ex) {
+        } catch (SecurityException | URISyntaxException | ReflectiveOperationException | IllegalArgumentException ex) {
             throw new RuntimeException(ex);
         }
     }
