@@ -23,6 +23,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStream;
+import java.io.Serial;
 import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
 import java.nio.file.Files;
@@ -207,6 +208,7 @@ public final class CGIServlet extends HttpServlet {
 
     /* some vars below copied from Craig R. McClanahan's InvokerServlet */
 
+    @Serial
     private static final long serialVersionUID = 1L;
 
     private static final Set<String> DEFAULT_SUPER_METHODS = new HashSet<>();
@@ -419,12 +421,17 @@ public final class CGIServlet extends HttpServlet {
             Locale locale = locales.nextElement();
             log.trace("Locale: [" + locale + "]");
         }
-        Enumeration<String> params = req.getParameterNames();
-        while (params.hasMoreElements()) {
-            String param = params.nextElement();
-            for (String value : req.getParameterValues(param)) {
-                log.trace("Request Parameter: " + param + ":  [" + value + "]");
+        Enumeration<String> params;
+        try {
+            params = req.getParameterNames();
+            while (params.hasMoreElements()) {
+                String param = params.nextElement();
+                for (String value : req.getParameterValues(param)) {
+                    log.trace("Request Parameter: " + param + ":  [" + value + "]");
+                }
             }
+        } catch (IllegalStateException ise) {
+            log.trace("Request Parameters: [Invalid]");
         }
         log.trace("Protocol: [" + req.getProtocol() + "]");
         log.trace("Remote Address: [" + req.getRemoteAddr() + "]");
