@@ -22,14 +22,7 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
-import java.net.MalformedURLException;
-import java.net.URL;
 import java.nio.file.Files;
-import java.security.CodeSource;
-import java.security.Permission;
-import java.security.PermissionCollection;
-import java.security.Policy;
-import java.security.cert.Certificate;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -54,7 +47,6 @@ import javax.management.ObjectName;
 import org.apache.catalina.Container;
 import org.apache.catalina.Context;
 import org.apache.catalina.DistributedManager;
-import org.apache.catalina.Globals;
 import org.apache.catalina.Host;
 import org.apache.catalina.Lifecycle;
 import org.apache.catalina.LifecycleEvent;
@@ -62,7 +54,6 @@ import org.apache.catalina.LifecycleListener;
 import org.apache.catalina.Manager;
 import org.apache.catalina.core.StandardContext;
 import org.apache.catalina.core.StandardHost;
-import org.apache.catalina.security.DeployXmlPermission;
 import org.apache.catalina.util.ContextName;
 import org.apache.catalina.util.IOTools;
 import org.apache.juli.logging.Log;
@@ -77,6 +68,9 @@ import org.apache.tomcat.util.res.StringManager;
 /**
  * Startup event listener for a <b>Host</b> that configures the properties of that Host, and the associated defined
  * contexts.
+ *
+ * @author Craig R. McClanahan
+ * @author Remy Maucherat
  */
 public class HostConfig implements LifecycleListener {
 
@@ -201,33 +195,6 @@ public class HostConfig implements LifecycleListener {
     }
 
 
-    private boolean isDeployThisXML(File docBase, ContextName cn) {
-        boolean deployThisXML = isDeployXML();
-        if (Globals.IS_SECURITY_ENABLED && !deployThisXML) {
-            // When running under a SecurityManager, deployXML may be overridden
-            // on a per Context basis by the granting of a specific permission
-            Policy currentPolicy = Policy.getPolicy();
-            if (currentPolicy != null) {
-                URL contextRootUrl;
-                try {
-                    contextRootUrl = docBase.toURI().toURL();
-                    CodeSource cs = new CodeSource(contextRootUrl, (Certificate[]) null);
-                    PermissionCollection pc = currentPolicy.getPermissions(cs);
-                    Permission p = new DeployXmlPermission(cn.getBaseName());
-                    if (pc.implies(p)) {
-                        deployThisXML = true;
-                    }
-                } catch (MalformedURLException e) {
-                    // Should never happen
-                    log.warn(sm.getString("hostConfig.docBaseUrlInvalid"), e);
-                }
-            }
-        }
-
-        return deployThisXML;
-    }
-
-
     /**
      * @return the copy XML config file flag for this component.
      */
@@ -292,14 +259,11 @@ public class HostConfig implements LifecycleListener {
         }
 
         // Process the event that has occurred
-        if (event.getType().equals(Lifecycle.PERIODIC_EVENT)) {
-            check();
-        } else if (event.getType().equals(Lifecycle.BEFORE_START_EVENT)) {
-            beforeStart();
-        } else if (event.getType().equals(Lifecycle.START_EVENT)) {
-            start();
-        } else if (event.getType().equals(Lifecycle.STOP_EVENT)) {
-            stop();
+        switch (event.getType()) {
+            case Lifecycle.PERIODIC_EVENT -> check();
+            case Lifecycle.BEFORE_START_EVENT -> beforeStart();
+            case Lifecycle.START_EVENT -> start();
+            case Lifecycle.STOP_EVENT -> stop();
         }
     }
 
@@ -386,7 +350,7 @@ public class HostConfig implements LifecycleListener {
         }
         try {
             return file.getCanonicalFile();
-        } catch (IOException ioe) {
+        } catch (IOException e) {
             return file;
         }
     }
@@ -837,8 +801,8 @@ public class HostConfig implements LifecycleListener {
             if (entry != null) {
                 xmlInWar = true;
             }
-        } catch (IOException ignore) {
-            // Ignore
+        } catch (IOException e) {
+            /* Ignore */
         }
 
         // If there is an expanded directory then any xml in that directory
@@ -850,7 +814,7 @@ public class HostConfig implements LifecycleListener {
         // test that here
 
         Context context = null;
-        boolean deployThisXML = isDeployThisXML(war, cn);
+        boolean deployThisXML = this.deployXML;
 
         try {
             if (deployThisXML && useXml && !copyXML) {
@@ -922,8 +886,8 @@ public class HostConfig implements LifecycleListener {
                             OutputStream ostream = new FileOutputStream(xml)) {
                         IOTools.flow(istream, ostream);
                     }
-                } catch (IOException ignore) {
-                    // Ignore
+                } catch (IOException e) {
+                    /* Ignore */
                 }
             }
         }
@@ -1074,7 +1038,7 @@ public class HostConfig implements LifecycleListener {
 
         DeployedApplication deployedApp;
         boolean copyThisXml = isCopyXML();
-        boolean deployThisXML = isDeployThisXML(dir, cn);
+        boolean deployThisXML = this.deployXML;
 
         try {
             if (deployThisXML && xml.exists()) {
@@ -1547,16 +1511,16 @@ public class HostConfig implements LifecycleListener {
         String canonicalLocation;
         try {
             canonicalLocation = resource.getParentFile().getCanonicalPath();
-        } catch (IOException ioe) {
-            log.warn(sm.getString("hostConfig.canonicalizing", resource.getParentFile(), app.name), ioe);
+        } catch (IOException e) {
+            log.warn(sm.getString("hostConfig.canonicalizing", resource.getParentFile(), app.name), e);
             return false;
         }
 
         String canonicalAppBase;
         try {
             canonicalAppBase = host.getAppBaseFile().getCanonicalPath();
-        } catch (IOException ioe) {
-            log.warn(sm.getString("hostConfig.canonicalizing", host.getAppBaseFile(), app.name), ioe);
+        } catch (IOException e) {
+            log.warn(sm.getString("hostConfig.canonicalizing", host.getAppBaseFile(), app.name), e);
             return false;
         }
 
@@ -1568,8 +1532,8 @@ public class HostConfig implements LifecycleListener {
         String canonicalConfigBase;
         try {
             canonicalConfigBase = host.getConfigBaseFile().getCanonicalPath();
-        } catch (IOException ioe) {
-            log.warn(sm.getString("hostConfig.canonicalizing", host.getConfigBaseFile(), app.name), ioe);
+        } catch (IOException e) {
+            log.warn(sm.getString("hostConfig.canonicalizing", host.getConfigBaseFile(), app.name), e);
             return false;
         }
 
@@ -1860,18 +1824,7 @@ public class HostConfig implements LifecycleListener {
         public boolean loggedDirWarning = false;
     }
 
-    private static class DeployDescriptor implements Runnable {
-
-        private final HostConfig config;
-        private final ContextName cn;
-        private final File descriptor;
-
-        DeployDescriptor(HostConfig config, ContextName cn, File descriptor) {
-            this.config = config;
-            this.cn = cn;
-            this.descriptor = descriptor;
-        }
-
+    private record DeployDescriptor(HostConfig config, ContextName cn, File descriptor) implements Runnable {
         @Override
         public void run() {
             try {
@@ -1882,18 +1835,7 @@ public class HostConfig implements LifecycleListener {
         }
     }
 
-    private static class DeployWar implements Runnable {
-
-        private final HostConfig config;
-        private final ContextName cn;
-        private final File war;
-
-        DeployWar(HostConfig config, ContextName cn, File war) {
-            this.config = config;
-            this.cn = cn;
-            this.war = war;
-        }
-
+    private record DeployWar(HostConfig config, ContextName cn, File war) implements Runnable {
         @Override
         public void run() {
             try {
@@ -1904,18 +1846,7 @@ public class HostConfig implements LifecycleListener {
         }
     }
 
-    private static class DeployDirectory implements Runnable {
-
-        private final HostConfig config;
-        private final ContextName cn;
-        private final File dir;
-
-        DeployDirectory(HostConfig config, ContextName cn, File dir) {
-            this.config = config;
-            this.cn = cn;
-            this.dir = dir;
-        }
-
+    private record DeployDirectory(HostConfig config, ContextName cn, File dir) implements Runnable {
         @Override
         public void run() {
             try {
@@ -1927,20 +1858,7 @@ public class HostConfig implements LifecycleListener {
     }
 
 
-    private static class MigrateApp implements Runnable {
-
-        private final HostConfig config;
-        private final ContextName cn;
-        private final File source;
-        private final File destination;
-
-        MigrateApp(HostConfig config, ContextName cn, File source, File destination) {
-            this.config = config;
-            this.cn = cn;
-            this.source = source;
-            this.destination = destination;
-        }
-
+    private record MigrateApp(HostConfig config, ContextName cn, File source, File destination) implements Runnable {
         @Override
         public void run() {
             try {
@@ -1961,22 +1879,7 @@ public class HostConfig implements LifecycleListener {
      * The LifecycleListener approach offers greater flexibility and enables the behaviour to be changed / extended /
      * removed in future without changing the Context API.
      */
-    private static class ExpandedDirectoryRemovalListener implements LifecycleListener {
-
-        private final File toDelete;
-        private final String newDocBase;
-
-        /**
-         * Create a listener that will ensure that any expanded WAR is removed and the docBase set to the specified WAR.
-         *
-         * @param toDelete   The file (a directory representing an expanded WAR) to be deleted
-         * @param newDocBase The new docBase for the Context
-         */
-        ExpandedDirectoryRemovalListener(File toDelete, String newDocBase) {
-            this.toDelete = toDelete;
-            this.newDocBase = newDocBase;
-        }
-
+    private record ExpandedDirectoryRemovalListener(File toDelete, String newDocBase) implements LifecycleListener {
         @Override
         public void lifecycleEvent(LifecycleEvent event) {
             if (Lifecycle.AFTER_STOP_EVENT.equals(event.getType())) {
