@@ -437,19 +437,6 @@ public class MemoryUserDatabase implements UserDatabase {
     }
 
 
-    /**
-     * Check for permissions to save this user database to persistent storage location.
-     *
-     * @return <code>true</code> if the database is writable
-     *
-     * @deprecated Use {@link #isWritable()}. This method will be removed in Tomcat 10.1.x onwards.
-     */
-    @Deprecated
-    public boolean isWriteable() {
-        return isWritable();
-    }
-
-
     /**
      * Check for permissions to save this user database to persistent storage location.
      *
@@ -573,11 +560,11 @@ public class MemoryUserDatabase implements UserDatabase {
                 if (writer.checkError()) {
                     throw new IOException(sm.getString("memoryUserDatabase.writeException", fileNew.getAbsolutePath()));
                 }
-            } catch (IOException ioe) {
+            } catch (IOException e) {
                 if (fileNew.exists() && !fileNew.delete()) {
                     log.warn(sm.getString("memoryUserDatabase.fileDelete", fileNew));
                 }
-                throw ioe;
+                throw e;
             }
             this.lastModified = fileNew.lastModified();
         } finally {
@@ -643,8 +630,8 @@ public class MemoryUserDatabase implements UserDatabase {
                     writeLock.unlock();
                 }
             }
-        } catch (Exception e) {
-            log.error(sm.getString("memoryUserDatabase.reloadError", id, uri), e);
+        } catch (Exception ioe) {
+            log.error(sm.getString("memoryUserDatabase.reloadError", id, uri), ioe);
         } finally {
             if (uConn != null) {
                 try {
@@ -665,8 +652,8 @@ public class MemoryUserDatabase implements UserDatabase {
 
     @Override
     public String toString() {
-        return "MemoryUserDatabase[id=" + this.id + ",pathname=" + pathname + ",groupCount=" + this.groups.size() +
-                ",roleCount=" + this.roles.size() + ",userCount=" + this.users.size() + ']';
+        return "MemoryUserDatabase[id=" + this.id + ",pathname=" + pathname + ",groupCount=" +
+                this.groups.size() + ",roleCount=" + this.roles.size() + ",userCount=" + this.users.size() + ']';
     }
 }
 
