@@ -21,7 +21,6 @@ import java.io.CharArrayWriter;
 import java.io.IOException;
 import java.net.InetAddress;
 import java.text.SimpleDateFormat;
-import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.Enumeration;
@@ -132,7 +131,10 @@ import org.apache.tomcat.util.net.IPv6Utils;
  * For extended attributes coming from a getAttribute() call, it is you responsibility to ensure there are no newline or
  * control characters.
  * </p>
+ *
+ * @author Craig R. McClanahan
  * @author Jason Brittain
+ * @author Remy Maucherat
  * @author Takayuki Kaneko
  * @author Peter Rossbach
  */
@@ -673,13 +675,16 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
             return;
         }
 
+        // Date for access log should be the beginning of the request
+        Date date = getDate(request.getCoyoteRequest().getStartTime());
+
         CharArrayWriter result = charArrayWriters.pop();
         if (result == null) {
             result = new CharArrayWriter(128);
         }
 
         for (AccessLogElement logElement : logElements) {
-            logElement.addElement(result, request, response, time);
+            logElement.addElement(result, date, request, response, time);
         }
 
         log(result);
@@ -742,42 +747,9 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
 
     /**
      * AccessLogElement writes the partial message into the buffer.
-     * <p>
-     * At least one method must be implemented else a loop will occur.
-     * <p>
-     * When the deprecated method is removed in Tomcat 12, the default implementation for
-     * {@link #addElement(CharArrayWriter, Request, Response, long)} will also be removed.
      */
     protected interface AccessLogElement {
-        /**
-         * Called to create an access log entry.
-         *
-         * @param buf      The buffer to which the log element should be added
-         * @param date     The time stamp for the start of the request
-         * @param request  The request that triggered this access log entry
-         * @param response The response to the request that triggered this access log entry
-         * @param time     The time taken in nanoseconds to process the request
-         *
-         * @deprecated Unused. Will be removed in Tomcat 12. Use
-         *                 {@link #addElement(CharArrayWriter, Request, Response, long)}
-         */
-        @Deprecated
-        default void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
-            addElement(buf, request, response, time);
-        }
-
-        /**
-         * Called to create an access log entry.
-         *
-         * @param buf      The buffer to which the log element should be added
-         * @param request  The request that triggered this access log entry
-         * @param response The response to the request that triggered this access log entry
-         * @param time     The time taken in nanoseconds to process the request
-         */
-        default void addElement(CharArrayWriter buf, Request request, Response response, long time) {
-            Date date = getDate(request.getCoyoteRequest().getStartTime());
-            addElement(buf, date, request, response, time);
-        }
+        void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time);
     }
 
     /**
@@ -796,7 +768,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class ThreadNameElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             RequestInfo info = request.getCoyoteRequest().getRequestProcessor();
             if (info != null) {
                 buf.append(info.getWorkerThreadName());
@@ -817,8 +789,8 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
             String init;
             try {
                 init = InetAddress.getLocalHost().getHostAddress();
-            } catch (Throwable t) {
-                ExceptionUtils.handleThrowable(t);
+            } catch (Throwable e) {
+                ExceptionUtils.handleThrowable(e);
                 init = "127.0.0.1";
             }
 
@@ -830,7 +802,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             buf.append(localAddrValue);
         }
     }
@@ -867,7 +839,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             String value = null;
             if (remoteAddressType == RemoteAddressType.PEER) {
                 value = request.getPeerAddr();
@@ -907,7 +879,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected class HostElement implements AccessLogElement, CachedElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             String value = null;
             if (requestAttributesEnabled) {
                 Object host = request.getAttribute(REMOTE_HOST_ATTRIBUTE);
@@ -915,10 +887,10 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
                     value = host.toString();
                 }
             }
-            if (value == null || value.length() == 0) {
+            if (value == null || value.isEmpty()) {
                 value = request.getRemoteHost();
             }
-            if (value == null || value.length() == 0) {
+            if (value == null || value.isEmpty()) {
                 value = "-";
             }
 
@@ -941,7 +913,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class LogicalUserNameElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             buf.append('-');
         }
     }
@@ -951,7 +923,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected class ProtocolElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             if (requestAttributesEnabled) {
                 Object proto = request.getAttribute(PROTOCOL_ATTRIBUTE);
                 if (proto == null) {
@@ -970,7 +942,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class UserElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             if (request != null) {
                 String value = request.getRemoteUser();
                 if (value != null) {
@@ -1094,7 +1066,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
                     usesBegin = false;
                     format = format.substring(4);
                 }
-                if (format.length() == 0) {
+                if (format.isEmpty()) {
                     type = FormatType.CLF;
                 } else if (format.equals(secFormat)) {
                     type = FormatType.SEC;
@@ -1113,58 +1085,53 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
-            Instant requestStartInstant = Instant.from(request.getCoyoteRequest().getStartInstant());
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
+            long timestamp = date.getTime();
             long frac;
             if (!usesBegin) {
-                requestStartInstant.plusNanos(time);
+                timestamp += TimeUnit.NANOSECONDS.toMillis(time);
             }
-            /*
-             * Implementation note: This is deliberately not implemented using switch. If a switch is used the compiler
-             * (at least the Oracle one) will use a synthetic class to implement the switch. The problem is that this
-             * class needs to be pre-loaded when using a SecurityManager and the name of that class will depend on any
-             * anonymous inner classes and any other synthetic classes. As such the name is not constant and keeping the
-             * pre-loading up to date as the name changes is error prone.
-             */
-            if (type == FormatType.CLF) {
-                buf.append(localDateCache.get().getFormat(requestStartInstant.toEpochMilli()));
-            } else if (type == FormatType.SEC) {
-                buf.append(Long.toString(requestStartInstant.getEpochSecond()));
-            } else if (type == FormatType.MSEC) {
-                buf.append(Long.toString(requestStartInstant.toEpochMilli()));
-            } else if (type == FormatType.MSEC_FRAC) {
-                frac = requestStartInstant.toEpochMilli() % 1000;
-                if (frac < 100) {
-                    if (frac < 10) {
-                        buf.append('0');
-                        buf.append('0');
-                    } else {
-                        buf.append('0');
-                    }
-                }
-                buf.append(Long.toString(frac));
-            } else {
-                // FormatType.SDF
-                long timestamp = requestStartInstant.toEpochMilli();
-                String temp = localDateCache.get().getFormat(format, locale, timestamp);
-                if (usesMsecs) {
+            switch (type) {
+                case CLF:
+                    buf.append(localDateCache.get().getFormat(timestamp));
+                    break;
+                case SEC:
+                    buf.append(Long.toString(timestamp / 1000));
+                    break;
+                case MSEC:
+                    buf.append(Long.toString(timestamp));
+                    break;
+                case MSEC_FRAC:
                     frac = timestamp % 1000;
-                    StringBuilder tripleMsec = new StringBuilder(4);
                     if (frac < 100) {
-                        tripleMsec.append('0');
+                        buf.append('0');
                         if (frac < 10) {
-                            tripleMsec.append('0');
+                            buf.append('0');
                         }
                     }
-                    tripleMsec.append(frac);
-                    temp = temp.replace(tripleMsecPattern, tripleMsec);
-                    temp = temp.replace(msecPattern, Long.toString(frac));
-                }
-                if (needsEscaping) {
-                    escapeAndAppend(temp, buf);
-                } else {
-                    buf.append(temp);
-                }
+                    buf.append(Long.toString(frac));
+                    break;
+                case SDF:
+                    String temp = localDateCache.get().getFormat(format, locale, timestamp);
+                    if (usesMsecs) {
+                        frac = timestamp % 1000;
+                        StringBuilder tripleMsec = new StringBuilder(4);
+                        if (frac < 100) {
+                            tripleMsec.append('0');
+                            if (frac < 10) {
+                                tripleMsec.append('0');
+                            }
+                        }
+                        tripleMsec.append(frac);
+                        temp = temp.replace(tripleMsecPattern, tripleMsec);
+                        temp = temp.replace(msecPattern, Long.toString(frac));
+                    }
+                    if (needsEscaping) {
+                        escapeAndAppend(temp, buf);
+                    } else {
+                        buf.append(temp);
+                    }
+                    break;
             }
         }
     }
@@ -1174,7 +1141,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class RequestElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             if (request != null) {
                 String method = request.getMethod();
                 if (method == null) {
@@ -1202,7 +1169,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class HttpStatusCodeElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             if (response != null) {
                 // This approach is used to reduce GC from toString conversion
                 int status = response.getStatus();
@@ -1251,7 +1218,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             if (requestAttributesEnabled && portType == PortType.LOCAL) {
                 Object port = request.getAttribute(SERVER_PORT_ATTRIBUTE);
                 if (port == null) {
@@ -1290,7 +1257,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             // Don't need to flush since trigger for log message is after the
             // response has been committed
             long length = response.getBytesWritten(false);
@@ -1318,7 +1285,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class MethodElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             if (request != null) {
                 buf.append(request.getMethod());
             }
@@ -1398,7 +1365,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             style.append(buf, time);
         }
     }
@@ -1408,7 +1375,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class FirstByteTimeElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             long commitTime = response.getCoyoteResponse().getCommitTimeNanos();
             if (commitTime == -1) {
                 buf.append('-');
@@ -1424,7 +1391,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class QueryElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             String query = null;
             if (request != null) {
                 query = request.getQueryString();
@@ -1441,7 +1408,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class SessionIdElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             if (request == null) {
                 buf.append('-');
             } else {
@@ -1460,7 +1427,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class RequestURIElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             if (request != null) {
                 buf.append(request.getRequestURI());
             } else {
@@ -1474,7 +1441,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected class LocalServerNameElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             String value = null;
             if (requestAttributesEnabled) {
                 Object serverName = request.getAttribute(SERVER_NAME_ATTRIBUTE);
@@ -1482,10 +1449,10 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
                     value = serverName.toString();
                 }
             }
-            if (value == null || value.length() == 0) {
+            if (value == null || value.isEmpty()) {
                 value = request.getServerName();
             }
-            if (value == null || value.length() == 0) {
+            if (value == null || value.isEmpty()) {
                 value = "-";
             }
 
@@ -1507,7 +1474,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             buf.append(str);
         }
     }
@@ -1523,7 +1490,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             Enumeration<String> iter = request.getHeaders(header);
             if (iter.hasMoreElements()) {
                 escapeAndAppend(iter.nextElement(), buf);
@@ -1548,7 +1515,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             StringBuilder value = null;
             boolean first = true;
             Cookie[] cookies = request.getCookies();
@@ -1586,7 +1553,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             if (null != response) {
                 Iterator<String> iter = response.getHeaders(header).iterator();
                 if (iter.hasNext()) {
@@ -1613,7 +1580,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             Object value = null;
             if (request != null) {
                 value = request.getAttribute(attribute);
@@ -1643,7 +1610,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             Object value = null;
             if (null != request) {
                 HttpSession sess = request.getSession(false);
@@ -1670,7 +1637,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      */
     protected static class ConnectionStatusElement implements AccessLogElement {
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
             if (response != null && request != null) {
                 boolean statusFound = false;
 
@@ -1708,6 +1675,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
     }
 
 
+
     /**
      * Write identifier element %{xxx}L
      */
@@ -1736,8 +1704,8 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         }
 
         @Override
-        public void addElement(CharArrayWriter buf, Request request, Response response, long time) {
-            switch (identifierType) {
+        public void addElement(CharArrayWriter buf, Date date, Request request, Response response, long time) {
+            switch(identifierType) {
                 case CONNECTION:
                     buf.append(request.getServletConnection().getConnectionId());
                     break;
@@ -1792,7 +1760,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
                 buf.append(ch);
             }
         }
-        if (buf.length() > 0) {
+        if (!buf.isEmpty()) {
             list.add(new StringElement(buf.toString()));
         }
         return list.toArray(new AccessLogElement[0]);
