@@ -154,18 +154,15 @@ public class RewriteValve extends ValveBase {
 
         InputStream is = null;
 
-        // Process configuration file for this valve
         // Process configuration file for this valve
         if (getContainer() instanceof Context) {
             context = true;
             String webInfResourcePath = "/WEB-INF/" + resourcePath;
             is = ((Context) getContainer()).getServletContext().getResourceAsStream(webInfResourcePath);
-            if (is == null) {
-                if (containerLog.isInfoEnabled()) {
-                    containerLog.info(sm.getString("rewriteValve.noConfiguration", webInfResourcePath));
-                }
-            } else {
-                if (containerLog.isDebugEnabled()) {
+            if (containerLog.isDebugEnabled()) {
+                if (is == null) {
+                    containerLog.debug(sm.getString("rewriteValve.noConfiguration", webInfResourcePath));
+                } else {
                     containerLog.debug(sm.getString("rewriteValve.readConfiguration", webInfResourcePath));
                 }
             }
@@ -174,9 +171,9 @@ public class RewriteValve extends ValveBase {
             try {
                 ConfigurationSource.Resource resource = ConfigFileLoader.getSource().getResource(resourceName);
                 is = resource.getInputStream();
-            } catch (IOException ioe) {
-                if (containerLog.isInfoEnabled()) {
-                    containerLog.info(sm.getString("rewriteValve.noConfiguration", resourceName), ioe);
+            } catch (IOException e) {
+                if (containerLog.isDebugEnabled()) {
+                    containerLog.debug(sm.getString("rewriteValve.noConfiguration", resourceName), e);
                 }
             }
         }
@@ -194,8 +191,8 @@ public class RewriteValve extends ValveBase {
         } finally {
             try {
                 is.close();
-            } catch (IOException ioe) {
-                containerLog.error(sm.getString("rewriteValve.closeError"), ioe);
+            } catch (IOException e) {
+                containerLog.error(sm.getString("rewriteValve.closeError"), e);
             }
         }
 
@@ -242,8 +239,7 @@ public class RewriteValve extends ValveBase {
                     break;
                 }
                 Object result = parse(line);
-                if (result instanceof RewriteRule) {
-                    RewriteRule rule = (RewriteRule) result;
+                if (result instanceof RewriteRule rule) {
                     if (containerLog.isTraceEnabled()) {
                         containerLog.trace("Add rule with pattern " + rule.getPatternString() + " and substitution " +
                                 rule.getSubstitutionString());
@@ -256,7 +252,7 @@ public class RewriteValve extends ValveBase {
                     for (RewriteCond condition : conditions) {
                         if (containerLog.isTraceEnabled()) {
                             containerLog.trace("Add condition " + condition.getCondPattern() + " test " +
-                                    condition.getTestString() + " to rule with pattern " + rule.getPatternString() +
+                                condition.getTestString() + " to rule with pattern " + rule.getPatternString() +
                                     " and substitution " + rule.getSubstitutionString() +
                                     (condition.isOrnext() ? " [OR]" : "") + (condition.isNocase() ? " [NC]" : ""));
                         }
@@ -277,8 +273,8 @@ public class RewriteValve extends ValveBase {
                         ((Lifecycle) map).start();
                     }
                 }
-            } catch (IOException ioe) {
-                containerLog.error(sm.getString("rewriteValve.readError"), ioe);
+            } catch (IOException e) {
+                containerLog.error(sm.getString("rewriteValve.readError"), e);
             }
         }
         this.mapsConfiguration = mapsConfiguration;
@@ -323,13 +319,13 @@ public class RewriteValve extends ValveBase {
 
         try {
 
-            Resolver resolver = new ResolverImpl(request, containerLog);
+            Resolver resolver = new ResolverImpl(request);
 
             invoked.set(Boolean.TRUE);
 
             // As long as MB isn't a char sequence or affiliated, this has to be converted to a string
             Charset uriCharset = request.getConnector().getURICharset();
-            String queryStringOriginalEncoded = request.getQueryString();
+            String originalQueryStringEncoded = request.getQueryString();
             MessageBytes urlMB = context ? request.getRequestPathMB() : request.getDecodedRequestURIMB();
             urlMB.toChars();
             CharSequence urlDecoded = urlMB.getCharChunk();
@@ -430,10 +426,10 @@ public class RewriteValve extends ValveBase {
                     StringBuilder urlStringEncoded =
                             new StringBuilder(REWRITE_DEFAULT_ENCODER.encode(urlStringRewriteEncoded, uriCharset));
 
-                    if (!qsd && queryStringOriginalEncoded != null && !queryStringOriginalEncoded.isEmpty()) {
+                    if (!qsd && originalQueryStringEncoded != null && !originalQueryStringEncoded.isEmpty()) {
                         if (rewrittenQueryStringRewriteEncoded == null) {
                             urlStringEncoded.append('?');
-                            urlStringEncoded.append(queryStringOriginalEncoded);
+                            urlStringEncoded.append(originalQueryStringEncoded);
                         } else {
                             if (qsa) {
                                 // if qsa is specified append the query
@@ -441,7 +437,7 @@ public class RewriteValve extends ValveBase {
                                 urlStringEncoded.append(
                                         REWRITE_QUERY_ENCODER.encode(rewrittenQueryStringRewriteEncoded, uriCharset));
                                 urlStringEncoded.append('&');
-                                urlStringEncoded.append(queryStringOriginalEncoded);
+                                urlStringEncoded.append(originalQueryStringEncoded);
                             } else if (index == urlStringEncoded.length() - 1) {
                                 // if the ? is the last character delete it, its only purpose was to
                                 // prevent the rewrite module from appending the query string
@@ -540,8 +536,7 @@ public class RewriteValve extends ValveBase {
                         urlStringRewriteEncoded = urlStringRewriteEncoded.substring(0, queryIndex);
                     }
                     // Parse path parameters from rewrite production and populate request path parameters
-                    urlStringRewriteEncoded =
-                            org.apache.catalina.util.RequestUtil.stripPathParams(urlStringRewriteEncoded, request);
+                    urlStringRewriteEncoded = org.apache.catalina.util.RequestUtil.stripPathParams(urlStringRewriteEncoded, request);
                     // Save the current context path before re-writing starts
                     String contextPath = null;
                     if (context) {
@@ -557,31 +552,24 @@ public class RewriteValve extends ValveBase {
 
                     // Step 3. Complete the 2nd stage to encoding.
                     chunk.append(REWRITE_DEFAULT_ENCODER.encode(urlStringRewriteEncoded, uriCharset));
-                    // Rewriting may have denormalized the URL and added encoded characters
-                    // Decode then normalize
-                    String urlStringRewriteDecoded = URLDecoder.decode(urlStringRewriteEncoded, uriCharset);
-                    urlStringRewriteDecoded = RequestUtil.normalize(urlStringRewriteDecoded);
+                    // Decoded and normalized URI
+                    // Rewriting may have denormalized the URL
+                    urlStringRewriteEncoded = RequestUtil.normalize(urlStringRewriteEncoded);
                     request.getCoyoteRequest().decodedURI().setChars(MessageBytes.EMPTY_CHAR_ARRAY, 0, 0);
                     chunk = request.getCoyoteRequest().decodedURI().getCharChunk();
                     if (context) {
                         // This is decoded and normalized
                         chunk.append(request.getServletContext().getContextPath());
                     }
-                    chunk.append(urlStringRewriteDecoded);
-                    // Set the new Query String
-                    if (queryStringRewriteEncoded == null) {
-                         // No new query string. Therefore the original is retained unless QSD is defined.
-                        if (qsd) {
-                            request.getCoyoteRequest().queryString().setChars(MessageBytes.EMPTY_CHAR_ARRAY, 0, 0);
-                        }
-                    } else {
-                        // New query string. Therefore the original is dropped unless QSA is defined (and QSD is not).
+                    chunk.append(URLDecoder.decode(urlStringRewriteEncoded, uriCharset));
+                    // Set the new Query if there is one
+                    if (queryStringRewriteEncoded != null) {
                         request.getCoyoteRequest().queryString().setChars(MessageBytes.EMPTY_CHAR_ARRAY, 0, 0);
                         chunk = request.getCoyoteRequest().queryString().getCharChunk();
                         chunk.append(REWRITE_QUERY_ENCODER.encode(queryStringRewriteEncoded, uriCharset));
-                        if (qsa && queryStringOriginalEncoded != null && !queryStringOriginalEncoded.isEmpty()) {
+                        if (qsa && originalQueryStringEncoded != null && !originalQueryStringEncoded.isEmpty()) {
                             chunk.append('&');
-                            chunk.append(queryStringOriginalEncoded);
+                            chunk.append(originalQueryStringEncoded);
                         }
                     }
                     // Set the new host if it changed
@@ -676,10 +664,6 @@ public class RewriteValve extends ValveBase {
                     while (flagsTokenizer.hasMoreElements()) {
                         parseRuleFlag(line, rule, flagsTokenizer.nextToken());
                     }
-                    // If QSD and QSA are present, QSD always takes precedence
-                    if (rule.isQsdiscard()) {
-                        rule.setQsappend(false);
-                    }
                 }
                 return rule;
             } else if (token.equals("RewriteMap")) {
@@ -841,20 +825,12 @@ public class RewriteValve extends ValveBase {
                 } else if (flag.startsWith("R=")) {
                     flag = flag.substring("R=".length());
                 }
-                switch (flag) {
-                    case "temp":
-                        redirectCode = HttpServletResponse.SC_FOUND;
-                        break;
-                    case "permanent":
-                        redirectCode = HttpServletResponse.SC_MOVED_PERMANENTLY;
-                        break;
-                    case "seeother":
-                        redirectCode = HttpServletResponse.SC_SEE_OTHER;
-                        break;
-                    default:
-                        redirectCode = Integer.parseInt(flag);
-                        break;
-                }
+                redirectCode = switch (flag) {
+                    case "temp" -> HttpServletResponse.SC_FOUND;
+                    case "permanent" -> HttpServletResponse.SC_MOVED_PERMANENTLY;
+                    case "seeother" -> HttpServletResponse.SC_SEE_OTHER;
+                    default -> Integer.parseInt(flag);
+                };
             }
             rule.setRedirectCode(redirectCode);
         } else if (flag.startsWith("skip") || flag.startsWith("S")) {
