@@ -25,6 +25,7 @@ import java.nio.file.StandardCopyOption;
 import java.util.HashMap;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.jar.Manifest;
 
@@ -46,8 +47,8 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
 
     private static final Log log = LogFactory.getLog(DirResourceSet.class);
 
-    private Map<String,ResourceLock> resourceLocksByPath = new HashMap<>();
-    private Object resourceLocksByPathLock = new Object();
+    private final Map<String,ResourceLock> resourceLocksByPath = new HashMap<>();
+    private final Object resourceLocksByPathLock = new Object();
 
 
     /**
@@ -102,7 +103,7 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
         String webAppMount = getWebAppMount();
         WebResourceRoot root = getRoot();
         boolean readOnly = isReadOnly();
-        if (path.startsWith(webAppMount)) {
+        if (isPathMounted(path, webAppMount)) {
             /*
              * Lock the path for reading until the WebResource has been constructed. The lock prevents concurrent reads
              * and writes (e.g. HTTP GET and PUT / DELETE) for the same path causing corruption of the FileResource
@@ -136,17 +137,13 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
     public String[] list(String path) {
         checkPath(path);
         String webAppMount = getWebAppMount();
-        if (path.startsWith(webAppMount)) {
+        if (isPathMounted(path, webAppMount)) {
             File f = file(path.substring(webAppMount.length()), true);
             if (f == null) {
                 return EMPTY_STRING_ARRAY;
             }
             String[] result = f.list();
-            if (result == null) {
-                return EMPTY_STRING_ARRAY;
-            } else {
-                return result;
-            }
+            return Objects.requireNonNullElse(result, EMPTY_STRING_ARRAY);
         } else {
             if (!path.endsWith("/")) {
                 path = path + "/";
@@ -168,15 +165,16 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
         checkPath(path);
         String webAppMount = getWebAppMount();
         ResourceSet<String> result = new ResourceSet<>();
-        if (path.startsWith(webAppMount)) {
+        if (isPathMounted(path, webAppMount)) {
             File f = file(path.substring(webAppMount.length()), true);
             if (f != null) {
                 File[] list = f.listFiles();
                 if (list != null) {
+                    String fCanPath = null;
                     for (File entry : list) {
                         // f has already been validated so the following checks
                         // can be much simpler than those in file()
-                        if (!getRoot().getAllowLinking()) {
+                        if (!getAllowLinking()) {
                             // allow linking is disabled so need to check for
                             // symlinks
                             boolean symlink = true;
@@ -190,7 +188,9 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
                                 // that what is left does not contain a symlink.
                                 absPath = entry.getAbsolutePath().substring(f.getAbsolutePath().length());
                                 String entryCanPath = entry.getCanonicalPath();
-                                String fCanPath = f.getCanonicalPath();
+                                if (fCanPath == null) {
+                                    fCanPath = f.getCanonicalPath();
+                                }
                                 if (entryCanPath.length() >= fCanPath.length()) {
                                     canPath = entryCanPath.substring(fCanPath.length());
                                     if (absPath.equals(canPath)) {
@@ -242,7 +242,7 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
             return false;
         }
         String webAppMount = getWebAppMount();
-        if (path.startsWith(webAppMount)) {
+        if (isPathMounted(path, webAppMount)) {
             File f = file(path.substring(webAppMount.length()), false);
             if (f == null) {
                 return false;
@@ -272,11 +272,11 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
         }
 
         String webAppMount = getWebAppMount();
-        if (!path.startsWith(webAppMount)) {
+        if (!isPathMounted(path, webAppMount)) {
             return false;
         }
 
-        File dest = null;
+        File dest;
         /*
          * Lock the path for writing until the write is complete. The lock prevents concurrent reads and writes (e.g.
          * HTTP GET and PUT / DELETE) for the same path causing corruption of the FileResource where some of the fields
@@ -311,7 +311,7 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
 
     @Override
     protected void checkType(File file) {
-        if (file.isDirectory() == false) {
+        if (!file.isDirectory()) {
             throw new IllegalArgumentException(
                     sm.getString("dirResourceSet.notDirectory", getBase(), File.separator, getInternalPath()));
         }
@@ -322,7 +322,7 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
     protected void initInternal() throws LifecycleException {
         super.initInternal();
         // Is this an exploded web application?
-        if (getWebAppMount().equals("")) {
+        if (getWebAppMount().isEmpty()) {
             // Look for a manifest
             File mf = file("META-INF/MANIFEST.MF", true);
             if (mf != null && mf.isFile()) {
@@ -376,7 +376,7 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
     @Override
     public ResourceLock lockForRead(String path) {
         String key = getLockKey(path);
-        ResourceLock resourceLock = null;
+        ResourceLock resourceLock;
         synchronized (resourceLocksByPathLock) {
             /*
              * Obtain the ResourceLock and increment the usage count inside the sync to ensure that that map always has
@@ -414,7 +414,7 @@ public class DirResourceSet extends AbstractFileResourceSet implements WebResour
     @Override
     public ResourceLock lockForWrite(String path) {
         String key = getLockKey(path);
-        ResourceLock resourceLock = null;
+        ResourceLock resourceLock;
         synchronized (resourceLocksByPathLock) {
             /*
              * Obtain the ResourceLock and increment the usage count inside the sync to ensure that that map always has
