@@ -133,7 +133,6 @@ public class Http2AsyncUpgradeHandler extends Http2UpgradeHandler {
                     se.getError(), se.getMessage()));
         }
 
-        // Treat a sent reset like a received reset and increment the overhead count
         increaseOverheadCount(FrameType.RST, getProtocol().getOverheadResetFactor());
 
         // Write a RST frame
@@ -199,12 +198,11 @@ public class Http2AsyncUpgradeHandler extends Http2UpgradeHandler {
 
 
     @Override
-    void writeHeaders(Stream stream, int pushedStreamId, MimeHeaders mimeHeaders, boolean endOfStream, int payloadSize)
-            throws IOException {
+    void writeHeaders(Stream stream, MimeHeaders mimeHeaders, boolean endOfStream, int payloadSize) throws IOException {
         headerWriteLock.lock();
         try {
-            AsyncHeaderFrameBuffers headerFrameBuffers = (AsyncHeaderFrameBuffers) doWriteHeaders(stream,
-                    pushedStreamId, mimeHeaders, endOfStream, payloadSize);
+            AsyncHeaderFrameBuffers headerFrameBuffers =
+                    (AsyncHeaderFrameBuffers) doWriteHeaders(stream, mimeHeaders, endOfStream, payloadSize);
             if (headerFrameBuffers != null) {
                 socketWrapper.write(BlockingMode.SEMI_BLOCK, protocol.getWriteTimeout(), TimeUnit.MILLISECONDS, null,
                         SocketWrapperBase.COMPLETE_WRITE, applicationErrorCompletion,
@@ -339,7 +337,7 @@ public class Http2AsyncUpgradeHandler extends Http2UpgradeHandler {
                         (int) (sendfile.end - sendfile.pos);
                 sendfile.streamReservation = sendfile.stream.reserveWindowSize(reservation, true);
                 sendfile.connectionReservation = reserveWindowSize(sendfile.stream, sendfile.streamReservation, true);
-            } catch (IOException ioe) {
+            } catch (IOException e) {
                 return SendfileState.ERROR;
             }
 
@@ -376,7 +374,7 @@ public class Http2AsyncUpgradeHandler extends Http2UpgradeHandler {
                         ByteBuffer.wrap(header), sendfile.mappedBuffer);
                 try {
                     handleAsyncException();
-                } catch (IOException ioe) {
+                } catch (IOException e) {
                     return SendfileState.ERROR;
                 }
             }
@@ -401,8 +399,8 @@ public class Http2AsyncUpgradeHandler extends Http2UpgradeHandler {
                 if (sendfile.left == 0) {
                     try {
                         sendfile.stream.getOutputBuffer().end();
-                    } catch (IOException ioe) {
-                        failed(ioe, sendfile);
+                    } catch (IOException e) {
+                        failed(e, sendfile);
                     }
                     return;
                 }
@@ -419,8 +417,8 @@ public class Http2AsyncUpgradeHandler extends Http2UpgradeHandler {
                         sendfile.connectionReservation =
                                 reserveWindowSize(sendfile.stream, sendfile.streamReservation, true);
                     }
-                } catch (IOException ioe) {
-                    failed(ioe, sendfile);
+                } catch (IOException e) {
+                    failed(e, sendfile);
                     return;
                 }
 
@@ -461,8 +459,8 @@ public class Http2AsyncUpgradeHandler extends Http2UpgradeHandler {
                             ByteBuffer.wrap(header), sendfile.mappedBuffer);
                     try {
                         handleAsyncException();
-                    } catch (IOException ioe) {
-                        failed(ioe, sendfile);
+                    } catch (IOException e) {
+                        failed(e, sendfile);
                         return;
                     }
                 }
