@@ -58,23 +58,6 @@ class Http2Parser {
     }
 
 
-    /**
-     * Read and process a single frame. Once the start of a frame is read, the remainder will be read using blocking IO.
-     *
-     * @param block Should this method block until a frame is available if no frame is available immediately?
-     *
-     * @return <code>true</code> if a frame was read otherwise <code>false</code>
-     *
-     * @throws IOException If an IO error occurs while trying to read a frame
-     *
-     * @deprecated Unused. Will be removed in Tomcat 11 onwards.
-     */
-    @Deprecated
-    boolean readFrame(boolean block) throws Http2Exception, IOException {
-        return readFrame(block, null);
-    }
-
-
     /**
      * Read and process a single frame. The initial read is non-blocking to determine if a frame is present. Once the
      * start of a frame is read, the remainder will be read using blocking IO.
