@@ -46,6 +46,12 @@ import org.apache.tomcat.util.descriptor.tld.TldResourcePath;
  * A placeholder for various things that are used throughout the JSP engine. This is a per-request/per-context data
  * structure. Some of the instance variables are set at different points. Most of the path-related stuff is here -
  * mangling names, versions, dirs, loading resources and dealing with uris.
+ *
+ * @author Anil K. Vijendran
+ * @author Harish Prabandham
+ * @author Pierre Delisle
+ * @author Costin Manolache
+ * @author Kin-man Chung
  */
 public class JspCompilationContext {
 
@@ -167,8 +173,7 @@ public class JspCompilationContext {
 
     public ClassLoader getJspLoader() {
         if (jspLoader == null) {
-            jspLoader = new JasperLoader(new URL[] { baseUrl }, getClassLoader(), basePackageName,
-                    rctxt.getPermissionCollection());
+            jspLoader = new JasperLoader(new URL[] { baseUrl }, getClassLoader(), basePackageName);
         }
         return jspLoader;
     }
@@ -386,17 +391,17 @@ public class JspCompilationContext {
                     result = uc.getLastModified();
                 }
             }
-        } catch (IOException ioe) {
+        } catch (IOException e) {
             if (log.isDebugEnabled()) {
-                log.debug(Localizer.getMessage("jsp.error.lastModified", getJspFile()), ioe);
+                log.debug(Localizer.getMessage("jsp.error.lastModified", getJspFile()), e);
             }
         } finally {
             if (uc != null) {
                 try {
                     uc.getInputStream().close();
-                } catch (IOException ioe) {
+                } catch (IOException e) {
                     if (log.isDebugEnabled()) {
-                        log.debug(Localizer.getMessage("jsp.error.lastModified", getJspFile()), ioe);
+                        log.debug(Localizer.getMessage("jsp.error.lastModified", getJspFile()), e);
                     }
                     result = -1;
                 }
@@ -596,8 +601,8 @@ public class JspCompilationContext {
             } catch (FileNotFoundException fnfe) {
                 // Re-throw to let caller handle this - will result in a 404
                 throw fnfe;
-            } catch (Exception e) {
-                JasperException je = new JasperException(Localizer.getMessage("jsp.error.unable.compile"), e);
+            } catch (Exception ex) {
+                JasperException je = new JasperException(Localizer.getMessage("jsp.error.unable.compile"), ex);
                 // Cache compilation exception
                 jsw.setCompilationException(je);
                 throw je;
@@ -617,8 +622,8 @@ public class JspCompilationContext {
             servletClass = jspLoader.loadClass(name);
         } catch (ClassNotFoundException cex) {
             throw new JasperException(Localizer.getMessage("jsp.error.unable.load"), cex);
-        } catch (Exception e) {
-            throw new JasperException(Localizer.getMessage("jsp.error.unable.compile"), e);
+        } catch (Exception ex) {
+            throw new JasperException(Localizer.getMessage("jsp.error.unable.compile"), ex);
         }
         removed = false;
         return servletClass;
