@@ -19,7 +19,7 @@ package org.apache.jasper;
 import java.io.File;
 import java.util.Map;
 
-import javax.servlet.jsp.tagext.TagLibraryInfo;
+import jakarta.servlet.jsp.tagext.TagLibraryInfo;
 
 import org.apache.jasper.compiler.JspConfig;
 import org.apache.jasper.compiler.TagPluginManager;
@@ -101,16 +101,6 @@ public interface Options {
      */
     TrimSpacesOption getTrimSpaces();
 
-    /**
-     * Gets the class-id value that is sent to Internet Explorer when using &lt;jsp:plugin&gt; tags.
-     *
-     * @return Class-id value
-     *
-     * @deprecated Will be removed in Tomcat 10.1.x
-     */
-    @Deprecated
-    String getIeClassId();
-
     /**
      * @return the work folder
      */
@@ -246,6 +236,103 @@ public interface Options {
      */
     boolean getQuoteAttributeEL();
 
+    /**
+     * @return the name of the variable that will be used in the generated JSP code for the expression factory
+     */
+    default String getVariableForExpressionFactory() {
+        return "_el_expressionfactory";
+    }
+
+    /**
+     * @return the name of the variable that will be used in the generated JSP code for the instance manager
+     */
+    default String getVariableForInstanceManager() {
+        return "_jsp_instancemanager";
+    }
+
+    /**
+     * @return {@code true} if tag pooling is disabled with page that uses extends.
+     */
+    default boolean getPoolTagsWithExtends() {
+        return false;
+    }
+
+    /**
+     * @return {@code true} if the requirement to have the object used in jsp:getProperty action to be previously
+     *             "introduced" to the JSP processor (see JSP.5.3) is enforced.
+     */
+    default boolean getStrictGetProperty() {
+        return true;
+    }
+
+    /**
+     * @return {@code true} if the strict white space rules are applied.
+     */
+    default boolean getStrictWhitespace() {
+        return true;
+    }
+
+    /**
+     * @return the default base class for generated JSP Servlets
+     */
+    default String getJspServletBase() {
+        return "org.apache.jasper.runtime.HttpJspBase";
+    }
+
+    /**
+     * _jspService is the name of the method that is called by HttpJspBase.service(). This is where most of the code
+     * generated from JSPs go.
+     *
+     * @return the method name
+     */
+    default String getServiceMethodName() {
+        return "_jspService";
+    }
+
+    /**
+     * @return ServletContext attribute for classpath. This is tomcat specific. Other servlet engines may choose to
+     *             support this attribute if they want to have this JSP engine running on them.
+     */
+    default String getServletClasspathAttribute() {
+        return "org.apache.catalina.jsp_classpath";
+    }
+
+    /**
+     * @return The query parameter that causes the JSP engine to just pregenerated the servlet but not invoke it.
+     */
+    default String getJspPrecompilationQueryParameter() {
+        return "jsp_precompile";
+    }
+
+    /**
+     * @return The default package name for compiled jsp pages.
+     */
+    default String getGeneratedJspPackageName() {
+        return "org.apache.jsp";
+    }
+
+    /**
+     * @return The default package name for tag handlers generated from tag files.
+     */
+    default String getGeneratedTagFilePackageName() {
+        return "org.apache.jsp.tag";
+    }
+
+    /**
+     * @return Prefix to use for generated temporary variable names
+     */
+    default String getTempVariableNamePrefix() {
+        return "_jspx_temp";
+    }
+
+    /**
+     * @return {@code true} if the container instance manager will be used to create the bean instances
+     */
+    default boolean getUseInstanceManagerForTags() {
+        return false;
+    }
+
+
     /**
      * Should the container include the time the file was generated in the comments at the start of a Java file
      * generated from a JSP or tag. Defaults to {@code true}.
@@ -258,7 +345,7 @@ public interface Options {
 
     /**
      * A string containing a comma-separated list of names to which custom tag implementations should be applied.
-     * Unknown or unused tag entries are harmless. Generally defined via an init parameter on the JspServlet.
+     * Unknown or unused tag entries are harmless.  Generally defined via an init parameter on the JspServlet.
      *
      * @return which tags to use
      */
