@@ -326,30 +326,15 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
             } else if (opt.equals("19")) {
                 settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_19);
             } else if (opt.equals("20")) {
-                // Constant not available in latest ECJ version that runs on
-                // Java 11.
-                // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_Source, "20");
+                settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_20);
             } else if (opt.equals("21")) {
-                // Constant not available in latest ECJ version that runs on
-                // Java 11.
-                // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_Source, "21");
+                settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_21);
             } else if (opt.equals("22")) {
-                // Constant not available in latest ECJ version that runs on
-                // Java 11.
-                // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_Source, "22");
+                settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_22);
             } else if (opt.equals("23")) {
-                // Constant not available in latest ECJ version that runs on
-                // Java 11.
-                // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_Source, "23");
+                settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_23);
             } else if (opt.equals("24")) {
-                // Constant not available in latest ECJ version that runs on
-                // Java 11.
-                // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_Source, "24");
+                settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_24);
             } else if (opt.equals("25")) {
                 // Constant not available in latest ECJ version shipped with
                 // Tomcat. May be supported in a snapshot build.
@@ -357,11 +342,11 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
                 settings.put(CompilerOptions.OPTION_Source, "25");
             } else {
                 log.warn(Localizer.getMessage("jsp.warning.unknown.sourceVM", opt));
-                settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_11);
+                settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_17);
             }
         } else {
-            // Default to 11
-            settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_11);
+            // Default to 17
+            settings.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_17);
         }
 
         // Target JVM
@@ -423,35 +408,20 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
                 settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_19);
                 settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_19);
             } else if (opt.equals("20")) {
-                // Constant not available in latest ECJ version that runs on
-                // Java 11.
-                // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_TargetPlatform, "20");
-                settings.put(CompilerOptions.OPTION_Compliance, "20");
+                settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_20);
+                settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_20);
             } else if (opt.equals("21")) {
-                // Constant not available in latest ECJ version that runs on
-                // Java 11.
-                // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_TargetPlatform, "21");
-                settings.put(CompilerOptions.OPTION_Compliance, "21");
+                settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_21);
+                settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_21);
             } else if (opt.equals("22")) {
-                // Constant not available in latest ECJ version that runs on
-                // Java 11.
-                // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_TargetPlatform, "22");
-                settings.put(CompilerOptions.OPTION_Compliance, "22");
+                settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_22);
+                settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_22);
             } else if (opt.equals("23")) {
-                // Constant not available in latest ECJ version that runs on
-                // Java 11.
-                // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_TargetPlatform, "23");
-                settings.put(CompilerOptions.OPTION_Compliance, "23");
+                settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_23);
+                settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_23);
             } else if (opt.equals("24")) {
-                // Constant not available in latest ECJ version that runs on
-                // Java 11.
-                // This is checked against the actual version below.
-                settings.put(CompilerOptions.OPTION_TargetPlatform, "24");
-                settings.put(CompilerOptions.OPTION_Compliance, "24");
+                settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_24);
+                settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_24);
             } else if (opt.equals("25")) {
                 // Constant not available in latest ECJ version shipped with
                 // Tomcat. May be supported in a snapshot build.
@@ -460,12 +430,12 @@ public class JDTCompiler extends org.apache.jasper.compiler.Compiler {
                 settings.put(CompilerOptions.OPTION_Compliance, "25");
             } else {
                 log.warn(Localizer.getMessage("jsp.warning.unknown.targetVM", opt));
-                settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_11);
+                settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_17);
             }
         } else {
-            // Default to 11
-            settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_11);
-            settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_11);
+            // Default to 17
+            settings.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_17);
+            settings.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_17);
         }
 
         final IProblemFactory problemFactory = new DefaultProblemFactory(Locale.getDefault());
