@@ -134,8 +134,7 @@ class Parser implements TagConstants {
             parser.addInclude(root, pageInfo.getIncludeCoda());
         }
 
-        Node.Nodes page = new Node.Nodes(root);
-        return page;
+        return new Node.Nodes(root);
     }
 
     /**
@@ -242,15 +241,12 @@ class Parser implements TagConstants {
         char ch = (char) reader.peekChar();
         if (Character.isLetter(ch) || ch == '_' || ch == ':') {
             StringBuilder buf = new StringBuilder();
-            buf.append(ch);
-            reader.nextChar();
-            ch = (char) reader.peekChar();
-            while (Character.isLetter(ch) || Character.isDigit(ch) || ch == '.' || ch == '_' || ch == '-' ||
-                    ch == ':') {
+            do {
                 buf.append(ch);
                 reader.nextChar();
                 ch = (char) reader.peekChar();
-            }
+            } while (Character.isLetter(ch) || Character.isDigit(ch) ||
+                ch == '.' || ch == '_' || ch == '-' || ch == ':');
             return buf.toString();
         }
         return null;
@@ -566,7 +562,7 @@ class Parser implements TagConstants {
     }
 
     /*
-     * Parses a attribute directive with the following syntax: AttributeDirective ::= ( S Attribute)*
+     * Parses an attribute directive with the following syntax: AttributeDirective ::= ( S Attribute)*
      */
     private void parseAttributeDirective(Node parent) throws JasperException {
         Attributes attrs = parseAttributes();
@@ -959,8 +955,7 @@ class Parser implements TagConstants {
         boolean result = false;
 
         if (reader.matchesOptionalSpacesFollowedBy("<jsp:attribute")) {
-            // May be an EmptyBody, depending on whether
-            // There's a "<jsp:body" before the ETag
+            // It may be an EmptyBody, depending on whether there's a "<jsp:body" before the ETag
 
             // First, parse <jsp:attribute> elements:
             parseNamedAttributes(parent);
@@ -1125,7 +1120,7 @@ class Parser implements TagConstants {
         // 'CustomActionJSPContent', or 'CustomActionScriptlessContent'.
         // depending on body-content in TLD.
 
-        // Looking for a body, it still can be empty; but if there is a
+        // Looking for a body, it still can be empty; but if there is
         // a tag body, its syntax would be dependent on the type of
         // body content declared in the TLD.
         String bc;
@@ -1135,7 +1130,7 @@ class Parser implements TagConstants {
             bc = tagFileInfo.getTagInfo().getBodyContent();
         }
 
-        Node tagNode = null;
+        Node tagNode;
         if (tagInfo != null) {
             tagNode = new Node.CustomTag(tagName, prefix, shortTagName, uri, attrs, start, parent, tagInfo,
                     tagHandlerClass);
