@@ -27,8 +27,6 @@ import java.io.UnsupportedEncodingException;
 import java.nio.file.DirectoryStream;
 import java.nio.file.Files;
 import java.nio.file.Path;
-import java.security.AccessController;
-import java.security.PrivilegedAction;
 import java.sql.Timestamp;
 import java.time.DateTimeException;
 import java.time.LocalDate;
@@ -366,7 +364,7 @@ public class FileHandler extends Handler {
         if (encoding != null && !encoding.isEmpty()) {
             try {
                 setEncoding(encoding);
-            } catch (UnsupportedEncodingException ignore) {
+            } catch (UnsupportedEncodingException ex) {
                 // Ignore
             }
         }
@@ -379,7 +377,7 @@ public class FileHandler extends Handler {
         if (filterName != null) {
             try {
                 setFilter((Filter) cl.loadClass(filterName).getConstructor().newInstance());
-            } catch (Exception ignore) {
+            } catch (Exception e) {
                 // Ignore
             }
         }
@@ -389,7 +387,7 @@ public class FileHandler extends Handler {
         if (formatterName != null) {
             try {
                 setFormatter((Formatter) cl.loadClass(formatterName).getConstructor().newInstance());
-            } catch (Exception ignore) {
+            } catch (Exception e) {
                 // Ignore and fallback to defaults
                 setFormatter(new OneLineFormatter());
             }
@@ -454,14 +452,14 @@ public class FileHandler extends Handler {
             if (fos != null) {
                 try {
                     fos.close();
-                } catch (IOException ignore) {
+                } catch (IOException e1) {
                     // Ignore
                 }
             }
             if (os != null) {
                 try {
                     os.close();
-                } catch (IOException ignore) {
+                } catch (IOException e1) {
                     // Ignore
                 }
             }
@@ -479,7 +477,7 @@ public class FileHandler extends Handler {
                 for (Path file : files) {
                     Files.delete(file);
                 }
-            } catch (IOException ioe) {
+            } catch (IOException e) {
                 reportError("Unable to delete log files older than [" + maxDays + "] days", null,
                         ErrorManager.GENERIC_FAILURE);
             }
@@ -495,8 +493,8 @@ public class FileHandler extends Handler {
                 try {
                     LocalDate dateFromFile = LocalDate.from(DateTimeFormatter.ISO_LOCAL_DATE.parse(date));
                     result = dateFromFile.isBefore(maxDaysOffset);
-                } catch (DateTimeException ignore) {
-                    // Unable to determine date from path. File will not be included.
+                } catch (DateTimeException e) {
+                    // no-op
                 }
             }
             return result;
@@ -523,34 +521,19 @@ public class FileHandler extends Handler {
 
     protected static final class ThreadFactory implements java.util.concurrent.ThreadFactory {
         private final String namePrefix;
-        private final boolean isSecurityEnabled;
         private final ThreadGroup group;
         private final AtomicInteger threadNumber = new AtomicInteger(1);
 
         public ThreadFactory(final String namePrefix) {
             this.namePrefix = namePrefix;
-            SecurityManager s = System.getSecurityManager();
-            if (s == null) {
-                this.isSecurityEnabled = false;
-                this.group = Thread.currentThread().getThreadGroup();
-            } else {
-                this.isSecurityEnabled = true;
-                this.group = s.getThreadGroup();
-            }
+            this.group = Thread.currentThread().getThreadGroup();
         }
 
         @Override
         public Thread newThread(Runnable r) {
             Thread t = new Thread(group, r, namePrefix + threadNumber.getAndIncrement());
             // Threads should not have as context classloader a webapp classloader
-            if (isSecurityEnabled) {
-                AccessController.doPrivileged((PrivilegedAction<Void>) () -> {
-                    t.setContextClassLoader(ThreadFactory.class.getClassLoader());
-                    return null;
-                });
-            } else {
-                t.setContextClassLoader(ThreadFactory.class.getClassLoader());
-            }
+            t.setContextClassLoader(ThreadFactory.class.getClassLoader());
             t.setDaemon(true);
             return t;
         }
