@@ -29,11 +29,22 @@ import org.apache.naming.EjbRef;
 
 /**
  * Object factory for EJBs.
+ *
+ * @author Jacek Laskowski
+ * @author Remy Maucherat
  */
 public class OpenEjbFactory implements ObjectFactory {
 
+
+    // -------------------------------------------------------------- Constants
+
+
     protected static final String DEFAULT_OPENEJB_FACTORY = "org.openejb.client.LocalInitialContextFactory";
 
+
+    // -------------------------------------------------- ObjectFactory Methods
+
+
     /**
      * Create a new EJB instance using OpenEJB.
      *
@@ -52,8 +63,7 @@ public class OpenEjbFactory implements ObjectFactory {
 
         Object beanObj = null;
 
-        if (obj instanceof EjbRef) {
-            EjbRef ref = (EjbRef) obj;
+        if (obj instanceof EjbRef ref) {
 
             String factory = DEFAULT_OPENEJB_FACTORY;
             RefAddr factoryRefAddr = ref.get("openejb.factory");
@@ -70,8 +80,12 @@ public class OpenEjbFactory implements ObjectFactory {
                 String ejbLink = linkRefAddr.getContent().toString();
                 beanObj = (new InitialContext(env)).lookup(ejbLink);
             }
+
         }
 
         return beanObj;
+
     }
+
+
 }
