@@ -1386,7 +1386,7 @@ public class Digester extends DefaultHandler2 {
                         }
                     } catch (URISyntaxException e) {
                         if (log.isDebugEnabled()) {
-                            log.debug(sm.getString("digester.invalidURI", baseURI, systemId), e);
+                            log.debug(sm.getString("digester.invalidURI", baseURI, systemId));
                         }
                     }
                 }
@@ -1931,9 +1931,6 @@ public class Digester extends DefaultHandler2 {
     public SAXException createSAXException(String message, Exception e) {
         if ((e instanceof InvocationTargetException)) {
             Throwable t = e.getCause();
-            if (t instanceof ThreadDeath) {
-                throw (ThreadDeath) t;
-            }
             if (t instanceof VirtualMachineError) {
                 throw (VirtualMachineError) t;
             }
@@ -1968,9 +1965,6 @@ public class Digester extends DefaultHandler2 {
     public SAXException createSAXException(Exception e) {
         if (e instanceof InvocationTargetException) {
             Throwable t = e.getCause();
-            if (t instanceof ThreadDeath) {
-                throw (ThreadDeath) t;
-            }
             if (t instanceof VirtualMachineError) {
                 throw (VirtualMachineError) t;
             }
