@@ -22,7 +22,6 @@ import java.io.StringWriter;
 import java.util.Collections;
 import java.util.Enumeration;
 import java.util.HashMap;
-import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 
@@ -60,6 +59,11 @@ import org.apache.tomcat.util.res.StringManager;
  * structure - will add an overhead that is not needed in most cases)
  * <p>
  * Apache seems to be using a similar method for storing and manipulating headers.
+ *
+ * @author dac@eng.sun.com
+ * @author James Todd [gonzo@eng.sun.com]
+ * @author Costin Manolache
+ * @author kevin seguin
  */
 public class MimeHeaders {
 
@@ -117,11 +121,6 @@ public class MimeHeaders {
         count = 0;
     }
 
-    @Deprecated
-    public void clear() {
-        recycle();
-    }
-
     @Override
     public String toString() {
         StringWriter sw = new StringWriter();
@@ -160,7 +159,7 @@ public class MimeHeaders {
         int j = -1;
         for (int i = 0; i < count; i++) {
             String name = headers[i].getName().toStringType();
-            if (allowedHeaders.contains(name.trim().toLowerCase(Locale.ENGLISH))) {
+            if (allowedHeaders.contains(name)) {
                 ++j;
                 if (j != i) {
                     headers[j] = headers[i];
