@@ -18,6 +18,7 @@ package org.apache.tomcat.util.http;
 
 import java.io.IOException;
 import java.io.Reader;
+import java.io.Serial;
 import java.io.StringReader;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -69,6 +70,8 @@ import org.apache.tomcat.util.res.StringManager;
  * value of the etag is not taken into consideration).
  * <p>
  * This class was contributed by Apache Jackrabbit
+ *
+ * @author Felix Meschberger
  */
 public class WebdavIfHeader {
 
@@ -224,10 +227,8 @@ public class WebdavIfHeader {
                     firstChar = readWhiteSpace(reader);
                     reader.reset();
                 } catch (IOException ignore) {
-                    /*
-                     * May be thrown according to API but is only thrown by the StringReader class if the reader is
-                     * already closed.
-                     */
+                    // may be thrown according to API but is only thrown by the
+                    // StringReader class if the reader is already closed.
                 }
 
                 if (firstChar == '(') {
@@ -699,6 +700,7 @@ public class WebdavIfHeader {
      */
     private static class IfList extends ArrayList<IfListEntry> {
 
+        @Serial
         private static final long serialVersionUID = 1L;
 
         /**
@@ -792,6 +794,7 @@ public class WebdavIfHeader {
      */
     private static class IfHeaderList extends ArrayList<IfList> implements IfHeaderInterface {
 
+        @Serial
         private static final long serialVersionUID = 1L;
 
         /**
@@ -837,6 +840,7 @@ public class WebdavIfHeader {
      */
     private class IfHeaderMap extends HashMap<String,IfHeaderList> implements IfHeaderInterface {
 
+        @Serial
         private static final long serialVersionUID = 1L;
 
         /**
