@@ -92,6 +92,8 @@ import org.apache.tomcat.util.res.StringManager;
  * </ul>
  * <li>Attribute caching is not supported</li>
  * </ul>
+ *
+ * @author Craig R. McClanahan
  * @author Costin Manolache
  */
 public class BaseModelMBean implements DynamicMBean, MBeanRegistration, ModelMBeanNotificationBroadcaster {
@@ -296,7 +298,7 @@ public class BaseModelMBean implements DynamicMBean, MBeanRegistration, ModelMBe
                 if (cl != null) {
                     return cl.loadClass(signature);
                 }
-            } catch (ClassNotFoundException ignore) {
+            } catch (ClassNotFoundException e) {
                 // Ignore
             }
             try {
@@ -370,8 +372,8 @@ public class BaseModelMBean implements DynamicMBean, MBeanRegistration, ModelMBe
         }
         try {
             sendAttributeChangeNotification(new Attribute(name, oldValue), attribute);
-        } catch (Exception e) {
-            log.error(sm.getString("baseModelMBean.notificationError", name), e);
+        } catch (Exception ex) {
+            log.error(sm.getString("baseModelMBean.notificationError", name), ex);
         }
         // attributes.put( name, value );
         // if( source != null ) {
@@ -405,7 +407,7 @@ public class BaseModelMBean implements DynamicMBean, MBeanRegistration, ModelMBe
             names[n++] = item.getName();
             try {
                 setAttribute(item);
-            } catch (Exception ignore) {
+            } catch (Exception e) {
                 // Ignore all exceptions
             }
         }
@@ -465,13 +467,30 @@ public class BaseModelMBean implements DynamicMBean, MBeanRegistration, ModelMBe
                     sm.getString("baseModelMBean.nullResource"));
         }
 
+        // if (!"objectreference".equalsIgnoreCase(type))
+        // throw new InvalidTargetObjectTypeException(type);
+
         this.resource = resource;
         this.resourceType = resource.getClass().getName();
+
+        // // Make the resource aware of the model mbean.
+        // try {
+        // Method m=resource.getClass().getMethod("setModelMBean",
+        // new Class[] {ModelMBean.class});
+        // if( m!= null ) {
+        // m.invoke(resource, new Object[] {this});
+        // }
+        // } catch( NoSuchMethodException t ) {
+        // // ignore
+        // } catch( Throwable t ) {
+        // log.error( "Can't set model mbean ", t );
+        // }
     }
 
 
     // ------------------------------ ModelMBeanNotificationBroadcaster Methods
 
+
     @Override
     public void addAttributeChangeNotificationListener(NotificationListener listener, String name, Object handback)
             throws IllegalArgumentException {
