@@ -24,6 +24,8 @@ import java.net.InetAddress;
 import java.net.InetSocketAddress;
 import java.net.SocketAddress;
 import java.net.SocketTimeoutException;
+import java.net.StandardProtocolFamily;
+import java.net.UnixDomainSocketAddress;
 import java.nio.ByteBuffer;
 import java.nio.channels.CancelledKeyException;
 import java.nio.channels.Channel;
@@ -58,7 +60,6 @@ import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.ExceptionUtils;
 import org.apache.tomcat.util.collections.SynchronizedQueue;
 import org.apache.tomcat.util.collections.SynchronizedStack;
-import org.apache.tomcat.util.compat.JreCompat;
 import org.apache.tomcat.util.compat.JrePlatform;
 import org.apache.tomcat.util.net.AbstractEndpoint.Handler.SocketState;
 import org.apache.tomcat.util.net.Acceptor.AcceptorState;
@@ -66,8 +67,10 @@ import org.apache.tomcat.util.net.jsse.JSSESupport;
 
 /**
  * NIO endpoint.
+ *
+ * @author Mladen Turk
  */
-public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel> {
+public class NioEndpoint extends AbstractNetworkChannelEndpoint<NioChannel,SocketChannel> {
 
 
     // -------------------------------------------------------------- Constants
@@ -237,8 +240,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 throw new IllegalArgumentException(sm.getString("endpoint.init.bind.inherited"));
             }
         } else if (getUnixDomainSocketPath() != null) {
-            SocketAddress sa = JreCompat.getInstance().getUnixDomainSocketAddress(getUnixDomainSocketPath());
-            serverSock = JreCompat.getInstance().openUnixDomainServerSocketChannel();
+            SocketAddress sa = UnixDomainSocketAddress.of(getUnixDomainSocketPath());
+            serverSock = ServerSocketChannel.open(StandardProtocolFamily.UNIX);
             serverSock.bind(sa, getAcceptCount());
             if (getUnixDomainSocketPathPermissions() != null) {
                 Path path = Paths.get(getUnixDomainSocketPath());
@@ -411,8 +414,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 return;
             }
             try {
-                SocketAddress sa = JreCompat.getInstance().getUnixDomainSocketAddress(getUnixDomainSocketPath());
-                try (SocketChannel socket = JreCompat.getInstance().openUnixDomainSocketChannel()) {
+                SocketAddress sa = UnixDomainSocketAddress.of(getUnixDomainSocketPath());
+                try (SocketChannel socket = SocketChannel.open(StandardProtocolFamily.UNIX)) {
                     // With a UDS, expect no delay connecting and no defer accept
                     socket.connect(sa);
                 }
@@ -472,11 +475,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
             if (channel == null) {
                 SocketBufferHandler bufhandler = new SocketBufferHandler(socketProperties.getAppReadBufSize(),
                         socketProperties.getAppWriteBufSize(), socketProperties.getDirectBuffer());
-                if (isSSLEnabled()) {
-                    channel = new SecureNioChannel(bufhandler, this);
-                } else {
-                    channel = new NioChannel(bufhandler);
-                }
+                channel = createChannel(bufhandler);
             }
             NioSocketWrapper newWrapper = new NioSocketWrapper(channel, this);
             channel.reset(socket, newWrapper);
@@ -568,6 +567,14 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
         return new SocketProcessor(socketWrapper, event);
     }
 
+    @Override
+    protected NioChannel createChannel(SocketBufferHandler buffer) {
+        if (isSSLEnabled()) {
+            return new SecureNioChannel(buffer, this);
+        }
+        return new NioChannel(buffer);
+    }
+
     // ----------------------------------------------------- Poller Inner Classes
 
     /**
@@ -703,8 +710,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 } else if (interestOps == OP_REGISTER) {
                     try {
                         sc.register(getSelector(), SelectionKey.OP_READ, socketWrapper);
-                    } catch (Exception e) {
-                        log.error(sm.getString("endpoint.nio.registerFail"), e);
+                    } catch (Exception x) {
+                        log.error(sm.getString("endpoint.nio.registerFail"), x);
                     }
                 } else {
                     final SelectionKey key = sc.keyFor(getSelector());
@@ -923,7 +930,6 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                     try {
                         sd.fchannel.close();
                     } catch (Exception ignore) {
-                        // Ignore
                     }
                     // For calls from outside the Poller, the caller is
                     // responsible for registering the socket for the
@@ -967,9 +973,9 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                     }
                     return SendfileState.PENDING;
                 }
-            } catch (IOException ioe) {
+            } catch (IOException e) {
                 if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("endpoint.sendfile.error"), ioe);
+                    log.debug(sm.getString("endpoint.sendfile.error"), e);
                 }
                 if (!calledByProcessor && sc != null) {
                     socketWrapper.close();
@@ -1253,10 +1259,10 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                         getSocket().free();
                     }
                 }
-            } catch (Throwable t) {
-                ExceptionUtils.handleThrowable(t);
+            } catch (Throwable e) {
+                ExceptionUtils.handleThrowable(e);
                 if (log.isDebugEnabled()) {
-                    log.error(sm.getString("endpoint.debug.channelCloseFail"), t);
+                    log.error(sm.getString("endpoint.debug.channelCloseFail"), e);
                 }
             } finally {
                 socketBufferHandler = SocketBufferHandler.EMPTY;
@@ -1268,10 +1274,10 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 if (data != null && data.fchannel != null && data.fchannel.isOpen()) {
                     data.fchannel.close();
                 }
-            } catch (Throwable t) {
-                ExceptionUtils.handleThrowable(t);
+            } catch (Throwable e) {
+                ExceptionUtils.handleThrowable(e);
                 if (log.isDebugEnabled()) {
-                    log.error(sm.getString("endpoint.sendfile.closeError"), t);
+                    log.error(sm.getString("endpoint.sendfile.closeError"), e);
                 }
             }
         }
@@ -1318,11 +1324,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                                 } else {
                                     readLock.wait();
                                 }
-                            } catch (InterruptedException ignore) {
-                                /*
-                                 * Most likely the Poller signalling there is data to read but could be spurious. Exit
-                                 * the wait, check status and proceed accordingly.
-                                 */
+                            } catch (InterruptedException e) {
+                                // Continue
                             }
                         }
                     }
@@ -1428,11 +1431,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                                 } else {
                                     writeLock.wait();
                                 }
-                            } catch (InterruptedException ignore) {
-                                /*
-                                 * Most likely the Poller signalling that data can be written but could be spurious.
-                                 * Exit the wait, check status and proceed accordingly.
-                                 */
+                            } catch (InterruptedException e) {
+                                // Continue
                             }
                         } else if (startNanos > 0) {
                             // If something was written, reset timeout
@@ -1562,8 +1562,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
 
         @Override
         public SSLSupport getSslSupport() {
-            if (getSocket() instanceof SecureNioChannel) {
-                SecureNioChannel ch = (SecureNioChannel) getSocket();
+            if (getSocket() instanceof SecureNioChannel ch) {
                 return ch.getSSLSupport();
             }
             return null;
@@ -1682,8 +1681,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                                 completionDone = false;
                             }
                         }
-                    } catch (IOException ioe) {
-                        setError(ioe);
+                    } catch (IOException e) {
+                        setError(e);
                     }
                 }
                 if (nBytes > 0 || (nBytes == 0 && !buffersArrayHasRemaining(buffers, offset, length) &&
@@ -1759,11 +1758,11 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                         // the handshake completes.
                         event = SocketEvent.OPEN_READ;
                     }
-                } catch (IOException ioe) {
+                } catch (IOException x) {
                     handshake = -1;
                     if (logHandshake.isDebugEnabled()) {
                         logHandshake.debug(sm.getString("endpoint.err.handshake", socketWrapper.getRemoteAddr(),
-                                Integer.toString(socketWrapper.getRemotePort())), ioe);
+                                Integer.toString(socketWrapper.getRemotePort())), x);
                     }
                 } catch (CancelledKeyException ckx) {
                     handshake = -1;
