@@ -64,7 +64,6 @@ import org.apache.tomcat.util.file.ConfigFileLoader;
 import org.apache.tomcat.util.net.jsse.JSSEKeyManager;
 import org.apache.tomcat.util.net.jsse.PEMFile;
 import org.apache.tomcat.util.res.StringManager;
-import org.apache.tomcat.util.security.KeyStoreUtil;
 
 /**
  * Common base class for {@link SSLUtil} implementations.
@@ -232,15 +231,15 @@ public abstract class SSLUtilBase implements SSLUtil {
                         (!passToUse.isEmpty() || "JKS".equalsIgnoreCase(type) || "PKCS12".equalsIgnoreCase(type))) {
                     storePass = passToUse.toCharArray();
                 }
-                KeyStoreUtil.load(ks, istream, storePass);
+                ks.load(istream, storePass);
             }
         } catch (IOException ioe) {
             // May be expected when working with a trust store
             // Re-throw. Caller will catch and log as required
             throw ioe;
-        } catch (Exception e) {
-            String msg = sm.getString("sslUtilBase.keystore_load_failed", type, path, e.getMessage());
-            log.error(msg, e);
+        } catch (Exception ex) {
+            String msg = sm.getString("sslUtilBase.keystore_load_failed", type, path, ex.getMessage());
+            log.error(msg, ex);
             throw new IOException(msg);
         } finally {
             if (istream != null) {
