@@ -31,7 +31,6 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
-import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
 
 import jakarta.servlet.ServletConnection;
@@ -59,7 +58,7 @@ public abstract class SocketWrapperBase<E> {
 
     private E socket;
     private final AbstractEndpoint<E,?> endpoint;
-    private final Lock lock = new ReentrantLock();
+    private final ReentrantLock lock = new ReentrantLock();
 
     protected final AtomicBoolean closed = new AtomicBoolean(false);
 
@@ -86,8 +85,6 @@ public abstract class SocketWrapperBase<E> {
     protected int remotePort = -1;
     protected volatile ServletConnection servletConnection = null;
 
-    protected String sniHostName = null;
-
     /**
      * Used to record the first IOException that occurs during non-blocking read/writes that can't be usefully
      * propagated up the stack since there is no user code or appropriate container code in the stack to handle it.
@@ -153,7 +150,7 @@ public abstract class SocketWrapperBase<E> {
         return endpoint;
     }
 
-    public Lock getLock() {
+    public ReentrantLock getLock() {
         return lock;
     }
 
@@ -211,20 +208,6 @@ public abstract class SocketWrapperBase<E> {
         this.negotiatedProtocol = negotiatedProtocol;
     }
 
-    /**
-     * @return the sniHostName
-     */
-    public String getSniHostName() {
-        return this.sniHostName;
-    }
-
-    /**
-     * @param sniHostName the SNI host name to set
-     */
-    public void setSniHostName(String sniHostName) {
-        this.sniHostName = sniHostName;
-    }
-
     /**
      * Set the timeout for reading. Values of zero or less will be changed to -1.
      *
@@ -437,10 +420,10 @@ public abstract class SocketWrapperBase<E> {
         if (closed.compareAndSet(false, true)) {
             try {
                 getEndpoint().getHandler().release(this);
-            } catch (Throwable t) {
-                ExceptionUtils.handleThrowable(t);
+            } catch (Throwable e) {
+                ExceptionUtils.handleThrowable(e);
                 if (log.isDebugEnabled()) {
-                    log.error(sm.getString("endpoint.debug.handlerRelease"), t);
+                    log.error(sm.getString("endpoint.debug.handlerRelease"), e);
                 }
             } finally {
                 getEndpoint().countDownConnection();
@@ -1376,13 +1359,7 @@ public abstract class SocketWrapperBase<E> {
             synchronized (state) {
                 if (state.state == CompletionState.PENDING) {
                     try {
-                        long timeoutExpiry = System.nanoTime() + unit.toNanos(timeout);
-                        long timeoutMillis = unit.toMillis(timeout);
-                         // Spurious wake-ups are possible. Keep waiting until state changes or timeout expires.
-                        while (state.state == CompletionState.PENDING && timeoutMillis > 0) {
-                            state.wait(unit.toMillis(timeout));
-                            timeoutMillis = (timeoutExpiry - System.nanoTime()) / 1_000_000;
-                        }
+                        state.wait(unit.toMillis(timeout));
                         if (state.state == CompletionState.PENDING) {
                             if (handler != null && state.callHandler.compareAndSet(true, false)) {
                                 handler.failed(new SocketTimeoutException(getTimeoutMsg(read)), attachment);
