@@ -325,21 +325,12 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
             addCertificate(certificate);
 
             // Client certificate verification
-            int value = 0;
-            switch (sslHostConfig.getCertificateVerification()) {
-                case NONE:
-                    value = SSL.SSL_CVERIFY_NONE;
-                    break;
-                case OPTIONAL:
-                    value = SSL.SSL_CVERIFY_OPTIONAL;
-                    break;
-                case OPTIONAL_NO_CA:
-                    value = SSL.SSL_CVERIFY_OPTIONAL_NO_CA;
-                    break;
-                case REQUIRED:
-                    value = SSL.SSL_CVERIFY_REQUIRE;
-                    break;
-            }
+            int value = switch (sslHostConfig.getCertificateVerification()) {
+                case NONE -> SSL.SSL_CVERIFY_NONE;
+                case OPTIONAL -> SSL.SSL_CVERIFY_OPTIONAL;
+                case OPTIONAL_NO_CA -> SSL.SSL_CVERIFY_OPTIONAL_NO_CA;
+                case REQUIRED -> SSL.SSL_CVERIFY_REQUIRE;
+            };
             SSLContext.setVerify(state.ctx, value, sslHostConfig.getCertificateVerificationDepth());
 
             if (tms != null) {
@@ -610,20 +601,12 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
     }
 
 
-    private static class OpenSSLState implements Runnable {
-
-        final long aprPool;
-        // OpenSSLConfCmd context
-        final long cctx;
-        // SSL context
-        final long ctx;
-
-        private OpenSSLState(long aprPool, long cctx, long ctx) {
-            this.aprPool = aprPool;
-            this.cctx = cctx;
-            this.ctx = ctx;
-        }
-
+    /**
+     * @param aprPool the APR pool
+     * @param cctx    OpenSSLConfCmd context
+     * @param ctx     SSL context
+     */
+    private record OpenSSLState(long aprPool, long cctx, long ctx) implements Runnable {
         @Override
         public void run() {
             if (ctx != 0) {
