@@ -59,12 +59,10 @@ import org.apache.tomcat.util.net.SSLHostConfig;
 import org.apache.tomcat.util.net.SSLHostConfig.CertificateVerification;
 import org.apache.tomcat.util.net.SSLHostConfigCertificate;
 import org.apache.tomcat.util.net.SSLHostConfigCertificate.Type;
-import org.apache.tomcat.util.net.SSLUtilBase;
 import org.apache.tomcat.util.net.openssl.OpenSSLConf;
 import org.apache.tomcat.util.net.openssl.OpenSSLConfCmd;
 import org.apache.tomcat.util.net.openssl.OpenSSLStatus;
 import org.apache.tomcat.util.net.openssl.OpenSSLUtil;
-import org.apache.tomcat.util.net.openssl.ciphers.Group;
 import org.apache.tomcat.util.openssl.SSL_CTX_set_alpn_select_cb$cb;
 import org.apache.tomcat.util.openssl.SSL_CTX_set_cert_verify_callback$cb;
 import org.apache.tomcat.util.openssl.SSL_CTX_set_tmp_dh_callback$dh;
@@ -83,6 +81,11 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
 
     private static final String defaultProtocol = "TLS";
 
+    private static final int SSL_AIDX_RSA = 0;
+    private static final int SSL_AIDX_DSA = 1;
+    private static final int SSL_AIDX_ECC = 3;
+    private static final int SSL_AIDX_MAX = 4;
+
     public static final int SSL_PROTOCOL_NONE = 0;
     public static final int SSL_PROTOCOL_SSLV2 = 1;
     public static final int SSL_PROTOCOL_SSLV3 = (1 << 1);
@@ -261,29 +264,6 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
             // Set int pem_password_cb(char *buf, int size, int rwflag, void *u) callback
             SSL_CTX_set_default_passwd_cb(sslCtx, pem_password_cb.allocate(new PasswordCallback(null), contextArena));
 
-            // Set server groups
-            // Note: It is also possible to override setSSLParameters in OpenSSLEngine to set the final
-            //  list of groups per connection, but this is less efficient than setting the configured
-            //  group list on the SSL context and letting OpenSSL figure it out.
-            if (sslHostConfig.getGroupList() != null) {
-                StringBuilder sb = new StringBuilder();
-                boolean first = true;
-                for (Group group : sslHostConfig.getGroupList()) {
-                    if (first) {
-                        first = false;
-                    } else {
-                        sb.append(':');
-                    }
-                    sb.append(group.toString());
-                }
-                try (var localArena = Arena.ofConfined()) {
-                    if (SSL_CTX_set1_groups_list(sslCtx, localArena.allocateFrom(sb.toString())) <= 0) {
-                        logLastError("openssl.errorSettingGroups");
-                        // Consider this is not fatal
-                    }
-                }
-            }
-
             if (negotiableProtocols != null && !negotiableProtocols.isEmpty()) {
                 alpn = true;
                 negotiableProtocolsBytes = new ArrayList<>(negotiableProtocols.size() + 1);
@@ -385,7 +365,7 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
                     }
                 }
             } catch (Exception e) {
-                log.error(sm.getString("opensslconf.checkFailed", e.getLocalizedMessage()), e);
+                log.error(sm.getString("opensslconf.checkFailed", e.getLocalizedMessage()));
                 return false;
             }
             if (!ok) {
@@ -434,7 +414,7 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
                     }
                 }
             } catch (Exception e) {
-                log.error(sm.getString("opensslconf.applyFailed"), e);
+                log.error(sm.getString("opensslconf.applyFailed"));
                 return false;
             }
             if (rc <= 0) {
@@ -531,10 +511,6 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
                 case REQUIRED -> SSL_VERIFY_FAIL_IF_NO_PEER_CERT();
             };
 
-            if (value == OPTIONAL_NO_CA) {
-                noOcspCheck = true;
-            }
-
             // Set int verify_callback(int preverify_ok, X509_STORE_CTX *x509_ctx) callback
             SSL_CTX_set_verify(state.sslCtx, value,
                     SSL_CTX_set_verify$callback.allocate(new OpenSSLEngine.VerifyCallback(), contextArena));
@@ -793,9 +769,7 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
                     x509TrustManager.checkClientTrusted(peerCerts, authMethod);
                     return 1;
                 } catch (Exception e) {
-                    if (log.isDebugEnabled()) {
-                        log.debug(sm.getString("openssl.certificateVerificationFailed"), e);
-                    }
+                    log.debug(sm.getString("openssl.certificateVerificationFailed"), e);
                 }
             }
             return 0;
@@ -898,7 +872,8 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
     }
 
 
-    public boolean addCertificate(SSLHostConfigCertificate certificate, Arena localArena) throws Exception {
+    private boolean addCertificate(SSLHostConfigCertificate certificate, Arena localArena) throws Exception {
+        int index = getCertificateIndex(certificate);
         // Load Server key and certificate
         if (certificate.getCertificateFile() != null) {
             // Pick right key password
@@ -916,8 +891,8 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
                         new InputStreamReader(ConfigFileLoader.getSource().getResource(keyPassFile).getInputStream(),
                                 StandardCharsets.UTF_8))) {
                     keyPassToUse = reader.readLine();
-                } catch (IOException ioe) {
-                    log.error(sm.getString("openssl.errorLoadingPassword", keyPassFile), ioe);
+                } catch (IOException e) {
+                    log.error(sm.getString("openssl.errorLoadingPassword", keyPassFile), e);
                     return false;
                 }
             } else {
@@ -927,8 +902,8 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
             byte[] certificateFileBytes;
             try (Resource resource = ConfigFileLoader.getSource().getResource(certificate.getCertificateFile())) {
                 certificateFileBytes = resource.getInputStream().readAllBytes();
-            } catch (IOException ioe) {
-                log.error(sm.getString("openssl.errorLoadingCertificate", certificate.getCertificateFile()), ioe);
+            } catch (IOException e) {
+                log.error(sm.getString("openssl.errorLoadingCertificate", certificate.getCertificateFile()), e);
                 return false;
             }
             MemorySegment certificateFileBytesNative =
@@ -982,8 +957,8 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
                     byte[] certificateKeyFileBytes;
                     try (Resource resource = ConfigFileLoader.getSource().getResource(certificateKeyFileName)) {
                         certificateKeyFileBytes = resource.getInputStream().readAllBytes();
-                    } catch (IOException ioe) {
-                        log.error(sm.getString("openssl.errorLoadingCertificate", certificateKeyFileName), ioe);
+                    } catch (IOException e) {
+                        log.error(sm.getString("openssl.errorLoadingCertificate", certificateKeyFileName), e);
                         return false;
                     }
                     MemorySegment certificateKeyFileBytesNative =
@@ -1050,8 +1025,8 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
                     logLastError("openssl.errorPrivateKeyCheck");
                     return false;
                 }
-                // Try to read DH parameters from the SSLCertificateFile
-                if (certificate.getType() == Type.RSA) {
+                // Try to read DH parameters from the (first) SSLCertificateFile
+                if (index == SSL_AIDX_RSA) {
                     BIO_reset(certificateBIO);
                     if (!openssl_h_Compatibility.BORINGSSL) {
                         if (!openssl_h_Compatibility.OPENSSL3) {
@@ -1121,10 +1096,10 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
                     try (Resource resource =
                             ConfigFileLoader.getSource().getResource(certificate.getCertificateChainFile())) {
                         certificateChainBytes = resource.getInputStream().readAllBytes();
-                    } catch (IOException ioe) {
+                    } catch (IOException e) {
                         log.error(
                                 sm.getString("openssl.errorLoadingCertificate", certificate.getCertificateChainFile()),
-                                ioe);
+                                e);
                         return false;
                     }
                     MemorySegment certificateChainBytesNative =
@@ -1188,7 +1163,7 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
             String alias = certificate.getCertificateKeyAlias();
             X509KeyManager x509KeyManager = certificate.getCertificateKeyManager();
             if (alias == null) {
-                alias = SSLUtilBase.DEFAULT_KEY_ALIAS;
+                alias = "tomcat";
             }
             X509Certificate[] chain = x509KeyManager.getCertificateChain(alias);
             if (chain == null) {
@@ -1272,6 +1247,23 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
     }
 
 
+    private static int getCertificateIndex(SSLHostConfigCertificate certificate) {
+        int result;
+        // If the type is undefined there will only be one certificate (enforced
+        // in SSLHostConfig) so use the RSA slot.
+        if (certificate.getType() == Type.RSA || certificate.getType() == Type.UNDEFINED) {
+            result = SSL_AIDX_RSA;
+        } else if (certificate.getType() == Type.EC) {
+            result = SSL_AIDX_ECC;
+        } else if (certificate.getType() == Type.DSA) {
+            result = SSL_AIDX_DSA;
+        } else {
+            result = SSL_AIDX_MAX;
+        }
+        return result;
+    }
+
+
     /*
      * Find a valid alias when none was specified in the config.
      */
@@ -1292,7 +1284,7 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
 
         Iterator<Type> iter = candidateTypes.iterator();
         while (result == null && iter.hasNext()) {
-            result = keyManager.chooseServerAlias(iter.next().getKeyType(), null, null);
+            result = keyManager.chooseServerAlias(iter.next().toString(), null, null);
         }
 
         return result;
@@ -1352,7 +1344,7 @@ public class OpenSSLContext implements org.apache.tomcat.util.net.SSLContext {
         X509KeyManager x509KeyManager = certificate.getCertificateKeyManager();
         if (x509KeyManager != null) {
             if (alias == null) {
-                alias = SSLUtilBase.DEFAULT_KEY_ALIAS;
+                alias = "tomcat";
             }
             chain = x509KeyManager.getCertificateChain(alias);
             if (chain == null) {
