@@ -16,6 +16,7 @@
  */
 package org.apache.tomcat.util.threads;
 
+import java.io.Serial;
 import java.util.Collection;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.RejectedExecutionException;
@@ -24,12 +25,15 @@ import java.util.concurrent.TimeUnit;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * As task queue specifically designed to run with a thread pool executor. The task queue is optimised to properly
- * utilize threads within a thread pool executor. If you use a normal queue, the executor will spawn threads when there
- * are idle threads and you won't be able to force items onto the queue itself.
+ * As task queue specifically designed to run with a thread pool executor. The
+ * task queue is optimised to properly utilize threads within a thread pool
+ * executor. If you use a normal queue, the executor will spawn threads when
+ * there are idle threads and you won't be able to force items onto the queue
+ * itself.
  */
 public class TaskQueue extends LinkedBlockingQueue<Runnable> implements RetryableQueue<Runnable> {
 
+    @Serial
     private static final long serialVersionUID = 1L;
     protected static final StringManager sm = StringManager.getManager(TaskQueue.class);
 
@@ -57,35 +61,36 @@ public class TaskQueue extends LinkedBlockingQueue<Runnable> implements Retryabl
         if (parent == null || parent.isShutdown()) {
             throw new RejectedExecutionException(sm.getString("taskQueue.notRunning"));
         }
-        return super.offer(o); // forces the item onto the queue, to be used if the task is rejected
+        return super.offer(o); //forces the item onto the queue, to be used if the task is rejected
     }
 
 
     @Override
     public boolean offer(Runnable o) {
-        // we can't do any checks
-        if (parent == null) {
+      //we can't do any checks
+        if (parent==null) {
             return super.offer(o);
         }
-        // we are maxed out on threads, simply queue the object
+        //we are maxed out on threads, simply queue the object
         if (parent.getPoolSizeNoLock() == parent.getMaximumPoolSize()) {
             return super.offer(o);
         }
-        // we have idle threads, just add it to the queue
+        //we have idle threads, just add it to the queue
         if (parent.getSubmittedCount() <= parent.getPoolSizeNoLock()) {
             return super.offer(o);
         }
-        // if we have less threads than maximum force creation of a new thread
+        //if we have less threads than maximum force creation of a new thread
         if (parent.getPoolSizeNoLock() < parent.getMaximumPoolSize()) {
             return false;
         }
-        // if we reached here, we need to add it to the queue
+        //if we reached here, we need to add it to the queue
         return super.offer(o);
     }
 
 
     @Override
-    public Runnable poll(long timeout, TimeUnit unit) throws InterruptedException {
+    public Runnable poll(long timeout, TimeUnit unit)
+            throws InterruptedException {
         Runnable runnable = super.poll(timeout, unit);
         if (runnable == null && parent != null) {
             // the poll timed out, it gives an opportunity to stop the current
@@ -98,7 +103,8 @@ public class TaskQueue extends LinkedBlockingQueue<Runnable> implements Retryabl
     @Override
     public Runnable take() throws InterruptedException {
         if (parent != null && parent.currentThreadShouldBeStopped()) {
-            return poll(parent.getKeepAliveTime(TimeUnit.MILLISECONDS), TimeUnit.MILLISECONDS);
+            return poll(parent.getKeepAliveTime(TimeUnit.MILLISECONDS),
+                    TimeUnit.MILLISECONDS);
             // yes, this may return null (in case of timeout) which normally
             // does not occur with take()
             // but the ThreadPoolExecutor implementation allows this
