@@ -24,6 +24,7 @@
  */
 package org.apache.tomcat.util.threads;
 
+import java.io.Serial;
 import java.util.ArrayList;
 import java.util.ConcurrentModificationException;
 import java.util.HashSet;
@@ -583,29 +584,6 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
      */
     private static final RejectedExecutionHandler defaultHandler = new RejectPolicy();
 
-    /**
-     * Permission required for callers of shutdown and shutdownNow.
-     * We additionally require (see checkShutdownAccess) that callers
-     * have permission to actually interrupt threads in the worker set
-     * (as governed by Thread.interrupt, which relies on
-     * ThreadGroup.checkAccess, which in turn relies on
-     * SecurityManager.checkAccess). Shutdowns are attempted only if
-     * these checks pass.
-     *
-     * All actual invocations of Thread.interrupt (see
-     * interruptIdleWorkers and interruptWorkers) ignore
-     * SecurityExceptions, meaning that the attempted interrupts
-     * silently fail. In the case of shutdown, they should not fail
-     * unless the SecurityManager has inconsistent policies, sometimes
-     * allowing access to a thread and sometimes not. In such cases,
-     * failure to actually interrupt threads may disable or delay full
-     * termination. Other uses of interruptIdleWorkers are advisory,
-     * and failure to actually interrupt will merely delay response to
-     * configuration changes so is not handled exceptionally.
-     */
-    private static final RuntimePermission shutdownPerm =
-        new RuntimePermission("modifyThread");
-
     /**
      * Class Worker mainly maintains interrupt control state for
      * threads running tasks, along with other minor bookkeeping.
@@ -630,6 +608,7 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
          * This class will never be serialized, but we provide a
          * serialVersionUID to suppress a javac warning.
          */
+        @Serial
         private static final long serialVersionUID = 6138294804551838833L;
 
         /** Thread this worker is running in.  Null if factory fails. */
@@ -768,25 +747,6 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
      * Methods for controlling interrupts to worker threads.
      */
 
-    /**
-     * If there is a security manager, makes sure caller has
-     * permission to shut down threads in general (see shutdownPerm).
-     * If this passes, additionally makes sure the caller is allowed
-     * to interrupt each worker thread. This might not be true even if
-     * first check passed, if the SecurityManager treats some threads
-     * specially.
-     */
-    private void checkShutdownAccess() {
-        // assert mainLock.isHeldByCurrentThread();
-        SecurityManager security = System.getSecurityManager();
-        if (security != null) {
-            security.checkPermission(shutdownPerm);
-            for (Worker w : workers) {
-                security.checkAccess(w.thread);
-            }
-        }
-    }
-
     /**
      * Interrupts all threads, even if active. Ignores SecurityExceptions
      * (in which case some threads may remain uninterrupted).
@@ -1375,12 +1335,11 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
         try {
             executeInternal(command);
         } catch (RejectedExecutionException rx) {
-            if (getQueue() instanceof RetryableQueue) {
+            if (getQueue() instanceof RetryableQueue<Runnable> queue) {
                 // If the Executor is close to maximum pool size, concurrent
                 // calls to execute() may result (due to Tomcat's use of
                 // TaskQueue) in some tasks being rejected rather than queued.
                 // If this happens, add them to the queue.
-                final RetryableQueue<Runnable> queue = (RetryableQueue<Runnable>) getQueue();
                 if (!queue.force(command)) {
                     submittedCount.decrementAndGet();
                     throw new RejectedExecutionException(sm.getString("threadPoolExecutor.queueFull"));
@@ -1467,7 +1426,6 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
         final ReentrantLock mainLock = this.mainLock;
         mainLock.lock();
         try {
-            checkShutdownAccess();
             advanceRunState(SHUTDOWN);
             interruptIdleWorkers();
             onShutdown(); // hook for ScheduledThreadPoolExecutor
@@ -1500,7 +1458,6 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
         final ReentrantLock mainLock = this.mainLock;
         mainLock.lock();
         try {
-            checkShutdownAccess();
             advanceRunState(STOP);
             interruptWorkers();
             tasks = drainQueue();
@@ -2186,8 +2143,7 @@ public class ThreadPoolExecutor extends AbstractExecutorService {
 
     protected boolean currentThreadShouldBeStopped() {
         Thread currentThread = Thread.currentThread();
-        if (threadRenewalDelay >= 0 && currentThread instanceof TaskThread) {
-            TaskThread currentTaskThread = (TaskThread) currentThread;
+        if (threadRenewalDelay >= 0 && currentThread instanceof TaskThread currentTaskThread) {
             return currentTaskThread.getCreationTime() < this.lastContextStoppedTime.longValue();
         }
         return false;
