@@ -17,10 +17,7 @@
 package org.apache.tomcat.websocket;
 
 import java.io.EOFException;
-import java.io.File;
-import java.io.FileInputStream;
 import java.io.IOException;
-import java.io.InputStream;
 import java.net.InetSocketAddress;
 import java.net.Proxy;
 import java.net.ProxySelector;
@@ -31,7 +28,6 @@ import java.nio.ByteBuffer;
 import java.nio.channels.AsynchronousChannelGroup;
 import java.nio.channels.AsynchronousSocketChannel;
 import java.nio.charset.StandardCharsets;
-import java.security.KeyStore;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Base64;
@@ -55,7 +51,6 @@ import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLEngine;
 import javax.net.ssl.SSLException;
 import javax.net.ssl.SSLParameters;
-import javax.net.ssl.TrustManagerFactory;
 
 import jakarta.websocket.ClientEndpoint;
 import jakarta.websocket.ClientEndpointConfig;
@@ -75,7 +70,6 @@ import org.apache.tomcat.InstanceManagerBindings;
 import org.apache.tomcat.util.buf.StringUtils;
 import org.apache.tomcat.util.collections.CaseInsensitiveKeyMap;
 import org.apache.tomcat.util.res.StringManager;
-import org.apache.tomcat.util.security.KeyStoreUtil;
 
 public class WsWebSocketContainer implements WebSocketContainer, BackgroundProcess {
 
@@ -218,8 +212,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
         for (Proxy proxy : proxies) {
             if (proxy.type().equals(Proxy.Type.HTTP)) {
                 sa = proxy.address();
-                if (sa instanceof InetSocketAddress) {
-                    InetSocketAddress inet = (InetSocketAddress) sa;
+                if (sa instanceof InetSocketAddress inet) {
                     if (inet.isUnresolved()) {
                         sa = new InetSocketAddress(inet.getHostName(), inet.getPort());
                     }
@@ -296,9 +289,9 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
                 if (httpResponse.status == Constants.PROXY_AUTHENTICATION_REQUIRED) {
                     return processAuthenticationChallenge(clientEndpointHolder, clientEndpointConfiguration, path,
                             redirectSet, userProperties, request, httpResponse, AuthenticationType.PROXY);
-                } else if (httpResponse.getStatus() != 200) {
+                } else if (httpResponse.status() != 200) {
                     throw new DeploymentException(sm.getString("wsWebSocketContainer.proxyConnectFail", selectedProxy,
-                            Integer.toString(httpResponse.getStatus())));
+                            Integer.toString(httpResponse.status())));
                 }
             }
 
@@ -342,7 +335,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
 
             if (httpResponse.status != 101) {
                 if (isRedirectStatus(httpResponse.status)) {
-                    List<String> locationHeader = httpResponse.getHandshakeResponse().getHeaders()
+                    List<String> locationHeader = httpResponse.handshakeResponse().getHeaders()
                             .get(Constants.LOCATION_HEADER_NAME);
 
                     if (locationHeader == null || locationHeader.isEmpty() || locationHeader.get(0) == null ||
@@ -383,7 +376,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
                             sm.getString("wsWebSocketContainer.invalidStatus", Integer.toString(httpResponse.status)));
                 }
             }
-            HandshakeResponse handshakeResponse = httpResponse.getHandshakeResponse();
+            HandshakeResponse handshakeResponse = httpResponse.handshakeResponse();
             clientEndpointConfiguration.getConfigurator().afterResponse(handshakeResponse);
 
             // Sub-protocol
@@ -478,7 +471,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
                     Integer.valueOf(httpResponse.status), authenticationType.getAuthorizationHeaderName()));
         }
 
-        List<String> authenticateHeaders = httpResponse.getHandshakeResponse().getHeaders()
+        List<String> authenticateHeaders = httpResponse.handshakeResponse().getHeaders()
                 .get(authenticationType.getAuthenticateHeaderName());
 
         if (authenticateHeaders == null || authenticateHeaders.isEmpty() || authenticateHeaders.get(0) == null ||
@@ -893,56 +886,21 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
     }
 
 
-    @SuppressWarnings("removal")
     private SSLEngine createSSLEngine(ClientEndpointConfig clientEndpointConfig, String host, int port)
             throws DeploymentException {
 
-        Map<String, Object> userProperties = clientEndpointConfig.getUserProperties();
         try {
             // See if a custom SSLContext has been provided
             SSLContext sslContext = clientEndpointConfig.getSSLContext();
 
-            // If no SSLContext is found, try the pre WebSocket 2.1 Tomcat
-            // specific method
-            if (sslContext == null) {
-                sslContext = (SSLContext) userProperties.get(Constants.SSL_CONTEXT_PROPERTY);
-            }
-
             if (sslContext == null) {
                 // Create the SSL Context
                 sslContext = SSLContext.getInstance("TLS");
-
-                // Trust store
-                String sslTrustStoreValue = (String) userProperties.get(Constants.SSL_TRUSTSTORE_PROPERTY);
-                if (sslTrustStoreValue != null) {
-                    String sslTrustStorePwdValue = (String) userProperties.get(Constants.SSL_TRUSTSTORE_PWD_PROPERTY);
-                    if (sslTrustStorePwdValue == null) {
-                        sslTrustStorePwdValue = Constants.SSL_TRUSTSTORE_PWD_DEFAULT;
-                    }
-
-                    File keyStoreFile = new File(sslTrustStoreValue);
-                    KeyStore ks = KeyStore.getInstance("JKS");
-                    try (InputStream is = new FileInputStream(keyStoreFile)) {
-                        KeyStoreUtil.load(ks, is, sslTrustStorePwdValue.toCharArray());
-                    }
-
-                    TrustManagerFactory tmf = TrustManagerFactory
-                            .getInstance(TrustManagerFactory.getDefaultAlgorithm());
-                    tmf.init(ks);
-
-                    sslContext.init(null, tmf.getTrustManagers(), null);
-                } else {
-                    sslContext.init(null, null, null);
-                }
+                sslContext.init(null, null, null);
             }
 
             SSLEngine engine = sslContext.createSSLEngine(host, port);
 
-            String sslProtocolsValue = (String) userProperties.get(Constants.SSL_PROTOCOLS_PROPERTY);
-            if (sslProtocolsValue != null) {
-                engine.setEnabledProtocols(sslProtocolsValue.split(","));
-            }
-
             engine.setUseClientMode(true);
 
             // Enable host verification
@@ -1101,23 +1059,6 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
     }
 
 
-    private static class HttpResponse {
-        private final int status;
-        private final HandshakeResponse handshakeResponse;
-
-        HttpResponse(int status, HandshakeResponse handshakeResponse) {
-            this.status = status;
-            this.handshakeResponse = handshakeResponse;
-        }
-
-
-        public int getStatus() {
-            return status;
-        }
-
-
-        public HandshakeResponse getHandshakeResponse() {
-            return handshakeResponse;
-        }
+    private record HttpResponse(int status, HandshakeResponse handshakeResponse) {
     }
 }
