@@ -26,20 +26,21 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentSkipListMap;
 
 import javax.naming.NamingException;
-import javax.servlet.DispatcherType;
-import javax.servlet.FilterRegistration;
-import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import javax.websocket.CloseReason;
-import javax.websocket.CloseReason.CloseCodes;
-import javax.websocket.DeploymentException;
-import javax.websocket.Encoder;
-import javax.websocket.server.ServerContainer;
-import javax.websocket.server.ServerEndpoint;
-import javax.websocket.server.ServerEndpointConfig;
-import javax.websocket.server.ServerEndpointConfig.Configurator;
+
+import jakarta.servlet.DispatcherType;
+import jakarta.servlet.FilterRegistration;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.websocket.CloseReason;
+import jakarta.websocket.CloseReason.CloseCodes;
+import jakarta.websocket.DeploymentException;
+import jakarta.websocket.Encoder;
+import jakarta.websocket.server.ServerContainer;
+import jakarta.websocket.server.ServerEndpoint;
+import jakarta.websocket.server.ServerEndpointConfig;
+import jakarta.websocket.server.ServerEndpointConfig.Configurator;
 
 import org.apache.tomcat.InstanceManager;
 import org.apache.tomcat.util.res.StringManager;
@@ -65,17 +66,12 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
     private final WsWriteTimeout wsWriteTimeout = new WsWriteTimeout();
 
     private final ServletContext servletContext;
-    private final Map<String,ExactPathMatch> configExactMatchMap = new ConcurrentHashMap<>();
-    private final Map<Integer,ConcurrentSkipListMap<String,TemplatePathMatch>> configTemplateMatchMap =
-            new ConcurrentHashMap<>();
-    @SuppressWarnings("deprecation")
-    private volatile boolean enforceNoAddAfterHandshake = org.apache.tomcat.websocket.Constants.STRICT_SPEC_COMPLIANCE;
-    private volatile boolean addAllowed = true;
-    private final Map<String,Set<WsSession>> authenticatedSessions = new ConcurrentHashMap<>();
+    private final Map<String, ExactPathMatch> configExactMatchMap = new ConcurrentHashMap<>();
+    private final Map<Integer, ConcurrentSkipListMap<String, TemplatePathMatch>> configTemplateMatchMap = new ConcurrentHashMap<>();
+    private final Map<String, Set<WsSession>> authenticatedSessions = new ConcurrentHashMap<>();
     private volatile boolean endpointsRegistered = false;
     private volatile boolean deploymentFailed = false;
 
-    @SuppressWarnings("deprecation")
     WsServerContainer(ServletContext servletContext) {
 
         this.servletContext = servletContext;
@@ -92,11 +88,6 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
             setDefaultMaxTextMessageBufferSize(Integer.parseInt(value));
         }
 
-        value = servletContext.getInitParameter(Constants.ENFORCE_NO_ADD_AFTER_HANDSHAKE_CONTEXT_INIT_PARAM);
-        if (value != null) {
-            setEnforceNoAddAfterHandshake(Boolean.parseBoolean(value));
-        }
-
         FilterRegistration.Dynamic fr = servletContext.addFilter("Tomcat WebSocket (JSR356) Filter", new WsFilter());
         if (fr != null) {
             fr.setAsyncSupported(true);
@@ -124,10 +115,6 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
 
     void addEndpoint(ServerEndpointConfig sec, boolean fromAnnotatedPojo) throws DeploymentException {
 
-        if (enforceNoAddAfterHandshake && !addAllowed) {
-            throw new DeploymentException(sm.getString("serverContainer.addNotAllowed"));
-        }
-
         if (servletContext == null) {
             throw new DeploymentException(sm.getString("serverContainer.servletContextMissing"));
         }
@@ -152,7 +139,7 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
             UriTemplate uriTemplate = new UriTemplate(path);
             if (uriTemplate.hasParameters()) {
                 Integer key = Integer.valueOf(uriTemplate.getSegmentCount());
-                ConcurrentSkipListMap<String,TemplatePathMatch> templateMatches = configTemplateMatchMap.get(key);
+                ConcurrentSkipListMap<String, TemplatePathMatch> templateMatches = configTemplateMatchMap.get(key);
                 if (templateMatches == null) {
                     // Ensure that if concurrent threads execute this block they
                     // all end up using the same ConcurrentSkipListMap instance
@@ -165,8 +152,8 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
                 if (oldMatch != null) {
                     // Note: This depends on Endpoint instances being added
                     // before POJOs in WsSci#onStartup()
-                    if (oldMatch.isFromAnnotatedPojo() && !newMatch.isFromAnnotatedPojo() &&
-                            oldMatch.getConfig().getEndpointClass() == newMatch.getConfig().getEndpointClass()) {
+                    if (oldMatch.fromAnnotatedPojo() && !newMatch.fromAnnotatedPojo() &&
+                            oldMatch.config().getEndpointClass() == newMatch.config().getEndpointClass()) {
                         // The WebSocket spec says to ignore the new match in this case
                         templateMatches.put(path, oldMatch);
                     } else {
@@ -182,14 +169,14 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
                 if (oldMatch != null) {
                     // Note: This depends on Endpoint instances being added
                     // before POJOs in WsSci#onStartup()
-                    if (oldMatch.isFromAnnotatedPojo() && !newMatch.isFromAnnotatedPojo() &&
-                            oldMatch.getConfig().getEndpointClass() == newMatch.getConfig().getEndpointClass()) {
+                    if (oldMatch.fromAnnotatedPojo() && !newMatch.fromAnnotatedPojo() &&
+                            oldMatch.config().getEndpointClass() == newMatch.config().getEndpointClass()) {
                         // The WebSocket spec says to ignore the new match in this case
                         configExactMatchMap.put(path, oldMatch);
                     } else {
                         // Duplicate path mappings
                         throw new DeploymentException(sm.getString("serverContainer.duplicatePaths", path,
-                                oldMatch.getConfig().getEndpointClass(), sec.getEndpointClass()));
+                                oldMatch.config().getEndpointClass(), sec.getEndpointClass()));
                     }
                 }
             }
@@ -271,62 +258,9 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
     }
 
 
-    /**
-     * Until the WebSocket specification provides such a mechanism, this Tomcat proprietary method is provided to enable
-     * applications to programmatically determine whether or not to upgrade an individual request to WebSocket.
-     * <p>
-     * Note: This method is not used by Tomcat but is used directly by third-party code and must not be removed.
-     *
-     * @param request    The request object to be upgraded
-     * @param response   The response object to be populated with the result of the upgrade
-     * @param sec        The server endpoint to use to process the upgrade request
-     * @param pathParams The path parameters associated with the upgrade request
-     *
-     * @throws ServletException If a configuration error prevents the upgrade from taking place
-     * @throws IOException      If an I/O error occurs during the upgrade process
-     *
-     * @deprecated This method will be removed in Apache Tomcat 10.1 onwards. It has been replaced by
-     *                 {@link #upgradeHttpToWebSocket(Object, Object, ServerEndpointConfig, Map)}
-     */
-    @Deprecated
-    public void doUpgrade(HttpServletRequest request, HttpServletResponse response, ServerEndpointConfig sec,
-            Map<String,String> pathParams) throws ServletException, IOException {
-        UpgradeUtil.doUpgrade(this, request, response, sec, pathParams);
-    }
-
-
-    /**
-     * Upgrade the HTTP connection represented by the {@code HttpServletRequest} and {@code HttpServletResponse} to the
-     * WebSocket protocol and establish a WebSocket connection as per the provided {@link ServerEndpointConfig}.
-     * <p>
-     * This method is primarily intended to be used by frameworks that implement the front-controller pattern. It does
-     * not deploy the provided endpoint.
-     * <p>
-     * If the WebSocket implementation is not deployed as part of a Jakarta Servlet container, this method will throw an
-     * {@link UnsupportedOperationException}.
-     * <p>
-     * This method will be part of the Jakarta WebSocket API from version 2.1
-     *
-     * @param httpServletRequest  The {@code HttpServletRequest} to be processed as a WebSocket handshake as per section
-     *                                4.0 of RFC 6455.
-     * @param httpServletResponse The {@code HttpServletResponse} to be used when processing the
-     *                                {@code httpServletRequest} as a WebSocket handshake as per section 4.0 of RFC
-     *                                6455.
-     * @param sec                 The server endpoint configuration to use to configure the WebSocket endpoint
-     * @param pathParameters      Provides a mapping of path parameter names and values, if any, to be used for the
-     *                                WebSocket connection established by the call to this method. If no such mapping is
-     *                                defined, an empty Map must be passed.
-     *
-     * @throws IllegalStateException         if the provided request does not meet the requirements of the WebSocket
-     *                                           handshake
-     * @throws UnsupportedOperationException if the WebSocket implementation is not deployed as part of a Jakarta
-     *                                           Servlet container
-     * @throws IOException                   if an I/O error occurs during the establishment of a WebSocket connection
-     * @throws DeploymentException           if a configuration error prevents the establishment of a WebSocket
-     *                                           connection
-     */
+    @Override
     public void upgradeHttpToWebSocket(Object httpServletRequest, Object httpServletResponse, ServerEndpointConfig sec,
-            Map<String,String> pathParameters) throws IOException, DeploymentException {
+            Map<String, String> pathParameters) throws IOException, DeploymentException {
         try {
             UpgradeUtil.doUpgrade(this, (HttpServletRequest) httpServletRequest,
                     (HttpServletResponse) httpServletResponse, sec, pathParameters);
@@ -338,16 +272,10 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
 
     public WsMappingResult findMapping(String path) {
 
-        // Prevent registering additional endpoints once the first attempt has
-        // been made to use one
-        if (addAllowed) {
-            addAllowed = false;
-        }
-
         // Check an exact match. Simple case as there are no templates.
         ExactPathMatch match = configExactMatchMap.get(path);
         if (match != null) {
-            return new WsMappingResult(match.getConfig(), Collections.emptyMap());
+            return new WsMappingResult(match.config(), Collections.emptyMap());
         }
 
         // No exact match. Need to look for template matches.
@@ -361,7 +289,7 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
 
         // Number of segments has to match
         Integer key = Integer.valueOf(pathUriTemplate.getSegmentCount());
-        ConcurrentSkipListMap<String,TemplatePathMatch> templateMatches = configTemplateMatchMap.get(key);
+        ConcurrentSkipListMap<String, TemplatePathMatch> templateMatches = configTemplateMatchMap.get(key);
 
         if (templateMatches == null) {
             // No templates with an equal number of segments so there will be
@@ -372,11 +300,11 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
         // List is in alphabetical order of normalised templates.
         // Correct match is the first one that matches.
         ServerEndpointConfig sec = null;
-        Map<String,String> pathParams = null;
+        Map<String, String> pathParams = null;
         for (TemplatePathMatch templateMatch : templateMatches.values()) {
-            pathParams = templateMatch.getUriTemplate().match(pathUriTemplate);
+            pathParams = templateMatch.uriTemplate().match(pathUriTemplate);
             if (pathParams != null) {
-                sec = templateMatch.getConfig();
+                sec = templateMatch.config();
                 break;
             }
         }
@@ -390,18 +318,6 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
     }
 
 
-    @Deprecated
-    public boolean isEnforceNoAddAfterHandshake() {
-        return enforceNoAddAfterHandshake;
-    }
-
-
-    @Deprecated
-    public void setEnforceNoAddAfterHandshake(boolean enforceNoAddAfterHandshake) {
-        this.enforceNoAddAfterHandshake = enforceNoAddAfterHandshake;
-    }
-
-
     protected WsWriteTimeout getTimeout() {
         return wsWriteTimeout;
     }
@@ -467,7 +383,7 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
             for (WsSession wsSession : wsSessions) {
                 try {
                     wsSession.close(AUTHENTICATED_HTTP_SESSION_CLOSED);
-                } catch (IOException ignore) {
+                } catch (IOException e) {
                     // Any IOExceptions during close will have been caught and the
                     // onError method called.
                 }
@@ -498,51 +414,11 @@ public class WsServerContainer extends WsWebSocketContainer implements ServerCon
     }
 
 
-    private static class TemplatePathMatch {
-        private final ServerEndpointConfig config;
-        private final UriTemplate uriTemplate;
-        private final boolean fromAnnotatedPojo;
-
-        TemplatePathMatch(ServerEndpointConfig config, UriTemplate uriTemplate, boolean fromAnnotatedPojo) {
-            this.config = config;
-            this.uriTemplate = uriTemplate;
-            this.fromAnnotatedPojo = fromAnnotatedPojo;
-        }
-
-
-        public ServerEndpointConfig getConfig() {
-            return config;
-        }
-
-
-        public UriTemplate getUriTemplate() {
-            return uriTemplate;
-        }
-
-
-        public boolean isFromAnnotatedPojo() {
-            return fromAnnotatedPojo;
-        }
+    private record TemplatePathMatch(ServerEndpointConfig config, UriTemplate uriTemplate,
+                                     boolean fromAnnotatedPojo) {
     }
 
 
-    private static class ExactPathMatch {
-        private final ServerEndpointConfig config;
-        private final boolean fromAnnotatedPojo;
-
-        ExactPathMatch(ServerEndpointConfig config, boolean fromAnnotatedPojo) {
-            this.config = config;
-            this.fromAnnotatedPojo = fromAnnotatedPojo;
-        }
-
-
-        public ServerEndpointConfig getConfig() {
-            return config;
-        }
-
-
-        public boolean isFromAnnotatedPojo() {
-            return fromAnnotatedPojo;
-        }
+    private record ExactPathMatch(ServerEndpointConfig config, boolean fromAnnotatedPojo) {
     }
 }
