@@ -23,6 +23,7 @@ import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
 import java.net.HttpURLConnection;
+import java.net.URI;
 import java.net.URL;
 import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
@@ -45,8 +46,8 @@ import org.junit.Assert;
 import org.junit.Test;
 
 import org.apache.catalina.Context;
+import org.apache.catalina.Globals;
 import org.apache.catalina.authenticator.BasicAuthenticator;
-import org.apache.catalina.filters.FailedRequestFilter;
 import org.apache.catalina.startup.SimpleHttpClient;
 import org.apache.catalina.startup.TesterMapRealm;
 import org.apache.catalina.startup.Tomcat;
@@ -54,8 +55,7 @@ import org.apache.catalina.startup.TomcatBaseTest;
 import org.apache.tomcat.unittest.TesterRequest;
 import org.apache.tomcat.util.buf.ByteChunk;
 import org.apache.tomcat.util.buf.EncodedSolidusHandling;
-import org.apache.tomcat.util.descriptor.web.FilterDef;
-import org.apache.tomcat.util.descriptor.web.FilterMap;
+import org.apache.tomcat.util.buf.StringUtils;
 import org.apache.tomcat.util.descriptor.web.LoginConfig;
 
 /**
@@ -71,7 +71,7 @@ public class TestRequest extends TomcatBaseTest {
      */
     @Test
     public void testBug37794() {
-        Bug37794Client client = new Bug37794Client(true);
+        Bug37794Client client = new Bug37794Client();
 
         // Edge cases around zero
         client.doRequest(-1, false); // Unlimited
@@ -110,22 +110,6 @@ public class TestRequest extends TomcatBaseTest {
         Assert.assertTrue(client.isResponseBodyOK());
     }
 
-    /**
-     * Additional test for failed requests handling when no FailedRequestFilter
-     * is defined.
-     */
-    @Test
-    public void testBug37794withoutFilter() {
-        Bug37794Client client = new Bug37794Client(false);
-
-        // Edge cases around actual content length
-        client.reset();
-        client.doRequest(6, false); // Too small should fail
-        // Response code will be OK, but parameters list will be empty
-        Assert.assertTrue(client.isResponse200());
-        Assert.assertEquals("", client.getResponseBody());
-    }
-
     private static class Bug37794Servlet extends HttpServlet {
 
         private static final long serialVersionUID = 1L;
@@ -155,14 +139,8 @@ public class TestRequest extends TomcatBaseTest {
      */
     private class Bug37794Client extends SimpleHttpClient {
 
-        private final boolean createFilter;
-
         private boolean init;
 
-        Bug37794Client(boolean createFilter) {
-            this.createFilter = createFilter;
-        }
-
         private synchronized void init() throws Exception {
             if (init) {
               return;
@@ -173,18 +151,6 @@ public class TestRequest extends TomcatBaseTest {
             Tomcat.addServlet(root, "Bug37794", new Bug37794Servlet());
             root.addServletMappingDecoded("/test", "Bug37794");
 
-            if (createFilter) {
-                FilterDef failedRequestFilter = new FilterDef();
-                failedRequestFilter.setFilterName("failedRequestFilter");
-                failedRequestFilter.setFilterClass(
-                        FailedRequestFilter.class.getName());
-                FilterMap failedRequestFilterMap = new FilterMap();
-                failedRequestFilterMap.setFilterName("failedRequestFilter");
-                failedRequestFilterMap.addURLPatternDecoded("/*");
-                root.addFilterDef(failedRequestFilter);
-                root.addFilterMap(failedRequestFilterMap);
-            }
-
             tomcat.start();
 
             setPort(tomcat.getConnector().getLocalPort());
@@ -208,7 +174,7 @@ public class TestRequest extends TomcatBaseTest {
                     request[0] =
                         "POST http://localhost:8080/test HTTP/1.1" + CRLF +
                         "Host: localhost:8080" + CRLF +
-                        "content-type: application/x-www-form-urlencoded" + CRLF +
+                        SimpleHttpClient.HTTP_HEADER_CONTENT_TYPE_FORM_URL_ENCODING +
                         "Transfer-Encoding: CHUNKED" + CRLF +
                         "Connection: close" + CRLF +
                         CRLF +
@@ -218,7 +184,7 @@ public class TestRequest extends TomcatBaseTest {
                     request[0] =
                         "POST http://localhost:8080/test HTTP/1.1" + CRLF +
                         "Host: localhost:8080" + CRLF +
-                        "content-type: application/x-www-form-urlencoded" + CRLF +
+                        SimpleHttpClient.HTTP_HEADER_CONTENT_TYPE_FORM_URL_ENCODING +
                         "Transfer-Encoding: chunked" + CRLF +
                         "Connection: close" + CRLF +
                         CRLF +
@@ -420,7 +386,7 @@ public class TestRequest extends TomcatBaseTest {
         // Make sure POST works properly
         //
         // POST with separate GET and POST parameters
-        client.doRequest("POST", "foo=bar", "application/x-www-form-urlencoded", "bar=baz", true);
+        client.doRequest("POST", "foo=bar", Globals.CONTENT_TYPE_FORM_URL_ENCODING, "bar=baz", true);
 
         Assert.assertTrue("Non-200 response for POST request",
                    client.isResponse200());
@@ -431,7 +397,7 @@ public class TestRequest extends TomcatBaseTest {
         client.reset();
 
         // POST with overlapping GET and POST parameters
-        client.doRequest("POST", "foo=bar&bar=foo", "application/x-www-form-urlencoded", "bar=baz&foo=baz", true);
+        client.doRequest("POST", "foo=bar&bar=foo", Globals.CONTENT_TYPE_FORM_URL_ENCODING, "bar=baz&foo=baz", true);
 
         Assert.assertTrue("Non-200 response for POST request",
                    client.isResponse200());
@@ -442,7 +408,7 @@ public class TestRequest extends TomcatBaseTest {
         client.reset();
 
         // PUT without POST-style parsing
-        client.doRequest("PUT", "foo=bar&bar=foo", "application/x-www-form-urlencoded", "bar=baz&foo=baz", false);
+        client.doRequest("PUT", "foo=bar&bar=foo", Globals.CONTENT_TYPE_FORM_URL_ENCODING, "bar=baz&foo=baz", false);
 
         Assert.assertTrue("Non-200 response for PUT/noparse request",
                    client.isResponse200());
@@ -453,7 +419,7 @@ public class TestRequest extends TomcatBaseTest {
         client.reset();
 
         // PUT with POST-style parsing
-        client.doRequest("PUT", "foo=bar&bar=foo", "application/x-www-form-urlencoded", "bar=baz&foo=baz", true);
+        client.doRequest("PUT", "foo=bar&bar=foo", Globals.CONTENT_TYPE_FORM_URL_ENCODING, "bar=baz&foo=baz", true);
 
         Assert.assertTrue("Non-200 response for PUT request",
                    client.isResponse200());
@@ -462,14 +428,6 @@ public class TestRequest extends TomcatBaseTest {
                      client.getResponseBody());
 
         client.reset();
-
-        /*
-        private Exception doRequest(String method,
-                                    String queryString,
-                                    String contentType,
-                                    String requestBody,
-                                    boolean allowBody) {
-        */
     }
 
     @Test
@@ -485,7 +443,7 @@ public class TestRequest extends TomcatBaseTest {
         HttpURLConnection conn = getConnection("http://localhost:" + getPort()
                 + "/parseParametersBeforeParseParts");
 
-        prepareRequestBug54984(conn);
+        prepareMultiPartRequest(conn);
 
         checkResponseBug54984(conn);
 
@@ -493,7 +451,7 @@ public class TestRequest extends TomcatBaseTest {
 
         conn = getConnection("http://localhost:" + getPort() + "/");
 
-        prepareRequestBug54984(conn);
+        prepareMultiPartRequest(conn);
 
         checkResponseBug54984(conn);
 
@@ -625,7 +583,7 @@ public class TestRequest extends TomcatBaseTest {
 
     private HttpURLConnection getConnection(String query) throws IOException {
         URL postURL;
-        postURL = new URL(query);
+        postURL = URI.create(query).toURL();
         HttpURLConnection conn = (HttpURLConnection) postURL.openConnection();
         conn.setRequestMethod("POST");
 
@@ -659,7 +617,7 @@ public class TestRequest extends TomcatBaseTest {
         }
     }
 
-    private void prepareRequestBug54984(HttpURLConnection conn)
+    private void prepareMultiPartRequest(HttpURLConnection conn)
             throws Exception {
         String boundary = "-----" + System.currentTimeMillis();
         conn.setRequestProperty("Content-Type",
@@ -904,7 +862,7 @@ public class TestRequest extends TomcatBaseTest {
 
 
     @Test
-    public void testGetReaderInvalidEbcoding() throws Exception {
+    public void testGetReaderInvalidEncoding() throws Exception {
         doTestGetReader("X-Invalid", false);
     }
 
@@ -963,4 +921,143 @@ public class TestRequest extends TomcatBaseTest {
             req.getReader();
         }
     }
+
+
+    /*
+     * https://bz.apache.org/bugzilla/show_bug.cgi?id=69442
+     */
+    @Test
+    public void testTestParameterMediaTypeLowerCase() throws Exception {
+        // toLowerCase() is unnecessary but keep it in case the constant is changed in the future
+        doTestParameterMediaTypeCase(Globals.CONTENT_TYPE_FORM_URL_ENCODING.toLowerCase(Locale.ENGLISH));
+    }
+
+
+    /*
+     * https://bz.apache.org/bugzilla/show_bug.cgi?id=69442
+     */
+    @Test
+    public void testTestParameterMediaTypeUpperCase() throws Exception {
+        doTestParameterMediaTypeCase(Globals.CONTENT_TYPE_FORM_URL_ENCODING.toUpperCase(Locale.ENGLISH));
+    }
+
+
+    private void doTestParameterMediaTypeCase(String contentType) throws Exception {
+        // Setup Tomcat instance
+        Tomcat tomcat = getTomcatInstance();
+
+        // No file system docBase required
+        Context ctx = getProgrammaticRootContext();
+
+        Tomcat.addServlet(ctx, "servlet", new Bug69442Servlet());
+        ctx.addServletMappingDecoded("/", "servlet");
+
+        tomcat.start();
+
+        ByteChunk bc = new ByteChunk();
+        Map<String,List<String>> reqHeaders = new HashMap<>();
+        reqHeaders.put("Content-Type", Arrays.asList(contentType));
+        postUrl("a=b&c=d".getBytes(), "http://localhost:" + getPort() + "/", bc, reqHeaders, null);
+        String responseBody = bc.toString();
+        Assert.assertTrue(responseBody, responseBody.contains("a=b"));
+        Assert.assertTrue(responseBody, responseBody.contains("c=d"));
+    }
+
+
+    private static class Bug69442Servlet extends HttpServlet {
+
+        private static final long serialVersionUID = 1L;
+
+        @Override
+        protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
+            resp.setContentType("text/plain");
+            resp.setCharacterEncoding(StandardCharsets.UTF_8);
+            PrintWriter pw = resp.getWriter();
+            Enumeration<String> names = req.getParameterNames();
+            while (names.hasMoreElements()) {
+                String name = names.nextElement();
+                String[] values = req.getParameterValues(name);
+                pw.println(name + "=" + StringUtils.join(values));
+            }
+        }
+    }
+
+
+    /*
+     * getParameter should work with a multipart/form-data request if there is no multipart config.
+     */
+    @Test
+    public void testBug69690a() throws Exception {
+        Tomcat tomcat = getTomcatInstance();
+        Context ctx = getProgrammaticRootContext();
+        Tomcat.addServlet(ctx, "Bug69690", new Bug69690Servlet());
+        ctx.addServletMappingDecoded("/", "Bug69690");
+        tomcat.start();
+
+        HttpURLConnection conn = getConnection("http://localhost:" + getPort() + "/parameter?a=b");
+
+        prepareMultiPartRequest(conn);
+
+        List<String> response = new ArrayList<>();
+        int status = conn.getResponseCode();
+        if (status == HttpURLConnection.HTTP_OK) {
+            try (InputStreamReader isr = new InputStreamReader(conn.getInputStream(), "UTF-8");
+                    BufferedReader reader = new BufferedReader(isr)) {
+                String line = null;
+                while ((line = reader.readLine()) != null) {
+                    response.add(line);
+                }
+                Assert.assertTrue(response.contains("OK"));
+            }
+        } else {
+            Assert.fail("OK status was expected: " + status);
+        }
+
+        conn.disconnect();
+    }
+
+
+    /*
+     * getPart should not work with a multipart/form-data request if there is no multipart config.
+     */
+    @Test
+    public void testBug69690b() throws Exception {
+        Tomcat tomcat = getTomcatInstance();
+        Context ctx = getProgrammaticRootContext();
+        Tomcat.addServlet(ctx, "Bug69690", new Bug69690Servlet());
+        ctx.addServletMappingDecoded("/", "Bug69690");
+        tomcat.start();
+
+        HttpURLConnection conn = getConnection("http://localhost:" + getPort() + "/part?a=b");
+
+        prepareMultiPartRequest(conn);
+
+        Assert.assertEquals(HttpServletResponse.SC_INTERNAL_SERVER_ERROR, conn.getResponseCode());
+
+        conn.disconnect();
+    }
+
+
+    private class Bug69690Servlet extends HttpServlet {
+
+        private static final long serialVersionUID = 1L;
+
+        @Override
+        protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
+            resp.setCharacterEncoding(StandardCharsets.UTF_8);
+            resp.setContentType("text/plain");
+            PrintWriter pw = resp.getWriter();
+
+            if (req.getRequestURI().endsWith("/parameter")) {
+                if ("b".equals(req.getParameter("a"))) {
+                    pw.print("OK");
+                } else {
+                    pw.print("FAIL - Parameter 'a' not set to 'b'");
+                }
+            } else {
+                // This should trigger an error since the servlet does not have a multi-part configuration.
+                req.getPart("any");
+            }
+        }
+    }
 }
