@@ -23,6 +23,7 @@ import java.io.Serializable;
 import java.lang.reflect.Field;
 import java.net.HttpURLConnection;
 import java.net.Socket;
+import java.net.URI;
 import java.net.URL;
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
@@ -1339,7 +1340,7 @@ public class TestNonBlockingAPI extends TomcatBaseTest {
     public static int postUrlWithDisconnect(boolean stream, BytesStreamer streamer, String path,
             Map<String, List<String>> reqHead, Map<String, List<String>> resHead) throws IOException {
 
-        URL url = new URL(path);
+        URL url = URI.create(path).toURL();
         HttpURLConnection connection = (HttpURLConnection) url.openConnection();
         connection.setDoOutput(true);
         connection.setReadTimeout(1000000);
@@ -2142,4 +2143,161 @@ public class TestNonBlockingAPI extends TomcatBaseTest {
             // NO-OP
         }
     }
+
+
+    @Test
+    public void testNonBlockingWriteWithClose() throws Exception {
+        AtomicBoolean asyncContextIsComplete = new AtomicBoolean(false);
+        AtomicBoolean asyncContextIsError = new AtomicBoolean(false);
+
+        CountDownLatch beforeCloseLatch = new CountDownLatch(1);
+        CountDownLatch afterCloseLatch = new CountDownLatch(1);
+
+        AtomicInteger written = new AtomicInteger(-1);
+
+        Tomcat tomcat = getTomcatInstance();
+        // Note: Low values of socket.txBufSize can trigger very poor
+        //       performance.
+        Assert.assertTrue(tomcat.getConnector().setProperty("socket.txBufSize", "524228"));
+
+        // No file system docBase required
+        Context ctx = getProgrammaticRootContext();
+
+        TesterAccessLogValve alv = new TesterAccessLogValve();
+        ctx.getPipeline().addValve(alv);
+
+        NBWriteWithCloseServlet servlet = new NBWriteWithCloseServlet(
+                asyncContextIsComplete, asyncContextIsError, beforeCloseLatch, afterCloseLatch, written);
+        String servletName = NBWriteWithCloseServlet.class.getName();
+        Tomcat.addServlet(ctx, servletName, servlet);
+        ctx.addServletMappingDecoded("/", servletName);
+
+        tomcat.start();
+
+        SocketFactory factory = SocketFactory.getDefault();
+        Socket s = factory.createSocket("localhost", getPort());
+
+        OutputStream os = s.getOutputStream();
+        os.write(("GET / HTTP/1.1\r\n" +
+                "Host: localhost:" + getPort() + "\r\n" +
+                "Connection: close\r\n" +
+                "\r\n").getBytes(StandardCharsets.ISO_8859_1));
+        os.flush();
+
+        // Wait for Servlet to fill write buffer
+        beforeCloseLatch.await();
+        // Close should return immediately
+        long start = System.nanoTime();
+        afterCloseLatch.await();
+        long duration = System.nanoTime() - start;
+
+        Assert.assertTrue("Close took [" + duration + "] ns", duration < 1_000_000_000);
+
+        // Read the body
+        InputStream is = s.getInputStream();
+        int read = 0;
+        byte[] buffer = new byte[8192];
+        do {
+            read = is.read(buffer);
+        } while (read != -1);
+
+        os.close();
+        is.close();
+        s.close();
+
+        Assert.assertTrue(asyncContextIsComplete.get());
+    }
+
+
+    @WebServlet(asyncSupported = true)
+    public static class NBWriteWithCloseServlet extends HttpServlet {
+        private static final long serialVersionUID = 1L;
+        private final AtomicBoolean asyncContextIsComplete;
+        private final AtomicBoolean asyncContextIsError;
+        private final CountDownLatch beforeCloseLatch;
+        private final CountDownLatch afterCloseLatch;
+        private final AtomicInteger written;
+
+        public NBWriteWithCloseServlet(AtomicBoolean asyncContextIsComplete, AtomicBoolean asyncContextIsError,
+                CountDownLatch beforeCloseLatch, CountDownLatch afterCloseLatch, AtomicInteger written) {
+            this.asyncContextIsComplete = asyncContextIsComplete;
+            this.asyncContextIsError = asyncContextIsError;
+            this.beforeCloseLatch = beforeCloseLatch;
+            this.afterCloseLatch = afterCloseLatch;
+            this.written = written;
+        }
+
+        @Override
+        protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
+            AsyncContext actx = req.startAsync();
+            actx.setTimeout(Long.MAX_VALUE);
+            actx.addListener(new AsyncListener() {
+
+                @Override
+                public void onTimeout(AsyncEvent event) throws IOException {
+                    log.info("onTimeout");
+                }
+
+                @Override
+                public void onStartAsync(AsyncEvent event) throws IOException {
+                    log.info("onStartAsync");
+                }
+
+                @Override
+                public void onError(AsyncEvent event) throws IOException {
+                    log.info("AsyncListener.onError");
+                    asyncContextIsError.set(true);
+                }
+
+                @Override
+                public void onComplete(AsyncEvent event) throws IOException {
+                    log.info("onComplete");
+                    asyncContextIsComplete.set(true);
+                }
+            });
+
+            // Write until buffer is full
+            ServletOutputStream out = resp.getOutputStream();
+            TestWriteListener03 writeListener = new TestWriteListener03(actx, beforeCloseLatch, afterCloseLatch);
+            out.setWriteListener(writeListener);
+
+            written.set(writeListener.written);
+        }
+    }
+
+
+    private static class TestWriteListener03 implements WriteListener {
+        private final AsyncContext ctx;
+        private final CountDownLatch beforeCloseLatch;
+        private final CountDownLatch afterCloseLatch;
+        int written = 0;
+
+        TestWriteListener03(AsyncContext ctx, CountDownLatch beforeCloseLatch, CountDownLatch afterCloseLatch) {
+            this.ctx = ctx;
+            this.beforeCloseLatch = beforeCloseLatch;
+            this.afterCloseLatch = afterCloseLatch;
+        }
+
+        @Override
+        public void onWritePossible() throws IOException {
+            if (written == 0) {
+                // Write until the buffer is full and then close the stream
+                while (ctx.getResponse().getOutputStream().isReady()) {
+                    ctx.getResponse().getOutputStream().write(DATA, written, CHUNK_SIZE);
+                    written += CHUNK_SIZE;
+                }
+                beforeCloseLatch.countDown();
+                ctx.getResponse().getOutputStream().close();
+                afterCloseLatch.countDown();
+            } else {
+                ctx.complete();
+            }
+        }
+
+        @Override
+        public void onError(Throwable throwable) {
+            log.info("WriteListener.onError");
+            throwable.printStackTrace();
+        }
+    }
 }
\ No newline at end of file
