@@ -24,26 +24,17 @@ import java.io.OutputStream;
 import java.io.PrintWriter;
 import java.net.HttpURLConnection;
 import java.net.InetAddress;
+import java.net.URI;
 import java.net.URL;
 import java.nio.file.FileVisitResult;
 import java.nio.file.FileVisitor;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.attribute.BasicFileAttributes;
-import java.util.ArrayList;
-import java.util.Collections;
 import java.util.Enumeration;
 import java.util.HashMap;
-import java.util.IdentityHashMap;
 import java.util.List;
-import java.util.Locale;
 import java.util.Map;
-import java.util.function.Consumer;
-import java.util.function.Predicate;
-import java.util.logging.Handler;
-import java.util.logging.Level;
-import java.util.logging.LogRecord;
-import java.util.logging.Logger;
 
 import jakarta.servlet.ServletContext;
 import jakarta.servlet.ServletException;
@@ -57,13 +48,8 @@ import org.junit.Assert;
 import org.junit.Before;
 
 import org.apache.catalina.Container;
-import org.apache.catalina.ContainerEvent;
-import org.apache.catalina.ContainerListener;
 import org.apache.catalina.Context;
-import org.apache.catalina.Lifecycle;
-import org.apache.catalina.LifecycleEvent;
 import org.apache.catalina.LifecycleException;
-import org.apache.catalina.LifecycleListener;
 import org.apache.catalina.LifecycleState;
 import org.apache.catalina.Manager;
 import org.apache.catalina.Server;
@@ -79,8 +65,6 @@ import org.apache.catalina.webresources.StandardRoot;
 import org.apache.coyote.http11.Http11NioProtocol;
 import org.apache.tomcat.util.buf.ByteChunk;
 import org.apache.tomcat.util.collections.CaseInsensitiveKeyMap;
-import org.apache.tomcat.util.http.Method;
-import org.apache.tomcat.util.res.StringManager;
 import org.apache.tomcat.util.scan.StandardJarScanFilter;
 import org.apache.tomcat.util.scan.StandardJarScanner;
 
@@ -153,13 +137,8 @@ public abstract class TomcatBaseTest extends LoggingBaseTest {
         ((StandardJarScanner) ctx.getJarScanner()).setScanClassPath(false);
         return ctx;
     }
-    public Context getProgrammaticRootContextWithManager() {
-        Context ctx = getProgrammaticRootContext();
-        if (ctx.getManager() == null) {
-            ctx.setManager(new StandardManager());
-        }
-        return ctx;
-    }
+
+
     /*
      * Sub-classes need to know port so they can connect
      */
@@ -565,7 +544,7 @@ public abstract class TomcatBaseTest extends LoggingBaseTest {
                         value.append(';');
                     }
                 }
-                out.println("PARAM:" + name + ": " + value);
+                out.println("PARAM/" + name + ": " + value);
             }
 
             out.println("SESSION-REQUESTED-ID: " +
@@ -596,7 +575,7 @@ public abstract class TomcatBaseTest extends LoggingBaseTest {
             }
 
             int bodySize = 0;
-            if (Method.PUT.equals(request.getMethod())) {
+            if ("PUT".equalsIgnoreCase(request.getMethod())) {
                 InputStream is = request.getInputStream();
                 int read = 0;
                 byte[] buffer = new byte[8192];
@@ -654,12 +633,12 @@ public abstract class TomcatBaseTest extends LoggingBaseTest {
 
     public static int getUrl(String path, ByteChunk out, boolean followRedirects)
             throws IOException {
-        return methodUrl(path, out, DEFAULT_CLIENT_TIMEOUT_MS, null, null, Method.GET, followRedirects);
+        return methodUrl(path, out, DEFAULT_CLIENT_TIMEOUT_MS, null, null, "GET", followRedirects);
     }
 
     public static int headUrl(String path, ByteChunk out, Map<String, List<String>> resHead)
             throws IOException {
-        return methodUrl(path, out, DEFAULT_CLIENT_TIMEOUT_MS, null, resHead, Method.HEAD);
+        return methodUrl(path, out, DEFAULT_CLIENT_TIMEOUT_MS, null, resHead, "HEAD");
     }
 
     public static int getUrl(String path, ByteChunk out, Map<String, List<String>> reqHead,
@@ -670,7 +649,7 @@ public abstract class TomcatBaseTest extends LoggingBaseTest {
     public static int getUrl(String path, ByteChunk out, int readTimeout,
             Map<String, List<String>> reqHead, Map<String, List<String>> resHead)
             throws IOException {
-        return methodUrl(path, out, readTimeout, reqHead, resHead, Method.GET);
+        return methodUrl(path, out, readTimeout, reqHead, resHead, "GET");
     }
 
     public static int methodUrl(String path, ByteChunk out, int readTimeout,
@@ -683,7 +662,7 @@ public abstract class TomcatBaseTest extends LoggingBaseTest {
                 Map<String, List<String>> reqHead, Map<String, List<String>> resHead, String method,
                 boolean followRedirects) throws IOException {
 
-        URL url = new URL(path);
+        URL url = URI.create(path).toURL();
         HttpURLConnection connection = (HttpURLConnection) url.openConnection();
         connection.setUseCaches(false);
         connection.setReadTimeout(readTimeout);
@@ -777,7 +756,7 @@ public abstract class TomcatBaseTest extends LoggingBaseTest {
                 Map<String, List<String>> reqHead,
                 Map<String, List<String>> resHead) throws IOException {
 
-        URL url = new URL(path);
+        URL url = URI.create(path).toURL();
         HttpURLConnection connection =
             (HttpURLConnection) url.openConnection();
         connection.setDoOutput(true);
@@ -946,214 +925,4 @@ public abstract class TomcatBaseTest extends LoggingBaseTest {
             session.setMaxInactiveInterval(newIntervalSecs);
         }
     }
-
-    /**
-     * Captures logs for the given logger names in the current ClassLoader.
-     */
-    public static class LogCapture implements AutoCloseable {
-        protected final Level level;
-        protected final String[] loggerNames;
-        protected final List<LogRecord> logRecords = Collections.synchronizedList(new ArrayList<>());
-        protected final Map<Logger, Level> previousLevelsOfLoggersMap = new IdentityHashMap<>();
-        private volatile boolean installed = false;
-        protected final Handler handler = new Handler() {
-            @Override
-            public void publish(LogRecord record) {
-                logRecords.add(record);
-            }
-
-            @Override
-            public void flush() {
-            }
-
-            @Override
-            public void close() throws SecurityException {
-                logRecords.clear();
-            }
-        };
-        public LogCapture(Level level, String... loggerNames) {
-            this.level = level;
-            this.loggerNames = loggerNames;
-        }
-
-        public void attach() {
-            if (!installed) {
-                for (String name : loggerNames) {
-                    Logger logger = Logger.getLogger(name);
-                    logger.addHandler(handler);
-                    if (level != null) {
-                        previousLevelsOfLoggersMap.put(logger, logger.getLevel());
-                        logger.setLevel(level);
-                    }
-                }
-                installed = true;
-            }
-        }
-
-        public boolean containsText(CharSequence s) {
-            for (LogRecord record : logRecords) {
-                if (record.getMessage().contains(s)) {
-                    return true;
-                }
-            }
-            return false;
-        }
-        public boolean hasException(Class<? extends Throwable> type) {
-            for (LogRecord record : logRecords) {
-                Throwable t = record.getThrown();
-                while (t != null) {
-                    if (type.isInstance(t)) {return true;}
-                    t = t.getCause();
-                }
-            }
-            return false;
-        }
-
-        @Override
-        public void close() throws Exception {
-            for (Logger l : previousLevelsOfLoggersMap.keySet()) {
-                try {
-                    l.removeHandler(handler);
-                } catch (Throwable ignore) {
-                }
-                try {
-                    l.setLevel(previousLevelsOfLoggersMap.get(l));
-                } catch (Throwable ignore) {
-                }
-            }
-            previousLevelsOfLoggersMap.clear();
-        }
-    }
-
-    public static LogCapture attachLogCapture(Level level, String... loggerNames) {
-        LogCapture logCapture = new LogCapture(level, loggerNames);
-        logCapture.attach();
-        return logCapture;
-    }
-
-    /**
-     * Captures webapp-scoped logs (e.g. ContextConfig/Digester) during the
-     * CONFIGURE_START phase of a {@link Context}.
-     */
-    public static class WebappLogCapture extends LogCapture implements LifecycleListener {
-        private String lifecycleEvent = Lifecycle.CONFIGURE_START_EVENT;
-        public WebappLogCapture(String lifecycleEvent, Level level, String... loggerNames) {
-            this(level, loggerNames);
-            this.lifecycleEvent = lifecycleEvent;
-        }
-        public WebappLogCapture(Level level, String... loggerNames) {
-            super(level, loggerNames);
-        }
-
-        @Override
-        public void lifecycleEvent(LifecycleEvent event) {
-            if (this.lifecycleEvent.equals(event.getType())) {
-                this.attach();
-            }
-        }
-    }
-
-    /**
-     * Installs a {@link WebappLogCapture} on the given {@link Context} so it runs
-     * before {@link ContextConfig} during CONFIGURE_START.
-     * @param ctx         the webapp context
-     * @param level       level for loggers (e.g. {@code Level.ALL})
-     * @param loggerNames fully-qualified logger names
-     * @return the active capture
-     */
-    public static WebappLogCapture attachWebappLogCapture(Context ctx, Level level, String... loggerNames) {
-        List<LifecycleListener> lifecycleListenersToReAdd = new ArrayList<>();
-        for (LifecycleListener l : ctx.findLifecycleListeners()) {
-            if (l instanceof ContextConfig) {
-                lifecycleListenersToReAdd.add(l);
-            }
-        }
-        for (LifecycleListener l : lifecycleListenersToReAdd) {
-            ctx.removeLifecycleListener(l);
-        }
-        WebappLogCapture webappLogCapture = new WebappLogCapture(level, loggerNames);
-        ctx.addLifecycleListener(webappLogCapture);
-        for (LifecycleListener l : lifecycleListenersToReAdd) {
-            ctx.addLifecycleListener(l);
-        }
-        return webappLogCapture;
-    }
-
-    /**
-     * Returns the localized key in a LocalStrings.properties file.
-     *
-     * @param packagePath The package that contains LocalStrings.properties, e.g. 'org.apache.catalina.startup'
-     * @param key           The key to find, e.g. 'versionLoggerListener.serverInfo.server.built'
-     * @param locale        The locale to use, e.g. Locale.ENGLISH
-     * @return The prefix before the first argument placeholder and if no placeholder, returns the whole formatted string.
-     */
-    public static String getKeyFromPropertiesFile(String packagePath, String key, Locale locale) {
-        StringManager sm;
-        if (locale != null) {
-            sm = StringManager.getManager(packagePath, locale);
-        } else {
-            sm = StringManager.getManager(packagePath);
-        }
-
-        String formatted = sm.getString(key, "XXX");
-        int insertIndex = formatted.indexOf("XXX");
-        return (insertIndex == -1) ? formatted : formatted.substring(0, insertIndex);
-    }
-    public static String getKeyFromPropertiesFile(String packagePath, String key) {
-        return getKeyFromPropertiesFile(packagePath, key, Locale.getDefault());
-    }
-    public static String getKeyFromPropertiesFile(StringManager sm, String key) {
-        String formatted = sm.getString(key, "XXX");
-        int insertIndex = formatted.indexOf("XXX");
-        return (insertIndex == -1) ? formatted : formatted.substring(0, insertIndex);
-    }
-
-    /**
-     * Injects a {@link LifecycleListener} to a {@link Context} of a {@link Container} that sends {@code ADD_CHILD_EVENT}.
-     * Useful when deploying with the Manager / HostConfig.
-     */
-    public static class ContainerInjector implements ContainerListener, AutoCloseable {
-
-        private final Container container;
-        private final Predicate<Context> filter;
-        private final Consumer<Context> action;
-        private volatile boolean installed = false;
-        private String containerEvent = Container.ADD_CHILD_EVENT;
-
-        private ContainerInjector(Container container, Predicate<Context> filter, Consumer<Context> action, String containerEvent) {
-            this.container = container;
-            this.filter = filter;
-            this.action = action;
-            if (containerEvent != null) {
-                this.containerEvent = containerEvent;
-            }
-            container.addContainerListener(this);
-        }
-
-        public static ContainerInjector inject(Container container, Predicate<Context> filter, Consumer<Context> action) {
-            return new ContainerInjector(container, filter, action, null);
-        }
-        public static ContainerInjector inject(Container container, Predicate<Context> filter, Consumer<Context> action, String containerEvent) {
-            return new ContainerInjector(container, filter, action, containerEvent);
-        }
-
-        @Override
-        public void containerEvent(ContainerEvent event) {
-            if (this.containerEvent.equals(event.getType()) && !installed) {
-                Object data = event.getData();
-                if (data instanceof Context) {
-                    Context ctx = (Context) data;
-                    if (filter != null && filter.test(ctx)) {
-                        action.accept(ctx);
-                        installed = true;
-                    }
-                }
-            }
-        }
-
-        @Override
-        public void close() {
-            container.removeContainerListener(this);
-        }
-    }
 }
